@@ -244,12 +244,12 @@ const short HITPIX=2; //hit-tolerance in pixel
             , sal_Int32 Width, sal_Int32 Height, sal_Int16 Flags )
             throw (uno::RuntimeException)
 {
+    SolarMutexGuard aGuard;
     uno::Reference<awt::XWindow> xWindow = m_xViewWindow;
-    Window* pWindow = m_pChartWindow;
-
-    if(xWindow.is() && pWindow)
+    
+    if(xWindow.is() && m_pChartWindow)
     {
-        Size aLogicSize = pWindow->PixelToLogic( Size( Width, Height ), MapMode( MAP_100TH_MM )  );
+        Size aLogicSize = m_pChartWindow->PixelToLogic( Size( Width, Height ), MapMode( MAP_100TH_MM )  );
 
         bool bIsEmbedded = true;
         //todo: for standalone chart: detect wether we are standalone
@@ -264,8 +264,8 @@ const short HITPIX=2; //hit-tolerance in pixel
             MapMode aNewMapMode( MAP_100TH_MM, Point(0,0)
             , Fraction(nScaleXNumerator,nScaleXDenominator)
             , Fraction(nScaleYNumerator,nScaleYDenominator) );
-            pWindow->SetMapMode(aNewMapMode);
-            pWindow->SetPosSizePixel( X, Y, Width, Height, Flags );
+            m_pChartWindow->SetMapMode(aNewMapMode);
+            m_pChartWindow->SetPosSizePixel( X, Y, Width, Height, Flags );
 
             //#i75867# poor quality of ole's alternative view with 3D scenes and zoomfactors besides 100%
             uno::Reference< beans::XPropertySet > xProp( m_xChartView, uno::UNO_QUERY );
@@ -286,7 +286,7 @@ const short HITPIX=2; //hit-tolerance in pixel
             //a correct work area is at least necessary for correct values in the position and  size dialog and for dragging area
             if(m_pDrawViewWrapper)
             {
-                Rectangle aRect(Point(0,0), pWindow->GetOutputSize());
+                Rectangle aRect(Point(0,0), m_pChartWindow->GetOutputSize());
                 m_pDrawViewWrapper->SetWorkArea( aRect );
             }
         }
@@ -294,9 +294,9 @@ const short HITPIX=2; //hit-tolerance in pixel
         {
             //change visarea
             ChartModelHelper::setPageSize( awt::Size( aLogicSize.Width(), aLogicSize.Height() ), getModel() );
-            pWindow->SetPosSizePixel( X, Y, Width, Height, Flags );
+            m_pChartWindow->SetPosSizePixel( X, Y, Width, Height, Flags );
         }
-        pWindow->Invalidate();
+        m_pChartWindow->Invalidate();
     }
 }
 
@@ -534,12 +534,11 @@ void ChartController::execute_Paint( const Rectangle& rRect )
         if( xUpdatable.is() )
             xUpdatable->update();
 
-        Window* pWindow = m_pChartWindow;
         {
             SolarMutexGuard aGuard;
             DrawViewWrapper* pDrawViewWrapper = m_pDrawViewWrapper;
             if(pDrawViewWrapper)
-                pDrawViewWrapper->CompleteRedraw(pWindow, Region(rRect) );
+                pDrawViewWrapper->CompleteRedraw(m_pChartWindow, Region(rRect) );
         }
     }
     catch( uno::Exception & ex )
@@ -563,9 +562,11 @@ bool isDoubleClick( const MouseEvent& rMEvt )
 
 void ChartController::startDoubleClickWaiting()
 {
+    SolarMutexGuard aGuard;
+
     m_bWaitingForDoubleClick = true;
 
-    ULONG nDblClkTime = 500;
+    sal_uLong nDblClkTime = 500;
     if( m_pChartWindow )
     {
         const MouseSettings& rMSettings = m_pChartWindow->GetSettings().GetMouseSettings();
@@ -588,11 +589,12 @@ IMPL_LINK( ChartController, DoubleClickWaitingHdl, void*, EMPTYARG )
     if( !m_bWaitingForMouseUp && m_aSelection.maybeSwitchSelectionAfterSingleClickWasEnsured() )
     {
         this->impl_selectObjectAndNotiy();
+        SolarMutexGuard aGuard;
         if( m_pChartWindow )
         {
             Window::PointerState aPointerState( m_pChartWindow->GetPointerState() );
             MouseEvent aMouseEvent( aPointerState.maPos,1/*nClicks*/,
-                                    0/*nMode*/, static_cast< USHORT >( aPointerState.mnState )/*nButtons*/,
+                                    0/*nMode*/, static_cast< sal_uInt16 >( aPointerState.mnState )/*nButtons*/,
                                     0/*nModifier*/ );
             impl_SetMousePointer( aMouseEvent );
         }
@@ -616,17 +618,16 @@ void ChartController::execute_MouseButtonDown( const MouseEvent& rMEvt )
 
     m_aSelection.remindSelectionBeforeMouseDown();
 
-    Window* pWindow = m_pChartWindow;
     DrawViewWrapper* pDrawViewWrapper = m_pDrawViewWrapper;
-    if(!pWindow || !pDrawViewWrapper )
+    if(!m_pChartWindow || !pDrawViewWrapper )
         return;
 
-    Point	aMPos	= pWindow->PixelToLogic(rMEvt.GetPosPixel());
+    Point	aMPos	= m_pChartWindow->PixelToLogic(rMEvt.GetPosPixel());
 
     if ( MOUSE_LEFT == rMEvt.GetButtons() )
     {
-        pWindow->GrabFocus();
-        pWindow->CaptureMouse();
+        m_pChartWindow->GrabFocus();
+        m_pChartWindow->CaptureMouse();
     }
 
     if( pDrawViewWrapper->IsTextEdit() )
@@ -711,7 +712,7 @@ void ChartController::execute_MouseButtonDown( const MouseEvent& rMEvt )
          && !rMEvt.IsRight() )
     {
         //start drag
-        USHORT  nDrgLog = (USHORT)pWindow->PixelToLogic(Size(DRGPIX,0)).Width();
+        sal_uInt16  nDrgLog = (sal_uInt16)m_pChartWindow->PixelToLogic(Size(DRGPIX,0)).Width();
         SdrDragMethod* pDragMethod = NULL;
 
         //change selection to 3D scene if rotate mode
@@ -751,9 +752,8 @@ void ChartController::execute_MouseMove( const MouseEvent& rMEvt )
 {
     SolarMutexGuard aGuard;
 
-    Window* pWindow = m_pChartWindow;
     DrawViewWrapper* pDrawViewWrapper = m_pDrawViewWrapper;
-    if(!pWindow || !pDrawViewWrapper)
+    if(!m_pChartWindow || !pDrawViewWrapper)
         return;
 
     if( m_pDrawViewWrapper->IsTextEdit() )
@@ -764,11 +764,9 @@ void ChartController::execute_MouseMove( const MouseEvent& rMEvt )
 
     if(pDrawViewWrapper->IsAction())
     {
-        pDrawViewWrapper->MovAction( pWindow->PixelToLogic( rMEvt.GetPosPixel() ) );
+        pDrawViewWrapper->MovAction( m_pChartWindow->PixelToLogic( rMEvt.GetPosPixel() ) );
     }
 
-    //??	pDrawViewWrapper->GetPageView()->DragPoly();
-    
     impl_SetMousePointer( rMEvt );
 }
 void ChartController::execute_Tracking( const TrackingEvent& /* rTEvt */ )
@@ -786,12 +784,11 @@ void ChartController::execute_MouseButtonUp( const MouseEvent& rMEvt )
     {
         SolarMutexGuard aGuard;
 
-        Window* pWindow = m_pChartWindow;
         DrawViewWrapper* pDrawViewWrapper = m_pDrawViewWrapper;
-        if(!pWindow || !pDrawViewWrapper)
+        if(!m_pChartWindow || !pDrawViewWrapper)
             return;
 
-        Point	aMPos	= pWindow->PixelToLogic(rMEvt.GetPosPixel());
+        Point	aMPos	= m_pChartWindow->PixelToLogic(rMEvt.GetPosPixel());
 
         if(pDrawViewWrapper->IsTextEdit())
         {
@@ -803,7 +800,11 @@ void ChartController::execute_MouseButtonUp( const MouseEvent& rMEvt )
         if ( m_eDrawMode == CHARTDRAW_INSERT && pDrawViewWrapper->IsCreateObj() )
         {
             pDrawViewWrapper->EndCreateObj( SDRCREATE_FORCEEND );
-            impl_switchDiagramPositioningToExcludingPositioning();
+            {
+                HiddenUndoContext aUndoContext( m_xUndoManager );
+                    // don't want the positioning Undo action to appear in the UI
+                impl_switchDiagramPositioningToExcludingPositioning();
+            }
             if ( pDrawViewWrapper->AreObjectsMarked() )
             {
                 if ( pDrawViewWrapper->GetCurrentObjIdentifier() == OBJ_TEXT )
@@ -840,12 +841,12 @@ void ChartController::execute_MouseButtonUp( const MouseEvent& rMEvt )
             if( pChartDragMethod )
             {
                 UndoGuard aUndoGuard( pChartDragMethod->getUndoDescription(),
-                        m_xUndoManager, getModel() );
+                        m_xUndoManager );
 
                 if( pDrawViewWrapper->EndDragObj(false) )
                 {
                     bDraggingDone = true;
-                    aUndoGuard.commitAction();
+                    aUndoGuard.commit();
                 }
             }
 
@@ -869,19 +870,25 @@ void ChartController::execute_MouseButtonUp( const MouseEvent& rMEvt )
                         if( !bIsMoveOnly && m_aSelection.isResizeableObjectSelected() )
                             eActionType = ActionDescriptionProvider::RESIZE;
                         
+                        ObjectType eObjectType = ObjectIdentifier::getObjectType( m_aSelection.getSelectedCID() );
+                        
                         UndoGuard aUndoGuard(
-                            ActionDescriptionProvider::createDescription(
-                                eActionType,
-                                ObjectNameProvider::getName( ObjectIdentifier::getObjectType( m_aSelection.getSelectedCID() ))),
-                            m_xUndoManager, getModel() );
-                        bool bChanged = PositionAndSizeHelper::moveObject( m_aSelection.getSelectedCID()
+                            ActionDescriptionProvider::createDescription( eActionType, ObjectNameProvider::getName( eObjectType)),
+                            m_xUndoManager );
+
+                        bool bChanged = false;    
+                        if ( eObjectType == OBJECTTYPE_LEGEND )
+                            bChanged = DiagramHelper::switchDiagramPositioningToExcludingPositioning( getModel(), false , true );
+                        
+                        bool bMoved = PositionAndSizeHelper::moveObject( m_aSelection.getSelectedCID()
                                         , getModel()
                                         , awt::Rectangle(aObjectRect.getX(),aObjectRect.getY(),aObjectRect.getWidth(),aObjectRect.getHeight())
                                         , awt::Rectangle(aPageRect.getX(),aPageRect.getY(),aPageRect.getWidth(),aPageRect.getHeight()) );
-                        if( bChanged )
+
+                        if( bMoved || bChanged )
                         {
                             bDraggingDone = true;
-                            aUndoGuard.commitAction();
+                            aUndoGuard.commit();
                         }
                     }
                 }
@@ -921,7 +928,7 @@ void ChartController::execute_MouseButtonUp( const MouseEvent& rMEvt )
         }
 
         //@todo ForcePointer(&rMEvt);
-        pWindow->ReleaseMouse();
+        m_pChartWindow->ReleaseMouse();
 
         if( m_aSelection.isSelectionDifferentFromBeforeMouseDown() )
             bNotifySelectionChange = true;
@@ -970,16 +977,18 @@ void ChartController::execute_DoubleClick( const Point* pMousePixel )
 
 void ChartController::execute_Resize()
 {
-    m_pChartWindow->Invalidate();
+    SolarMutexGuard aGuard;
+    if(m_pChartWindow)
+        m_pChartWindow->Invalidate();
 }
 void ChartController::execute_Activate()
 {
-    ///// pDrawViewWrapper->SetEditMode(TRUE);
+    ///// pDrawViewWrapper->SetEditMode(sal_True);
 }
 void ChartController::execute_Deactivate()
 {
     /*
-    pDrawViewWrapper->SetEditMode(FALSE);
+    pDrawViewWrapper->SetEditMode(sal_False);
     this->ReleaseMouse();
     */
 }
@@ -993,13 +1002,11 @@ void ChartController::execute_LoseFocus()
 
 void ChartController::execute_Command( const CommandEvent& rCEvt )
 {
-    Window* pWindow = m_pChartWindow;
-
     bool bIsAction = false;
     {
         SolarMutexGuard aGuard;
         DrawViewWrapper* pDrawViewWrapper = m_pDrawViewWrapper;
-        if(!pWindow || !pDrawViewWrapper)
+        if(!m_pChartWindow || !pDrawViewWrapper)
             return;
         bIsAction = m_pDrawViewWrapper->IsAction();
     }
@@ -1007,7 +1014,11 @@ void ChartController::execute_Command( const CommandEvent& rCEvt )
     // pop-up menu
     if(rCEvt.GetCommand() == COMMAND_CONTEXTMENU && !bIsAction)
     {
-        m_pChartWindow->ReleaseMouse();
+        {
+            SolarMutexGuard aGuard;
+            if(m_pChartWindow)
+                m_pChartWindow->ReleaseMouse();
+        }
 
         if( m_aSelection.isSelectionDifferentFromBeforeMouseDown() )
             impl_notifySelectionChangeListeners();
@@ -1021,7 +1032,9 @@ void ChartController::execute_Command( const CommandEvent& rCEvt )
             Point aPos( rCEvt.GetMousePosPixel() );
             if( !rCEvt.IsMouseEvent() )
             {
-                aPos = m_pChartWindow->GetPointerState().maPos;
+                SolarMutexGuard aGuard;
+                if(m_pChartWindow)
+                    aPos = m_pChartWindow->GetPointerState().maPos;
             }
             aContextMenuHelper.completeAndExecute( aPos, aContextMenu );
         }
@@ -1087,7 +1100,6 @@ void ChartController::execute_Command( const CommandEvent& rCEvt )
                         }
                     }
 
-                    //const sal_Int32 nIdBeforeFormat = nUniqueId;
                     if( bIsPoint )
                     {
                         if( bHasDataLabelAtPoint )
@@ -1139,10 +1151,7 @@ void ChartController::execute_Command( const CommandEvent& rCEvt )
                     if( bHasYErrorBars )
                         lcl_insertMenuCommand( xPopupMenu, xMenuEx, nUniqueId++, C2U(".uno:FormatYErrorBars") );
 
-                    //if( nIdBeforeFormat != nUniqueId )
-                        xPopupMenu->insertSeparator( -1 );
-
-                    //const sal_Int32 nIdBeforeInsert = nUniqueId;
+                    xPopupMenu->insertSeparator( -1 );
 
                     if( !bHasDataLabelsAtSeries )
                         lcl_insertMenuCommand( xPopupMenu, xMenuEx, nUniqueId++, C2U(".uno:InsertDataLabels") );
@@ -1155,10 +1164,6 @@ void ChartController::execute_Command( const CommandEvent& rCEvt )
                     if( !bHasYErrorBars )
                         lcl_insertMenuCommand( xPopupMenu, xMenuEx, nUniqueId++, C2U(".uno:InsertYErrorBars") );
 
-                    //if( nIdBeforeInsert != nUniqueId )
-                    //    xPopupMenu->insertSeparator( -1 );
-
-                    //const sal_Int32 nIdBeforeDelete = nUniqueId;
 
                     if( bHasDataLabelsAtSeries || ( bHasDataLabelsAtPoints && bHasFormattedDataPointsOtherThanSelected ) )
                         lcl_insertMenuCommand( xPopupMenu, xMenuEx, nUniqueId++, C2U(".uno:DeleteDataLabels") );
@@ -1174,8 +1179,7 @@ void ChartController::execute_Command( const CommandEvent& rCEvt )
                     if( bHasFormattedDataPointsOtherThanSelected )
                         lcl_insertMenuCommand( xPopupMenu, xMenuEx, nUniqueId++, C2U(".uno:ResetAllDataPoints"));
 
-                    //if( nIdBeforeDelete != nUniqueId )
-                        xPopupMenu->insertSeparator( -1 );
+                    xPopupMenu->insertSeparator( -1 );
                     
                     lcl_insertMenuCommand( xPopupMenu, xMenuEx, nUniqueId, C2U(".uno:ArrangeRow"));
                     uno::Reference< awt::XPopupMenu > xArrangePopupMenu( 
@@ -1291,7 +1295,11 @@ void ChartController::execute_Command( const CommandEvent& rCEvt )
                 ::svt::ContextMenuHelper aContextMenuHelper( m_xFrame );
                 Point aPos( rCEvt.GetMousePosPixel() );
                 if( !rCEvt.IsMouseEvent() )
-                    aPos = m_pChartWindow->GetPointerState().maPos;
+                {
+                    SolarMutexGuard aGuard;
+                    if(m_pChartWindow)
+                        aPos = m_pChartWindow->GetPointerState().maPos;
+                }
                 aContextMenuHelper.completeAndExecute( aPos, xPopupMenu );
             }
         }
@@ -1302,6 +1310,7 @@ void ChartController::execute_Command( const CommandEvent& rCEvt )
              ( rCEvt.GetCommand() == COMMAND_INPUTCONTEXTCHANGE ) )
     {
         //#i84417# enable editing with IME
+        SolarMutexGuard aGuard;
         if( m_pDrawViewWrapper )
             m_pDrawViewWrapper->Command( rCEvt, m_pChartWindow );
     }
@@ -1311,9 +1320,8 @@ bool ChartController::execute_KeyInput( const KeyEvent& rKEvt )
 {
     bool bReturn=false;
 
-    Window* pWindow = m_pChartWindow;
     DrawViewWrapper* pDrawViewWrapper = m_pDrawViewWrapper;
-    if(!pWindow || !pDrawViewWrapper)
+    if(!m_pChartWindow || !pDrawViewWrapper)
         return bReturn;
 
     // handle accelerators
@@ -1328,7 +1336,6 @@ bool ChartController::execute_KeyInput( const KeyEvent& rKEvt )
 
     KeyCode aKeyCode( rKEvt.GetKeyCode());
     sal_uInt16 nCode = aKeyCode.GetCode();
-//     bool bShift = aKeyCode.IsShift();
     bool bAlternate = aKeyCode.IsMod2();
 
     if( m_apAccelExecute.get() )
@@ -1336,20 +1343,21 @@ bool ChartController::execute_KeyInput( const KeyEvent& rKEvt )
     if( bReturn )
         return bReturn;
 
-    if( pDrawViewWrapper->IsTextEdit() )
     {
-        if( pDrawViewWrapper->KeyInput(rKEvt,pWindow) )
+        SolarMutexGuard aGuard;
+        if( pDrawViewWrapper->IsTextEdit() )
         {
-            bReturn = true;
-            if( nCode == KEY_ESCAPE )
+            if( pDrawViewWrapper->KeyInput(rKEvt,m_pChartWindow) )
             {
-                this->EndTextEdit();
+                bReturn = true;
+                if( nCode == KEY_ESCAPE )
+                {
+                    this->EndTextEdit();
+                }
             }
         }
     }
 
-    //if( m_pDrawViewWrapper->IsAction() );
-
     // keyboard accessibility
     ObjectType eObjectType = ObjectIdentifier::getObjectType( m_aSelection.getSelectedCID() );
     if( ! bReturn )
@@ -1435,12 +1443,16 @@ bool ChartController::execute_KeyInput( const KeyEvent& rKEvt )
                     // default 1 mm in each direction
                     double fGrowAmountX = 200.0;
                     double fGrowAmountY = 200.0;
-                    if( bAlternate && pWindow )
+                    if( bAlternate && m_pChartWindow )
                     {
                         // together with Alt-key: 1 px in each direction
-                        Size aPixelSize = pWindow->PixelToLogic( Size( 2, 2 ));
-                        fGrowAmountX = static_cast< double >( aPixelSize.Width());
-                        fGrowAmountY = static_cast< double >( aPixelSize.Height());
+                        SolarMutexGuard aGuard;
+                        if( m_pChartWindow )
+                        {
+                            Size aPixelSize = m_pChartWindow->PixelToLogic( Size( 2, 2 ));
+                            fGrowAmountX = static_cast< double >( aPixelSize.Width());
+                            fGrowAmountY = static_cast< double >( aPixelSize.Height());
+                        }
                     }
                     if( nCode == KEY_SUBTRACT )
                     {
@@ -1462,12 +1474,16 @@ bool ChartController::execute_KeyInput( const KeyEvent& rKEvt )
                     // default 1 mm
                     double fShiftAmountX = 100.0;
                     double fShiftAmountY = 100.0;
-                    if( bAlternate && pWindow )
+                    if( bAlternate && m_pChartWindow )
                     {
                         // together with Alt-key: 1 px
-                        Size aPixelSize = pWindow->PixelToLogic( Size( 1, 1 ));
-                        fShiftAmountX = static_cast< double >( aPixelSize.Width());
-                        fShiftAmountY = static_cast< double >( aPixelSize.Height());
+                        SolarMutexGuard aGuard;
+                        if(m_pChartWindow)
+                        {
+                            Size aPixelSize = m_pChartWindow->PixelToLogic( Size( 1, 1 ));
+                            fShiftAmountX = static_cast< double >( aPixelSize.Width());
+                            fShiftAmountY = static_cast< double >( aPixelSize.Height());
+                        }
                     }
                     switch( nCode )
                     {
@@ -1558,25 +1574,11 @@ bool ChartController::execute_KeyInput( const KeyEvent& rKEvt )
         bReturn = executeDispatch_Delete();
         if( ! bReturn )
         {
+            SolarMutexGuard aGuard;
             InfoBox( m_pChartWindow, String(SchResId( STR_ACTION_NOTPOSSIBLE ))).Execute();
         }
     }
 
-    /* old chart:
-    // Ctrl-Shift-R: Repaint
-    if (!bReturn && GetWindow())
-    {
-        KeyCode aKeyCode = rKEvt.GetKeyCode();
-
-        if (aKeyCode.IsMod1() && aKeyCode.IsShift()
-            && aKeyCode.GetCode() == KEY_R)
-        {
-                // 3D-Kontext wieder zerstoeren
-            GetWindow()->Invalidate();
-            bReturn = TRUE;
-        }
-    }
-    */
     return bReturn;
 }
 
@@ -1656,7 +1658,16 @@ bool ChartController::requestQuickHelp(
 
     if ( bSuccess )
     {
+        SolarMutexGuard aGuard;
+        if ( m_pDrawViewWrapper && m_pDrawViewWrapper->IsTextEdit() )
+        {
+            this->EndTextEdit();
+        }
         this->impl_selectObjectAndNotiy();
+        if ( m_pChartWindow )
+        {
+            m_pChartWindow->Invalidate();
+        }
         return sal_True;
     }
 
@@ -1730,11 +1741,14 @@ bool ChartController::requestQuickHelp(
 
 void ChartController::impl_selectObjectAndNotiy()
 {
-    DrawViewWrapper* pDrawViewWrapper = m_pDrawViewWrapper;
-    if( pDrawViewWrapper )
     {
-        pDrawViewWrapper->SetDragMode( m_eDragMode );
-        m_aSelection.applySelection( m_pDrawViewWrapper );
+        SolarMutexGuard aGuard;
+        DrawViewWrapper* pDrawViewWrapper = m_pDrawViewWrapper;
+        if( pDrawViewWrapper )
+        {
+            pDrawViewWrapper->SetDragMode( m_eDragMode );
+            m_aSelection.applySelection( m_pDrawViewWrapper );
+        }
     }
     impl_notifySelectionChangeListeners();
 }
@@ -1809,7 +1823,7 @@ bool ChartController::impl_moveOrResizeObject(
 
             ObjectType eObjectType = ObjectIdentifier::getObjectType( rCID );
             UndoGuard aUndoGuard( ActionDescriptionProvider::createDescription(
-                    eActionType, ObjectNameProvider::getName( eObjectType )), m_xUndoManager, xChartModel );
+                    eActionType, ObjectNameProvider::getName( eObjectType )), m_xUndoManager );
             {
                 ControllerLockGuard aCLGuard( xChartModel );
                 if( bNeedShift )
@@ -1817,7 +1831,7 @@ bool ChartController::impl_moveOrResizeObject(
                 if( bNeedResize || (eObjectType == OBJECTTYPE_DIAGRAM) )//Also set an explicat size at the diagram when an explicit position is set
                     xObjProp->setPropertyValue( C2U("RelativeSize"), uno::makeAny( aRelSize ));
             }
-            aUndoGuard.commitAction();
+            aUndoGuard.commit();
         }
     }
     return bResult;
@@ -1863,19 +1877,18 @@ bool ChartController::impl_DragDataPoint( const ::rtl::OUString & rCID, double f
 void ChartController::impl_SetMousePointer( const MouseEvent & rEvent )
 {
     SolarMutexGuard aGuard;
-    Window* pWindow = m_pChartWindow;
-    if( m_pDrawViewWrapper && pWindow )
+    if( m_pDrawViewWrapper && m_pChartWindow )
     {
-        Point aMousePos( pWindow->PixelToLogic( rEvent.GetPosPixel()));
+        Point aMousePos( m_pChartWindow->PixelToLogic( rEvent.GetPosPixel()));
         sal_uInt16 nModifier = rEvent.GetModifier();
-        BOOL bLeftDown = rEvent.IsLeft();
+        sal_Bool bLeftDown = rEvent.IsLeft();
 
         if ( m_pDrawViewWrapper->IsTextEdit() )
         {
             if( m_pDrawViewWrapper->IsTextEditHit( aMousePos, HITPIX) )
             {
-                pWindow->SetPointer( m_pDrawViewWrapper->GetPreferedPointer(
-                    aMousePos, pWindow, nModifier, bLeftDown ) );
+                m_pChartWindow->SetPointer( m_pDrawViewWrapper->GetPreferedPointer(
+                    aMousePos, m_pChartWindow, nModifier, bLeftDown ) );
                 return;
             }
         }
@@ -1892,7 +1905,7 @@ void ChartController::impl_SetMousePointer( const MouseEvent & rEvent )
         {
             
             Pointer aPointer = m_pDrawViewWrapper->GetPreferedPointer(
-                aMousePos, pWindow, nModifier, bLeftDown );
+                aMousePos, m_pChartWindow, nModifier, bLeftDown );
             bool bForceArrowPointer = false;
 
             ObjectIdentifier aOID( m_aSelection.getSelectedOID() );
@@ -1925,9 +1938,9 @@ void ChartController::impl_SetMousePointer( const MouseEvent & rEvent )
             }
 
             if( bForceArrowPointer )
-                pWindow->SetPointer( Pointer( POINTER_ARROW ));
+                m_pChartWindow->SetPointer( Pointer( POINTER_ARROW ));
             else
-                pWindow->SetPointer( aPointer );
+                m_pChartWindow->SetPointer( aPointer );
         }
         else
         {
@@ -1976,7 +1989,7 @@ void ChartController::impl_SetMousePointer( const MouseEvent & rEvent )
                         }
                         break;
                 }
-                pWindow->SetPointer( Pointer( ePointerStyle ) );
+                m_pChartWindow->SetPointer( Pointer( ePointerStyle ) );
                 return;
             }
 
@@ -1988,7 +2001,7 @@ void ChartController::impl_SetMousePointer( const MouseEvent & rEvent )
             {
                 if( aHitObjectCID.equals(m_aSelection.getSelectedCID()) )
                 {
-                    pWindow->SetPointer( Pointer( POINTER_ARROW ));
+                    m_pChartWindow->SetPointer( Pointer( POINTER_ARROW ));
                     return;
                 }
             }
@@ -1996,14 +2009,14 @@ void ChartController::impl_SetMousePointer( const MouseEvent & rEvent )
             if( !aHitObjectCID.getLength() )
             {
                 //additional shape was hit
-                pWindow->SetPointer( POINTER_MOVE );
+                m_pChartWindow->SetPointer( POINTER_MOVE );
             }
             else if( ObjectIdentifier::isDragableObject( aHitObjectCID ) )
             {
                 if( (m_eDragMode == SDRDRAG_ROTATE)
                     && SelectionHelper::isRotateableObject( aHitObjectCID
                         , getModel() ) )
-                    pWindow->SetPointer( Pointer( POINTER_ROTATE ) );
+                    m_pChartWindow->SetPointer( Pointer( POINTER_ROTATE ) );
                 else
                 {
                     ObjectType eHitObjectType = ObjectIdentifier::getObjectType( aHitObjectCID );
@@ -2012,15 +2025,15 @@ void ChartController::impl_SetMousePointer( const MouseEvent & rEvent )
                         if( !ObjectIdentifier::areSiblings(aHitObjectCID,m_aSelection.getSelectedCID())
                             && !ObjectIdentifier::areIdenticalObjects(aHitObjectCID,m_aSelection.getSelectedCID()) )
                         {
-                            pWindow->SetPointer( Pointer( POINTER_ARROW ));
+                            m_pChartWindow->SetPointer( Pointer( POINTER_ARROW ));
                             return;
                         }
                     }
-                    pWindow->SetPointer( POINTER_MOVE );
+                    m_pChartWindow->SetPointer( POINTER_MOVE );
                 }
             }
             else
-                pWindow->SetPointer( Pointer( POINTER_ARROW ));
+                m_pChartWindow->SetPointer( Pointer( POINTER_ARROW ));
         }
     }
 }
