@@ -158,7 +158,6 @@ TickmarkProperties AxisProperties::makeTickmarkPropertiesForComplexCategories(
     return aTickmarkProperties;
 }
 
-//static
 TickmarkProperties AxisProperties::getBiggestTickmarkProperties()
 {
     TickmarkProperties aTickmarkProperties;
@@ -184,7 +183,6 @@ AxisProperties::AxisProperties( const uno::Reference< XAxis >& xAxisModel
     , m_pfExrtaLinePositionAtOtherAxis(NULL)
     , m_bCrossingAxisHasReverseDirection(false)
     , m_bCrossingAxisIsCategoryAxes(false)
-    , m_bAxisBetweenCategories(false)
     , m_fLabelDirectionSign(1.0)
     , m_fInnerDirectionSign(1.0)
     , m_aLabelAlignment(LABEL_ALIGN_RIGHT_TOP)
@@ -214,7 +212,6 @@ AxisProperties::AxisProperties( const AxisProperties& rAxisProperties )
     , m_pfExrtaLinePositionAtOtherAxis( NULL )
     , m_bCrossingAxisHasReverseDirection( rAxisProperties.m_bCrossingAxisHasReverseDirection )
     , m_bCrossingAxisIsCategoryAxes( rAxisProperties.m_bCrossingAxisIsCategoryAxes )
-    , m_bAxisBetweenCategories( rAxisProperties.m_bAxisBetweenCategories )
     , m_fLabelDirectionSign( rAxisProperties.m_fLabelDirectionSign )
     , m_fInnerDirectionSign( rAxisProperties.m_fInnerDirectionSign )
     , m_aLabelAlignment( rAxisProperties.m_aLabelAlignment )
@@ -281,11 +278,7 @@ void AxisProperties::initAxisPositioning( const uno::Reference< beans::XProperty
                 xAxisProp->getPropertyValue(C2U( "CrossoverValue" )) >>= fValue;
 
                 if( m_bCrossingAxisIsCategoryAxes )
-                {
                     fValue = ::rtl::math::round(fValue);
-                    if( m_bAxisBetweenCategories )
-                        fValue-=0.5;
-                }
                 m_pfMainLinePositionAtOtherAxis = new double(fValue);
             }
             else if( ::com::sun::star::chart::ChartAxisPosition_ZERO == m_eCrossoverType )
@@ -319,8 +312,17 @@ void AxisProperties::init( bool bCartesian )
     if( m_nDimensionIndex<2 )
         initAxisPositioning( xProp );
 
+    ScaleData aScaleData = m_xAxisModel->getScaleData();
+    if( m_nDimensionIndex==0 )
+        AxisHelper::checkDateAxis( aScaleData, m_pExplicitCategoriesProvider, bCartesian );
+    m_nAxisType = aScaleData.AxisType;
+
     if( bCartesian )
     {
+        if( m_nDimensionIndex == 0 && m_nAxisType == AxisType::CATEGORY
+                && m_pExplicitCategoriesProvider && m_pExplicitCategoriesProvider->hasComplexCategories() )
+            m_bComplexCategories = true;
+
         if( ::com::sun::star::chart::ChartAxisPosition_END == m_eCrossoverType )
             m_fInnerDirectionSign = m_bCrossingAxisHasReverseDirection ? 1 : -1;
         else
@@ -362,10 +364,6 @@ void AxisProperties::init( bool bCartesian )
         //init display labels    
         xProp->getPropertyValue( C2U( "DisplayLabels" ) ) >>= m_bDisplayLabels;
 
-        //init categories
-        ScaleData aScaleData = m_xAxisModel->getScaleData();
-        m_nAxisType = aScaleData.AxisType;
-                
         //init TickmarkProperties
         xProp->getPropertyValue( C2U( "MajorTickmarks" ) ) >>= m_nMajorTickmarks;
         xProp->getPropertyValue( C2U( "MinorTickmarks" ) ) >>= m_nMinorTickmarks;
@@ -403,16 +401,7 @@ AxisLabelProperties::AxisLabelProperties()
                         , nRhythm( 1 )
                         , bRhythmIsFix(false)
 {
-    /*
-    aLocale.Language = C2U( "en" );
-    aLocale.Country  = C2U( "US" );
 
-    //aLocale.Language = C2U( "ar" );
-    //aLocale.Country  = C2U( "IR" );
-
-    //aLocale.Language = C2U( "ja" );
-    //aLocale.Country  = C2U( "JP" );
-    */
 }
 
 void AxisLabelProperties::init( const uno::Reference< XAxis >& xAxisModel )
@@ -453,28 +442,6 @@ void AxisLabelProperties::init( const uno::Reference< XAxis >& xAxisModel )
     }
 }
 
-/*
-sal_Int16 getSwappedWritingMode( sal_Int16 nWritingMode )
-{
-    //LR_TB == LT
-    //RL_TB == RT (Arabic, Hebrew)
-    //TB_RL == TR (Japanese, Chinese, Korean)
-    // ?? TL (Mongolian) see also text::WritingMode2
-
-    switch(nWritingMode)
-    {
-        case text::WritingMode2::RL_TB:
-            return  text::WritingMode2::TB_RL;
-        case text::WritingMode2::TB_RL:
-            return  text::WritingMode2::RL_TB;
-        case text::WritingMode2::LR_TB:
-            return  text::WritingMode2::TB_LR;
-        default:
-            return  text::WritingMode2::LR_TB;
-    }
-}
-*/
-
 sal_Bool AxisLabelProperties::getIsStaggered() const
 {
     if( STAGGER_ODD == eStaggering || STAGGER_EVEN == eStaggering )
