@@ -79,7 +79,6 @@ namespace chart
 //-----------------------------------------------------------------------------
 //-----------------------------------------------------------------------------
 
-//static
 void ShapeFactory::setShapeName( const uno::Reference< drawing::XShape >& xShape
                                , const rtl::OUString& rName )
 {
@@ -103,7 +102,6 @@ void ShapeFactory::setShapeName( const uno::Reference< drawing::XShape >& xShape
 
 //-----------------------------------------------------------------------------
 
-//static
 rtl::OUString ShapeFactory::getShapeName( const uno::Reference< drawing::XShape >& xShape )
 {
     rtl::OUString aRet;
@@ -187,7 +185,6 @@ uno::Any createPolyPolygon_Cube(
     //fWidthH stands for Half Width
     const double fWidthH = rSize.DirectionX >=0.0?  rSize.DirectionX/2.0  : -rSize.DirectionX/2.0;
     const double fHeight = rSize.DirectionY;
-//     const double fDepth  = rSize.DirectionZ >=0.0?  rSize.DirectionZ      : -rSize.DirectionZ ;
 
     const double fHeightSign = fHeight >= 0.0 ? 1.0 : -1.0;
 
@@ -216,7 +213,6 @@ uno::Any createPolyPolygon_Cube(
 
     for(sal_Int32 nN = nPointCount; nN--;)
         *pInnerSequenceZ++ = 0.0;
-        //*pInnerSequenceZ++ = -fDepth/2.0;
 
     if(nPointCount == 5)
     {
@@ -954,26 +950,6 @@ drawing::PolyPolygonBezierCoords getRingBezierCoords(
         fStartAngleRadian, fWidthAngleRadian, fUnitCircleInnerRadius, aTransformationFromUnitCircle, fAngleSubdivisionRadian );
     appendAndCloseBezierCoords( aReturn, aInnerArc, sal_True );
 
-    //fill rMarkHandlePoints
-    /*
-    {
-        rMarkHandlePoints.realloc(1);
-        rMarkHandlePoints[0].realloc(6);
-        sal_Int32 nHandleCount=0;
-        sal_Int32 nOuterArcCount = aOuterArc.Coordinates[0].getLength();
-        if(nOuterArcCount>0)
-            rMarkHandlePoints[0][nHandleCount++]=aOuterArc.Coordinates[0][0];
-        if(nOuterArcCount>1)
-            rMarkHandlePoints[0][nHandleCount++]=aOuterArc.Coordinates[0][nOuterArcCount-1];
-        sal_Int32 nInnerArcCount = aInnerArc.Coordinates[0].getLength();
-        if(nInnerArcCount>0)
-            rMarkHandlePoints[0][nHandleCount++]=aInnerArc.Coordinates[0][0];
-        if(nInnerArcCount>1)
-            rMarkHandlePoints[0][nHandleCount++]=aInnerArc.Coordinates[0][nInnerArcCount-1];
-        rMarkHandlePoints[0].realloc(nHandleCount);
-    }
-    */
-
     return aReturn;
 }
 
@@ -1019,19 +995,6 @@ uno::Reference< drawing::XShape >
                 , aTransformationFromUnitCircle, fAngleSubdivisionRadian );
 
             xProp->setPropertyValue( C2U( "PolyPolygonBezier" ), uno::makeAny( aCoords ) );
-
-            //add shape for markhandles
-            /*
-            drawing::PointSequenceSequence aMarkHandlePoints(1); to be filled within getRingBezierCoords
-            if( xGroup.is() )
-            {
-                VLineProperties aHandleLineProperties;
-                aHandleLineProperties.LineStyle    = uno::makeAny( drawing::LineStyle_NONE );
-                uno::Reference< drawing::XShape > xHandleShape =
-                    this->createLine2D( xGroup, aMarkHandlePoints, &aHandleLineProperties );
-                this->setShapeName( xHandleShape, C2U("HandlesOnly") );
-            }
-            */
         }
         catch( uno::Exception& e )
         {
@@ -1495,7 +1458,7 @@ drawing::PolyPolygonShape3D createPolyPolygon_Symbol( const drawing::Position3D&
             break;
         }
     }
-    //return uno::Any( &aPP, ::getCppuType((const drawing::PolyPolygonShape3D*)0) );
+
     return aPP;
 }
 
@@ -1646,7 +1609,7 @@ uno::Reference< drawing::XShapes >
 
         xTarget->add(xShape);
 
-        //it is necessary to set the transform matrix to initialize the scene properly (bug #106316#)
+        //it is necessary to set the transform matrix to initialize the scene properly
         //otherwise all objects which are placed into this Group will not be visible
         //the following should be unnecessary after a the bug is fixed
         {
@@ -1806,11 +1769,7 @@ uno::Reference< drawing::XShape >
     //create shape
     uno::Reference< drawing::XShape > xShape(
         m_xShapeFactory->createInstance( C2U(
-            //"com.sun.star.drawing.LineShape") ), uno::UNO_QUERY );
             "com.sun.star.drawing.PolyLineShape") ), uno::UNO_QUERY );
-            //"com.sun.star.drawing.PolyLinePathShape") ), uno::UNO_QUERY );
-            //"com.sun.star.drawing.PolyPolygonPathShape") ), uno::UNO_QUERY );
-            //"com.sun.star.drawing.PolyPolygonShape") ), uno::UNO_QUERY );
     xTarget->add(xShape);
 
     //set properties
@@ -1960,7 +1919,6 @@ uno::Reference< drawing::XShape >
     return xShape;
 }
 
-//static
 rtl::OUString ShapeFactory::getStackedString( const rtl::OUString& rString, bool bStacked )
 {
     sal_Int32 nLen = rString.getLength();
@@ -1981,7 +1939,6 @@ rtl::OUString ShapeFactory::getStackedString( const rtl::OUString& rString, bool
     return aStackStr.makeStringAndClear();
 }
 
-//static
 bool ShapeFactory::hasPolygonAnyLines( drawing::PolyPolygonShape3D& rPoly)
 {
     // #i67757# check all contained polygons, if at least one polygon contains 2 or more points, return true
@@ -1991,7 +1948,6 @@ bool ShapeFactory::hasPolygonAnyLines( drawing::PolyPolygonShape3D& rPoly)
     return false;
 }
 
-//static
 bool ShapeFactory::isPolygonEmptyOrSinglePoint( drawing::PolyPolygonShape3D& rPoly)
 {
     // true, if empty polypolygon or one polygon with one point
@@ -1999,7 +1955,6 @@ bool ShapeFactory::isPolygonEmptyOrSinglePoint( drawing::PolyPolygonShape3D& rPo
         ((rPoly.SequenceX.getLength() == 1) && (rPoly.SequenceX[0].getLength() <= 1));
 }
 
-//static
 void ShapeFactory::closePolygon( drawing::PolyPolygonShape3D& rPoly)
 {
     DBG_ASSERT( rPoly.SequenceX.getLength() <= 1, "ShapeFactory::closePolygon - single polygon expected" );
@@ -2010,7 +1965,6 @@ void ShapeFactory::closePolygon( drawing::PolyPolygonShape3D& rPoly)
     AddPointToPoly( rPoly, aFirst );
 }
 
-//static
 awt::Size ShapeFactory::calculateNewSizeRespectingAspectRatio(
          const awt::Size& rTargetSize
          , const awt::Size& rSourceSizeWithCorrectAspectRatio )
@@ -2026,7 +1980,6 @@ awt::Size ShapeFactory::calculateNewSizeRespectingAspectRatio(
     return aNewSize;
 }
 
-//static
 awt::Point ShapeFactory::calculateTopLeftPositionToCenterObject(
            const awt::Point& rTargetAreaPosition
          , const awt::Size& rTargetAreaSize
@@ -2038,7 +1991,6 @@ awt::Point ShapeFactory::calculateTopLeftPositionToCenterObject(
     return aNewPosition;
 }
 
-//static
 ::basegfx::B2IRectangle ShapeFactory::getRectangleOfShape(
         const uno::Reference< drawing::XShape >& xShape )
 {
@@ -2054,7 +2006,6 @@ awt::Point ShapeFactory::calculateTopLeftPositionToCenterObject(
 
 }
 
-//static
 awt::Size ShapeFactory::getSizeAfterRotation(
          const uno::Reference< drawing::XShape >& xShape, double fRotationAngleDegree )
 {
