@@ -57,9 +57,10 @@
 //	nur Search ohne Optimierung!
 
 // STATIC DATA -----------------------------------------------------------
+using ::editeng::SvxBorderLine;
 using namespace formula;
 
-inline BOOL IsAmbiguousScriptNonZero( BYTE nScript )
+inline bool IsAmbiguousScriptNonZero( sal_uInt8 nScript )
 {
     //!	move to a header file
     return ( nScript != SCRIPTTYPE_LATIN &&
@@ -110,13 +111,13 @@ void ScColumn::Init(SCCOL nNewCol, SCTAB nNewTab, ScDocument* pDoc)
 }
 
 
-SCsROW ScColumn::GetNextUnprotected( SCROW nRow, BOOL bUp ) const
+SCsROW ScColumn::GetNextUnprotected( SCROW nRow, bool bUp ) const
 {
     return pAttrArray->GetNextUnprotected(nRow, bUp);
 }
 
 
-USHORT ScColumn::GetBlockMatrixEdges( SCROW nRow1, SCROW nRow2, USHORT nMask ) const
+sal_uInt16 ScColumn::GetBlockMatrixEdges( SCROW nRow1, SCROW nRow2, sal_uInt16 nMask ) const
 {
     // nix:0, mitte:1, unten:2, links:4, oben:8, rechts:16, offen:32
     if ( !pItems )
@@ -139,8 +140,8 @@ USHORT ScColumn::GetBlockMatrixEdges( SCROW nRow1, SCROW nRow2, USHORT nMask ) c
     else
     {
         ScAddress aOrg( ScAddress::INITIALIZE_INVALID );
-        BOOL bOpen = FALSE;
-        USHORT nEdges = 0;
+        bool bOpen = false;
+        sal_uInt16 nEdges = 0;
         SCSIZE nIndex;
         Search( nRow1, nIndex );
         while ( nIndex < nCount && pItems[nIndex].nRow <= nRow2 )
@@ -153,7 +154,7 @@ USHORT ScColumn::GetBlockMatrixEdges( SCROW nRow1, SCROW nRow2, USHORT nMask ) c
                 if ( nEdges )
                 {
                     if ( nEdges & 8 )
-                        bOpen = TRUE;	// obere Kante oeffnet, weitersehen
+                        bOpen = true;	// obere Kante oeffnet, weitersehen
                     else if ( !bOpen )
                         return nEdges | 32;	// es gibt was, was nicht geoeffnet wurde
                     else if ( nEdges & 1 )
@@ -164,7 +165,7 @@ USHORT ScColumn::GetBlockMatrixEdges( SCROW nRow1, SCROW nRow2, USHORT nMask ) c
                         || ((nMask & 4)  && (nEdges & 16) && !(nEdges & 4)) )
                         return nEdges;	// nur linke/rechte Kante
                     if ( nEdges & 2 )
-                        bOpen = FALSE;	// untere Kante schliesst
+                        bOpen = false;	// untere Kante schliesst
                 }
             }
             nIndex++;
@@ -176,11 +177,11 @@ USHORT ScColumn::GetBlockMatrixEdges( SCROW nRow1, SCROW nRow2, USHORT nMask ) c
 }
 
 
-BOOL ScColumn::HasSelectionMatrixFragment(const ScMarkData& rMark) const
+bool ScColumn::HasSelectionMatrixFragment(const ScMarkData& rMark) const
 {
     if ( rMark.IsMultiMarked() )
     {
-        BOOL bFound = FALSE;
+        bool bFound = false;
 
         ScAddress aOrg( ScAddress::INITIALIZE_INVALID );
         ScAddress aCurOrg( ScAddress::INITIALIZE_INVALID );
@@ -188,8 +189,8 @@ BOOL ScColumn::HasSelectionMatrixFragment(const ScMarkData& rMark) const
         ScMarkArrayIter aMarkIter( rMark.GetArray()+nCol );
         while ( !bFound && aMarkIter.Next( nTop, nBottom ) )
         {
-            BOOL bOpen = FALSE;
-            USHORT nEdges;
+            bool bOpen = false;
+            sal_uInt16 nEdges;
             SCSIZE nIndex;
             Search( nTop, nIndex );
             while ( !bFound && nIndex < nCount && pItems[nIndex].nRow <= nBottom )
@@ -202,16 +203,16 @@ BOOL ScColumn::HasSelectionMatrixFragment(const ScMarkData& rMark) const
                     if ( nEdges )
                     {
                         if ( nEdges & 8 )
-                            bOpen = TRUE;	// obere Kante oeffnet, weitersehen
+                            bOpen = true;	// obere Kante oeffnet, weitersehen
                         else if ( !bOpen )
-                            return TRUE;	// es gibt was, was nicht geoeffnet wurde
+                            return true;	// es gibt was, was nicht geoeffnet wurde
                         else if ( nEdges & 1 )
-                            bFound = TRUE;	// mittendrin, alles selektiert?
+                            bFound = true;	// mittendrin, alles selektiert?
                         // (4 und nicht 16) oder (16 und nicht 4)
                         if ( (((nEdges & 4) | 16) ^ ((nEdges & 16) | 4)) )
-                            bFound = TRUE;	// nur linke/rechte Kante, alles selektiert?
+                            bFound = true;	// nur linke/rechte Kante, alles selektiert?
                         if ( nEdges & 2 )
-                            bOpen = FALSE;	// untere Kante schliesst
+                            bOpen = false;	// untere Kante schliesst
 
                         if ( bFound )
                         {	// alles selektiert?
@@ -231,34 +232,34 @@ BOOL ScColumn::HasSelectionMatrixFragment(const ScMarkData& rMark) const
                                     aOrg.Col() + nC - 1, aOrg.Row() + nR - 1,
                                     aOrg.Tab() ) );
                                 if ( rMark.IsAllMarked( aRange ) )
-                                    bFound = FALSE;
+                                    bFound = false;
                             }
                             else
-                                bFound = FALSE;		// war schon
+                                bFound = false;		// war schon
                         }
                     }
                 }
                 nIndex++;
             }
             if ( bOpen )
-                return TRUE;
+                return true;
         }
         return bFound;
     }
     else
-        return FALSE;
+        return false;
 }
 
 
-bool ScColumn::HasAttrib( SCROW nRow1, SCROW nRow2, USHORT nMask ) const
+bool ScColumn::HasAttrib( SCROW nRow1, SCROW nRow2, sal_uInt16 nMask ) const
 {
     return pAttrArray->HasAttrib( nRow1, nRow2, nMask );
 }
 
 
-BOOL ScColumn::HasAttribSelection( const ScMarkData& rMark, USHORT nMask ) const
+bool ScColumn::HasAttribSelection( const ScMarkData& rMark, sal_uInt16 nMask ) const
 {
-    BOOL bFound = FALSE;
+    bool bFound = false;
 
     SCROW nTop;
     SCROW nBottom;
@@ -269,7 +270,7 @@ BOOL ScColumn::HasAttribSelection( const ScMarkData& rMark, USHORT nMask ) const
         while (aMarkIter.Next( nTop, nBottom ) && !bFound)
         {
             if (pAttrArray->HasAttrib( nTop, nBottom, nMask ))
-                bFound = TRUE;
+                bFound = true;
         }
     }
 
@@ -277,15 +278,15 @@ BOOL ScColumn::HasAttribSelection( const ScMarkData& rMark, USHORT nMask ) const
 }
 
 
-BOOL ScColumn::ExtendMerge( SCCOL nThisCol, SCROW nStartRow, SCROW nEndRow,
+bool ScColumn::ExtendMerge( SCCOL nThisCol, SCROW nStartRow, SCROW nEndRow,
                             SCCOL& rPaintCol, SCROW& rPaintRow,
-                            BOOL bRefresh, BOOL bAttrs )
+                            bool bRefresh, bool bAttrs )
 {
     return pAttrArray->ExtendMerge( nThisCol, nStartRow, nEndRow, rPaintCol, rPaintRow, bRefresh, bAttrs );
 }
 
 
-void ScColumn::MergeSelectionPattern( ScMergePatternState& rState, const ScMarkData& rMark, BOOL bDeep ) const
+void ScColumn::MergeSelectionPattern( ScMergePatternState& rState, const ScMarkData& rMark, bool bDeep ) const
 {
     SCROW nTop;
     SCROW nBottom;
@@ -303,7 +304,7 @@ void ScColumn::MergeSelectionPattern( ScMergePatternState& rState, const ScMarkD
 }
 
 
-void ScColumn::MergePatternArea( ScMergePatternState& rState, SCROW nRow1, SCROW nRow2, BOOL bDeep ) const
+void ScColumn::MergePatternArea( ScMergePatternState& rState, SCROW nRow1, SCROW nRow2, bool bDeep ) const
 {
     pAttrArray->MergePatternArea( nRow1, nRow2, rState, bDeep );
 }
@@ -311,14 +312,14 @@ void ScColumn::MergePatternArea( ScMergePatternState& rState, SCROW nRow1, SCROW
 
 void ScColumn::MergeBlockFrame( SvxBoxItem* pLineOuter, SvxBoxInfoItem* pLineInner,
                             ScLineFlags& rFlags,
-                            SCROW nStartRow, SCROW nEndRow, BOOL bLeft, SCCOL nDistRight ) const
+                            SCROW nStartRow, SCROW nEndRow, bool bLeft, SCCOL nDistRight ) const
 {
     pAttrArray->MergeBlockFrame( pLineOuter, pLineInner, rFlags, nStartRow, nEndRow, bLeft, nDistRight );
 }
 
 
 void ScColumn::ApplyBlockFrame( const SvxBoxItem* pLineOuter, const SvxBoxInfoItem* pLineInner,
-                            SCROW nStartRow, SCROW nEndRow, BOOL bLeft, SCCOL nDistRight )
+                            SCROW nStartRow, SCROW nEndRow, bool bLeft, SCCOL nDistRight )
 {
     pAttrArray->ApplyBlockFrame( pLineOuter, pLineInner, nStartRow, nEndRow, bLeft, nDistRight );
 }
@@ -330,7 +331,7 @@ const ScPatternAttr* ScColumn::GetPattern( SCROW nRow ) const
 }
 
 
-const SfxPoolItem* ScColumn::GetAttr( SCROW nRow, USHORT nWhich ) const
+const SfxPoolItem* ScColumn::GetAttr( SCROW nRow, sal_uInt16 nWhich ) const
 {
     return &pAttrArray->GetPattern( nRow )->GetItemSet().Get(nWhich);
 }
@@ -377,7 +378,7 @@ sal_uInt32 ScColumn::GetNumberFormat( SCROW nStartRow, SCROW nEndRow ) const
 }
 
 
-ULONG ScColumn::GetNumberFormat( SCROW nRow ) const
+sal_uInt32 ScColumn::GetNumberFormat( SCROW nRow ) const
 {
     return pAttrArray->GetPattern( nRow )->GetNumberFormat( pDocument->GetFormatTable() );
 }
@@ -387,7 +388,7 @@ SCsROW ScColumn::ApplySelectionCache( SfxItemPoolCache* pCache, const ScMarkData
 {
     SCROW nTop = 0;
     SCROW nBottom = 0;
-    BOOL bFound = FALSE;
+    bool bFound = false;
 
     if ( rMark.IsMultiMarked() )
     {
@@ -395,7 +396,7 @@ SCsROW ScColumn::ApplySelectionCache( SfxItemPoolCache* pCache, const ScMarkData
         while (aMarkIter.Next( nTop, nBottom ))
         {
             pAttrArray->ApplyCacheArea( nTop, nBottom, pCache, pDataArray );
-            bFound = TRUE;
+            bFound = true;
         }
     }
 
@@ -408,7 +409,7 @@ SCsROW ScColumn::ApplySelectionCache( SfxItemPoolCache* pCache, const ScMarkData
 }
 
 
-void ScColumn::ChangeSelectionIndent( BOOL bIncrement, const ScMarkData& rMark )
+void ScColumn::ChangeSelectionIndent( bool bIncrement, const ScMarkData& rMark )
 {
     SCROW nTop;
     SCROW nBottom;
@@ -422,7 +423,7 @@ void ScColumn::ChangeSelectionIndent( BOOL bIncrement, const ScMarkData& rMark )
 }
 
 
-void ScColumn::ClearSelectionItems( const USHORT* pWhich,const ScMarkData& rMark )
+void ScColumn::ClearSelectionItems( const sal_uInt16* pWhich,const ScMarkData& rMark )
 {
     SCROW nTop;
     SCROW nBottom;
@@ -436,7 +437,7 @@ void ScColumn::ClearSelectionItems( const USHORT* pWhich,const ScMarkData& rMark
 }
 
 
-void ScColumn::DeleteSelection( USHORT nDelFlag, const ScMarkData& rMark )
+void ScColumn::DeleteSelection( sal_uInt16 nDelFlag, const ScMarkData& rMark )
 {
     SCROW nTop;
     SCROW nBottom;
@@ -457,9 +458,9 @@ void ScColumn::ApplyPattern( SCROW nRow, const ScPatternAttr& rPatAttr )
 
     const ScPatternAttr* pPattern = pAttrArray->GetPattern( nRow );
 
-    //	TRUE = alten Eintrag behalten
+    //	true = alten Eintrag behalten
 
-    ScPatternAttr* pNewPattern = (ScPatternAttr*) &aCache.ApplyTo( *pPattern, TRUE );
+    ScPatternAttr* pNewPattern = (ScPatternAttr*) &aCache.ApplyTo( *pPattern, true );
     ScDocumentPool::CheckRef( *pPattern );
     ScDocumentPool::CheckRef( *pNewPattern );
 
@@ -493,7 +494,7 @@ void ScColumn::ApplyPatternIfNumberformatIncompatible( const ScRange& rRange,
         SCROW nRow1, nRow2;
         const ScPatternAttr* pPattern = pAttrArray->GetPatternRange(
             nRow1, nRow2, nRow );
-        ULONG nFormat = pPattern->GetNumberFormat( pFormatter );
+        sal_uInt32 nFormat = pPattern->GetNumberFormat( pFormatter );
         short nOldType = pFormatter->GetType( nFormat );
         if ( nOldType == nNewType || pFormatter->IsCompatible( nOldType, nNewType ) )
             nRow = nRow2;
@@ -515,7 +516,7 @@ void ScColumn::ApplyStyle( SCROW nRow, const ScStyleSheet& rStyle )
     if (pNewPattern)
     {
         pNewPattern->SetStyleSheet((ScStyleSheet*)&rStyle);
-        pAttrArray->SetPattern(nRow, pNewPattern, TRUE);
+        pAttrArray->SetPattern(nRow, pNewPattern, true);
         delete pNewPattern;
     }
 }
@@ -542,7 +543,7 @@ void ScColumn::ApplySelectionStyle(const ScStyleSheet& rStyle, const ScMarkData&
 
 
 void ScColumn::ApplySelectionLineStyle( const ScMarkData& rMark,
-                                    const SvxBorderLine* pLine, BOOL bColorOnly )
+                                    const SvxBorderLine* pLine, bool bColorOnly )
 {
     if ( bColorOnly && !pLine )
         return;
@@ -565,16 +566,16 @@ const ScStyleSheet* ScColumn::GetStyle( SCROW nRow ) const
 }
 
 
-const ScStyleSheet* ScColumn::GetSelectionStyle( const ScMarkData& rMark, BOOL& rFound ) const
+const ScStyleSheet* ScColumn::GetSelectionStyle( const ScMarkData& rMark, bool& rFound ) const
 {
-    rFound = FALSE;
+    rFound = false;
     if (!rMark.IsMultiMarked())
     {
-        DBG_ERROR("ScColumn::GetSelectionStyle ohne Selektion");
+        OSL_FAIL("ScColumn::GetSelectionStyle ohne Selektion");
         return NULL;
     }
 
-    BOOL bEqual = TRUE;
+    bool bEqual = true;
 
     const ScStyleSheet* pStyle = NULL;
     const ScStyleSheet* pNewStyle;
@@ -591,9 +592,9 @@ const ScStyleSheet* ScColumn::GetSelectionStyle( const ScMarkData& rMark, BOOL&
         while (bEqual && ( pPattern = aAttrIter.Next( nRow, nDummy ) ) != NULL)
         {
             pNewStyle = pPattern->GetStyleSheet();
-            rFound = TRUE;
+            rFound = true;
             if ( !pNewStyle || ( pStyle && pNewStyle != pStyle ) )
-                bEqual = FALSE;												// unterschiedliche
+                bEqual = false;												// unterschiedliche
             pStyle = pNewStyle;
         }
     }
@@ -602,11 +603,11 @@ const ScStyleSheet* ScColumn::GetSelectionStyle( const ScMarkData& rMark, BOOL&
 }
 
 
-const ScStyleSheet*	ScColumn::GetAreaStyle( BOOL& rFound, SCROW nRow1, SCROW nRow2 ) const
+const ScStyleSheet*	ScColumn::GetAreaStyle( bool& rFound, SCROW nRow1, SCROW nRow2 ) const
 {
-    rFound = FALSE;
+    rFound = false;
 
-    BOOL bEqual = TRUE;
+    bool bEqual = true;
 
     const ScStyleSheet* pStyle = NULL;
     const ScStyleSheet* pNewStyle;
@@ -618,9 +619,9 @@ const ScStyleSheet*	ScColumn::GetAreaStyle( BOOL& rFound, SCROW nRow1, SCROW nRo
     while (bEqual && ( pPattern = aAttrIter.Next( nRow, nDummy ) ) != NULL)
     {
         pNewStyle = pPattern->GetStyleSheet();
-        rFound = TRUE;
+        rFound = true;
         if ( !pNewStyle || ( pStyle && pNewStyle != pStyle ) )
-            bEqual = FALSE;												// unterschiedliche
+            bEqual = false;												// unterschiedliche
         pStyle = pNewStyle;
     }
 
@@ -632,38 +633,38 @@ void ScColumn::FindStyleSheet( const SfxStyleSheetBase* pStyleSheet, ScFlatBoolR
     pAttrArray->FindStyleSheet( pStyleSheet, rUsedRows, bReset );
 }
 
-BOOL ScColumn::IsStyleSheetUsed( const ScStyleSheet& rStyle, BOOL bGatherAllStyles ) const
+bool ScColumn::IsStyleSheetUsed( const ScStyleSheet& rStyle, bool bGatherAllStyles ) const
 {
     return pAttrArray->IsStyleSheetUsed( rStyle, bGatherAllStyles );
 }
 
 
-BOOL ScColumn::ApplyFlags( SCROW nStartRow, SCROW nEndRow, INT16 nFlags )
+bool ScColumn::ApplyFlags( SCROW nStartRow, SCROW nEndRow, sal_Int16 nFlags )
 {
     return pAttrArray->ApplyFlags( nStartRow, nEndRow, nFlags );
 }
 
 
-BOOL ScColumn::RemoveFlags( SCROW nStartRow, SCROW nEndRow, INT16 nFlags )
+bool ScColumn::RemoveFlags( SCROW nStartRow, SCROW nEndRow, sal_Int16 nFlags )
 {
     return pAttrArray->RemoveFlags( nStartRow, nEndRow, nFlags );
 }
 
 
-void ScColumn::ClearItems( SCROW nStartRow, SCROW nEndRow, const USHORT* pWhich )
+void ScColumn::ClearItems( SCROW nStartRow, SCROW nEndRow, const sal_uInt16* pWhich )
 {
     pAttrArray->ClearItems( nStartRow, nEndRow, pWhich );
 }
 
 
-void ScColumn::SetPattern( SCROW nRow, const ScPatternAttr& rPatAttr, BOOL bPutToPool )
+void ScColumn::SetPattern( SCROW nRow, const ScPatternAttr& rPatAttr, bool bPutToPool )
 {
     pAttrArray->SetPattern( nRow, &rPatAttr, bPutToPool );
 }
 
 
 void ScColumn::SetPatternArea( SCROW nStartRow, SCROW nEndRow,
-                                const ScPatternAttr& rPatAttr, BOOL bPutToPool )
+                                const ScPatternAttr& rPatAttr, bool bPutToPool )
 {
     pAttrArray->SetPatternArea( nStartRow, nEndRow, &rPatAttr, bPutToPool );
 }
@@ -696,12 +697,12 @@ void ScColumn::ApplyAttr( SCROW nRow, const SfxPoolItem& rAttr )
 #endif
 
 
-BOOL ScColumn::Search( SCROW nRow, SCSIZE& nIndex ) const
+bool ScColumn::Search( SCROW nRow, SCSIZE& nIndex ) const
 {
     if ( !pItems || !nCount )
     {
         nIndex = 0;
-        return FALSE;
+        return false;
     }
     SCROW nMinRow = pItems[0].nRow;
     if ( nRow <= nMinRow )
@@ -715,12 +716,12 @@ BOOL ScColumn::Search( SCROW nRow, SCSIZE& nIndex ) const
         if ( nRow == nMaxRow )
         {
             nIndex = nCount - 1;
-            return TRUE;
+            return true;
         }
         else
         {
             nIndex = nCount;
-            return FALSE;
+            return false;
         }
     }
 
@@ -728,9 +729,9 @@ BOOL ScColumn::Search( SCROW nRow, SCSIZE& nIndex ) const
     long	nLo 	= nOldLo = 0;
     long	nHi 	= nOldHi = Min(static_cast<long>(nCount)-1, static_cast<long>(nRow) );
     long	i		= 0;
-    BOOL	bFound	= FALSE;
+    bool	bFound	= false;
     // quite continuous distribution? => interpolating search
-    BOOL	bInterpol = (static_cast<SCSIZE>(nMaxRow - nMinRow) < nCount * 2);
+    bool	bInterpol = (static_cast<SCSIZE>(nMaxRow - nMinRow) < nCount * 2);
     SCROW	nR;
 
     while ( !bFound && nLo <= nHi )
@@ -745,7 +746,7 @@ BOOL ScColumn::Search( SCROW nRow, SCSIZE& nIndex ) const
             if ( i < 0 || static_cast<SCSIZE>(i) >= nCount )
             {	// oops ...
                 i = (nLo+nHi) / 2;
-                bInterpol = FALSE;
+                bInterpol = false;
             }
         }
         nR = pItems[i].nRow;
@@ -755,7 +756,7 @@ BOOL ScColumn::Search( SCROW nRow, SCSIZE& nIndex ) const
             if ( bInterpol )
             {
                 if ( nLo <= nOldLo )
-                    bInterpol = FALSE;
+                    bInterpol = false;
                 else
                     nOldLo = nLo;
             }
@@ -768,13 +769,13 @@ BOOL ScColumn::Search( SCROW nRow, SCSIZE& nIndex ) const
                 if ( bInterpol )
                 {
                     if ( nHi >= nOldHi )
-                        bInterpol = FALSE;
+                        bInterpol = false;
                     else
                         nOldHi = nHi;
                 }
             }
             else
-                bFound = TRUE;
+                bFound = true;
         }
     }
     if (bFound)
@@ -944,16 +945,16 @@ void ScColumn::SwapRow(SCROW nRow1, SCROW nRow2)
 
         if (pCode1->GetLen() == pCode2->GetLen())		// nicht-UPN
         {
-            BOOL bEqual = TRUE;
-            USHORT nLen = pCode1->GetLen();
+            bool bEqual = true;
+            sal_uInt16 nLen = pCode1->GetLen();
             FormulaToken** ppToken1 = pCode1->GetArray();
             FormulaToken** ppToken2 = pCode2->GetArray();
-            for (USHORT i=0; i<nLen; i++)
+            for (sal_uInt16 i=0; i<nLen; i++)
             {
                 if ( !ppToken1[i]->TextEqual(*(ppToken2[i])) ||
                         ppToken1[i]->Is3DRef() || ppToken2[i]->Is3DRef() )
                 {
-                    bEqual = FALSE;
+                    bEqual = false;
                     break;
                 }
             }
@@ -969,9 +970,6 @@ void ScColumn::SwapRow(SCROW nRow1, SCROW nRow2)
         }
     }
 
-    //	hier kein UpdateReference wegen #30529# - mitsortiert werden nur noch relative Referenzen
-//	long dy = (long)nRow2 - (long)nRow1;
-
     /*  Create clone of pCell1 at position of pCell2 (pCell1 exists always, see
         variable swapping above). Do not clone the note, but move pointer of
         old note to new cell. */
@@ -1076,11 +1074,11 @@ void ScColumn::SwapCell( SCROW nRow, ScColumn& rCol)
 }
 
 
-BOOL ScColumn::TestInsertCol( SCROW nStartRow, SCROW nEndRow) const
+bool ScColumn::TestInsertCol( SCROW nStartRow, SCROW nEndRow) const
 {
     if (!IsEmpty())
     {
-        BOOL bTest = TRUE;
+        bool bTest = true;
         if (pItems)
             for (SCSIZE i=0; (i<nCount) && bTest; i++)
                 bTest = (pItems[i].nRow < nStartRow) || (pItems[i].nRow > nEndRow)
@@ -1096,11 +1094,11 @@ BOOL ScColumn::TestInsertCol( SCROW nStartRow, SCROW nEndRow) const
         return bTest;
     }
     else
-        return TRUE;
+        return true;
 }
 
 
-BOOL ScColumn::TestInsertRow( SCSIZE nSize ) const
+bool ScColumn::TestInsertRow( SCSIZE nSize ) const
 {
     //  AttrArray only looks for merged cells
 
@@ -1126,16 +1124,16 @@ void ScColumn::InsertRow( SCROW nStartRow, SCSIZE nSize )
     if ( i >= nCount )
         return ;
 
-    BOOL bOldAutoCalc = pDocument->GetAutoCalc();
-    pDocument->SetAutoCalc( FALSE );	// Mehrfachberechnungen vermeiden
+    bool bOldAutoCalc = pDocument->GetAutoCalc();
+    pDocument->SetAutoCalc( false );	// Mehrfachberechnungen vermeiden
 
     SCSIZE nNewCount = nCount;
-    BOOL bCountChanged = FALSE;
+    bool bCountChanged = false;
     ScAddress aAdr( nCol, 0, nTab );
     ScHint aHint( SC_HINT_DATACHANGED, aAdr, NULL );    // only areas (ScBaseCell* == NULL)
     ScAddress& rAddress = aHint.GetAddress();
     // for sparse occupation use single broadcasts, not ranges
-    BOOL bSingleBroadcasts = (((pItems[nCount-1].nRow - pItems[i].nRow) /
+    bool bSingleBroadcasts = (((pItems[nCount-1].nRow - pItems[i].nRow) /
                 (nCount - i)) > 1);
     if ( bSingleBroadcasts )
     {
@@ -1143,14 +1141,14 @@ void ScColumn::InsertRow( SCROW nStartRow, SCSIZE nSize )
         for ( ; i < nCount; i++)
         {
             SCROW nOldRow = pItems[i].nRow;
-            // #43940# Aenderung Quelle broadcasten
+            // Aenderung Quelle broadcasten
             if ( nLastBroadcast != nOldRow )
             {   // direkt aufeinanderfolgende nicht doppelt broadcasten
                 rAddress.SetRow( nOldRow );
                 pDocument->AreaBroadcast( aHint );
             }
             SCROW nNewRow = (pItems[i].nRow += nSize);
-            // #43940# Aenderung Ziel broadcasten
+            // Aenderung Ziel broadcasten
             rAddress.SetRow( nNewRow );
             pDocument->AreaBroadcast( aHint );
             nLastBroadcast = nNewRow;
@@ -1160,7 +1158,7 @@ void ScColumn::InsertRow( SCROW nStartRow, SCSIZE nSize )
             if ( nNewRow > MAXROW && !bCountChanged )
             {
                 nNewCount = i;
-                bCountChanged = TRUE;
+                bCountChanged = true;
             }
         }
     }
@@ -1177,7 +1175,7 @@ void ScColumn::InsertRow( SCROW nStartRow, SCSIZE nSize )
             if ( nNewRow > MAXROW && !bCountChanged )
             {
                 nNewCount = i;
-                bCountChanged = TRUE;
+                bCountChanged = true;
                 aRange.aEnd.SetRow( MAXROW );
             }
         }
@@ -1219,7 +1217,7 @@ void ScColumn::InsertRow( SCROW nStartRow, SCSIZE nSize )
 }
 
 
-void ScColumn::CopyToClip(SCROW nRow1, SCROW nRow2, ScColumn& rColumn, BOOL bKeepScenarioFlags, BOOL bCloneNoteCaptions)
+void ScColumn::CopyToClip(SCROW nRow1, SCROW nRow2, ScColumn& rColumn, bool bKeepScenarioFlags, bool bCloneNoteCaptions)
 {
     pAttrArray->CopyArea( nRow1, nRow2, 0, *rColumn.pAttrArray,
                             bKeepScenarioFlags ? (SC_MF_ALL & ~SC_MF_SCENARIO) : SC_MF_ALL );
@@ -1263,8 +1261,8 @@ void ScColumn::CopyToClip(SCROW nRow1, SCROW nRow2, ScColumn& rColumn, BOOL bKee
 }
 
 
-void ScColumn::CopyToColumn(SCROW nRow1, SCROW nRow2, USHORT nFlags, BOOL bMarked,
-                                ScColumn& rColumn, const ScMarkData* pMarkData, BOOL bAsLink )
+void ScColumn::CopyToColumn(SCROW nRow1, SCROW nRow2, sal_uInt16 nFlags, bool bMarked,
+                                ScColumn& rColumn, const ScMarkData* pMarkData, bool bAsLink )
 {
     if (bMarked)
     {
@@ -1277,12 +1275,12 @@ void ScColumn::CopyToColumn(SCROW nRow1, SCROW nRow2, USHORT nFlags, BOOL bMarke
             {
                 if ( nEnd >= nRow1 )
                     CopyToColumn( Max(nRow1,nStart), Min(nRow2,nEnd),
-                                    nFlags, FALSE, rColumn, pMarkData, bAsLink );
+                                    nFlags, false, rColumn, pMarkData, bAsLink );
             }
         }
         else
         {
-            DBG_ERROR("CopyToColumn: bMarked, aber keine Markierung");
+            OSL_FAIL("CopyToColumn: bMarked, aber keine Markierung");
         }
         return;
     }
@@ -1299,7 +1297,7 @@ void ScColumn::CopyToColumn(SCROW nRow1, SCROW nRow2, USHORT nFlags, BOOL bMarke
                 const ScPatternAttr* pPattern = pAttrArray->GetPattern( nRow );
                 ScPatternAttr* pNewPattern = new ScPatternAttr( *pPattern );
                 pNewPattern->SetStyleSheet( (ScStyleSheet*)pStyle );
-                rColumn.pAttrArray->SetPattern( nRow, pNewPattern, TRUE );
+                rColumn.pAttrArray->SetPattern( nRow, pNewPattern, true );
                 delete pNewPattern;
             }
         }
@@ -1358,16 +1356,16 @@ void ScColumn::CopyToColumn(SCROW nRow1, SCROW nRow2, USHORT nFlags, BOOL bMarke
 }
 
 
-void ScColumn::UndoToColumn(SCROW nRow1, SCROW nRow2, USHORT nFlags, BOOL bMarked,
+void ScColumn::UndoToColumn(SCROW nRow1, SCROW nRow2, sal_uInt16 nFlags, bool bMarked,
                                 ScColumn& rColumn, const ScMarkData* pMarkData )
 {
     if (nRow1 > 0)
-        CopyToColumn( 0, nRow1-1, IDF_FORMULA, FALSE, rColumn );
+        CopyToColumn( 0, nRow1-1, IDF_FORMULA, false, rColumn );
 
     CopyToColumn( nRow1, nRow2, nFlags, bMarked, rColumn, pMarkData );		//! bMarked ????
 
     if (nRow2 < MAXROW)
-        CopyToColumn( nRow2+1, MAXROW, IDF_FORMULA, FALSE, rColumn );
+        CopyToColumn( nRow2+1, MAXROW, IDF_FORMULA, false, rColumn );
 }
 
 
@@ -1390,8 +1388,6 @@ void ScColumn::CopyUpdated( const ScColumn& rPosCol, ScColumn& rDestCol ) const
         }
     }
 
-    //	Dummy:
-    //	CopyToColumn( 0,MAXROW, IDF_FORMULA, FALSE, rDestCol, NULL, FALSE );
 }
 
 
@@ -1408,7 +1404,7 @@ void ScColumn::CopyScenarioFrom( const ScColumn& rSrcCol )
         {
             DeleteArea( nStart, nEnd, IDF_CONTENTS );
             ((ScColumn&)rSrcCol).
-                CopyToColumn( nStart, nEnd, IDF_CONTENTS, FALSE, *this );
+                CopyToColumn( nStart, nEnd, IDF_CONTENTS, false, *this );
 
             //	UpdateUsed nicht noetig, schon in TestCopyScenario passiert
 
@@ -1439,7 +1435,7 @@ void ScColumn::CopyScenarioTo( ScColumn& rDestCol ) const
         {
             rDestCol.DeleteArea( nStart, nEnd, IDF_CONTENTS );
             ((ScColumn*)this)->
-                CopyToColumn( nStart, nEnd, IDF_CONTENTS, FALSE, rDestCol );
+                CopyToColumn( nStart, nEnd, IDF_CONTENTS, false, rDestCol );
 
             //	UpdateUsed nicht noetig, schon in TestCopyScenario passiert
 
@@ -1457,9 +1453,9 @@ void ScColumn::CopyScenarioTo( ScColumn& rDestCol ) const
 }
 
 
-BOOL ScColumn::TestCopyScenarioTo( const ScColumn& rDestCol ) const
+bool ScColumn::TestCopyScenarioTo( const ScColumn& rDestCol ) const
 {
-    BOOL bOk = TRUE;
+    bool bOk = true;
     ScAttrIterator aAttrIter( pAttrArray, 0, MAXROW );
     SCROW nStart = 0, nEnd = 0;
     const ScPatternAttr* pPattern = aAttrIter.Next( nStart, nEnd );
@@ -1467,7 +1463,7 @@ BOOL ScColumn::TestCopyScenarioTo( const ScColumn& rDestCol ) const
     {
         if ( ((ScMergeFlagAttr&)pPattern->GetItem( ATTR_MERGE_FLAG )).IsScenario() )
             if ( rDestCol.pAttrArray->HasAttrib( nStart, nEnd, HASATTR_PROTECTED ) )
-                bOk = FALSE;
+                bOk = false;
 
         pPattern = aAttrIter.Next( nStart, nEnd );
     }
@@ -1488,7 +1484,7 @@ void ScColumn::MarkScenarioIn( ScMarkData& rDestMark ) const
         {
             aRange.aStart.SetRow( nStart );
             aRange.aEnd.SetRow( nEnd );
-            rDestMark.SetMultiMarkArea( aRange, TRUE );
+            rDestMark.SetMultiMarkArea( aRange, true );
         }
 
         pPattern = aAttrIter.Next( nStart, nEnd );
@@ -1516,7 +1512,7 @@ void ScColumn::SwapCol(ScColumn& rCol)
     rCol.pAttrArray = pAttrArray;
     pAttrArray = pTempAttr;
 
-    // #38415# AttrArray muss richtige Spaltennummer haben
+    // AttrArray muss richtige Spaltennummer haben
     pAttrArray->SetCol(nCol);
     rCol.pAttrArray->SetCol(rCol.nCol);
 
@@ -1597,7 +1593,7 @@ void ScColumn::MoveTo(SCROW nStartRow, SCROW nEndRow, ScColumn& rCol)
             ScAddress& rAddress = aHint.GetAddress();
             ScNoteCell* pNoteCell = new ScNoteCell;		// Dummy like in DeleteRange
 
-            // #121990# must iterate backwards, because indexes of following cells become invalid
+            // must iterate backwards, because indexes of following cells become invalid
             for (EntryPosPairs::reverse_iterator it( aEntries.rbegin());
                     it != aEntries.rend(); ++it)
             {
@@ -1644,7 +1640,7 @@ bool ScColumn::UpdateReference( UpdateRefMode eUpdateRefMode, SCCOL nCol1, SCROW
         }
         else
         {
-            // #90279# For performance reasons two loop bodies instead of
+            // For performance reasons two loop bodies instead of
             // testing for update mode in each iteration.
             // Anyways, this is still a bottleneck on large arrays with few
             // formulas cells.
@@ -1770,7 +1766,7 @@ void ScColumn::UpdateInsertTabAbs(SCTAB nTable)
 }
 
 
-void ScColumn::UpdateDeleteTab( SCTAB nTable, BOOL bIsMove, ScColumn* pRefUndo )
+void ScColumn::UpdateDeleteTab( SCTAB nTable, bool bIsMove, ScColumn* pRefUndo )
 {
     if (nTab > nTable)
         pAttrArray->SetTab(--nTab);
@@ -1786,7 +1782,7 @@ void ScColumn::UpdateDeleteTab( SCTAB nTable, BOOL bIsMove, ScColumn* pRefUndo )
                     back the formula cell while keeping the original note. */
                 ScBaseCell* pSave = pRefUndo ? pOld->CloneWithoutNote( *pDocument ) : 0;
 
-                BOOL bChanged = pOld->UpdateDeleteTab(nTable, bIsMove);
+                bool bChanged = pOld->UpdateDeleteTab(nTable, bIsMove);
                 if ( nRow != pItems[i].nRow )
                     Search( nRow, i );		// Listener geloescht/eingefuegt?
 
@@ -1820,7 +1816,7 @@ void ScColumn::UpdateMoveTab( SCTAB nOldPos, SCTAB nNewPos, SCTAB nTabNo )
 }
 
 
-void ScColumn::UpdateCompile( BOOL bForceIfNameInUse )
+void ScColumn::UpdateCompile( bool bForceIfNameInUse )
 {
     if (pItems)
         for (SCSIZE i = 0; i < nCount; i++)
@@ -1851,9 +1847,9 @@ void ScColumn::SetTabNo(SCTAB nNewTab)
 }
 
 
-BOOL ScColumn::IsRangeNameInUse(SCROW nRow1, SCROW nRow2, USHORT nIndex) const
+bool ScColumn::IsRangeNameInUse(SCROW nRow1, SCROW nRow2, sal_uInt16 nIndex) const
 {
-    BOOL bInUse = FALSE;
+    bool bInUse = false;
     if (pItems)
         for (SCSIZE i = 0; !bInUse && (i < nCount); i++)
             if ((pItems[i].nRow >= nRow1) &&
@@ -1863,7 +1859,7 @@ BOOL ScColumn::IsRangeNameInUse(SCROW nRow1, SCROW nRow2, USHORT nIndex) const
     return bInUse;
 }
 
-void ScColumn::FindRangeNamesInUse(SCROW nRow1, SCROW nRow2, std::set<USHORT>& rIndexes) const
+void ScColumn::FindRangeNamesInUse(SCROW nRow1, SCROW nRow2, std::set<sal_uInt16>& rIndexes) const
 {
     if (pItems)
         for (SCSIZE i = 0; i < nCount; i++)
@@ -1905,8 +1901,8 @@ void ScColumn::SetDirtyVar()
 void ScColumn::SetDirty()
 {
     // wird nur dokumentweit verwendet, kein FormulaTrack
-    BOOL bOldAutoCalc = pDocument->GetAutoCalc();
-    pDocument->SetAutoCalc( FALSE );	// Mehrfachberechnungen vermeiden
+    bool bOldAutoCalc = pDocument->GetAutoCalc();
+    pDocument->SetAutoCalc( false );	// Mehrfachberechnungen vermeiden
     for (SCSIZE i=0; i<nCount; i++)
     {
         ScFormulaCell* p = (ScFormulaCell*) pItems[i].pCell;
@@ -1925,8 +1921,8 @@ void ScColumn::SetDirty( const ScRange& rRange )
 {	// broadcastet alles innerhalb eines Range, mit FormulaTrack
     if ( !pItems || !nCount )
         return ;
-    BOOL bOldAutoCalc = pDocument->GetAutoCalc();
-    pDocument->SetAutoCalc( FALSE );	// Mehrfachberechnungen vermeiden
+    bool bOldAutoCalc = pDocument->GetAutoCalc();
+    pDocument->SetAutoCalc( false );	// Mehrfachberechnungen vermeiden
     SCROW nRow2 = rRange.aEnd.Row();
     ScAddress aPos( nCol, 0, nTab );
     ScHint aHint( SC_HINT_DATACHANGED, aPos, NULL );
@@ -1954,8 +1950,8 @@ void ScColumn::SetTableOpDirty( const ScRange& rRange )
 {
     if ( !pItems || !nCount )
         return ;
-    BOOL bOldAutoCalc = pDocument->GetAutoCalc();
-    pDocument->SetAutoCalc( FALSE );	// no multiple recalculation
+    bool bOldAutoCalc = pDocument->GetAutoCalc();
+    pDocument->SetAutoCalc( false );	// no multiple recalculation
     SCROW nRow2 = rRange.aEnd.Row();
     ScAddress aPos( nCol, 0, nTab );
     ScHint aHint( SC_HINT_TABLEOPDIRTY, aPos, NULL );
@@ -1981,8 +1977,8 @@ void ScColumn::SetTableOpDirty( const ScRange& rRange )
 
 void ScColumn::SetDirtyAfterLoad()
 {
-    BOOL bOldAutoCalc = pDocument->GetAutoCalc();
-    pDocument->SetAutoCalc( FALSE );	// Mehrfachberechnungen vermeiden
+    bool bOldAutoCalc = pDocument->GetAutoCalc();
+    pDocument->SetAutoCalc( false );	// Mehrfachberechnungen vermeiden
     for (SCSIZE i=0; i<nCount; i++)
     {
         ScFormulaCell* p = (ScFormulaCell*) pItems[i].pCell;
@@ -2014,8 +2010,8 @@ void ScColumn::SetDirtyAfterLoad()
 
 void ScColumn::SetRelNameDirty()
 {
-    BOOL bOldAutoCalc = pDocument->GetAutoCalc();
-    pDocument->SetAutoCalc( FALSE );	// Mehrfachberechnungen vermeiden
+    bool bOldAutoCalc = pDocument->GetAutoCalc();
+    pDocument->SetAutoCalc( false );	// Mehrfachberechnungen vermeiden
     for (SCSIZE i=0; i<nCount; i++)
     {
         ScFormulaCell* p = (ScFormulaCell*) pItems[i].pCell;
@@ -2063,9 +2059,9 @@ void ScColumn::CompileAll()
             {
                 SCROW nRow = pItems[i].nRow;
                 // fuer unbedingtes kompilieren
-                // bCompile=TRUE und pCode->nError=0
+                // bCompile=true und pCode->nError=0
                 ((ScFormulaCell*)pCell)->GetCode()->SetCodeError( 0 );
-                ((ScFormulaCell*)pCell)->SetCompile( TRUE );
+                ((ScFormulaCell*)pCell)->SetCompile( true );
                 ((ScFormulaCell*)pCell)->CompileTokenArray();
                 if ( nRow != pItems[i].nRow )
                     Search( nRow, i );		// Listener geloescht/eingefuegt?
@@ -2120,14 +2116,14 @@ void ScColumn::ResetChanged( SCROW nStartRow, SCROW nEndRow )
 }
 
 
-BOOL ScColumn::HasEditCells(SCROW nStartRow, SCROW nEndRow, SCROW& rFirst) const
+bool ScColumn::HasEditCells(SCROW nStartRow, SCROW nEndRow, SCROW& rFirst) const
 {
     //	used in GetOptimalHeight - ambiguous script type counts as edit cell
 
     SCROW nRow = 0;
     SCSIZE nIndex;
     Search(nStartRow,nIndex);
-    while ( (nIndex < nCount) ? ((nRow=pItems[nIndex].nRow) <= nEndRow) : FALSE )
+    while ( (nIndex < nCount) ? ((nRow=pItems[nIndex].nRow) <= nEndRow) : false )
     {
         ScBaseCell* pCell = pItems[nIndex].pCell;
         CellType eCellType = pCell->GetCellType();
@@ -2136,17 +2132,17 @@ BOOL ScColumn::HasEditCells(SCROW nStartRow, SCROW nEndRow, SCROW& rFirst) const
              ((eCellType == CELLTYPE_FORMULA) && ((ScFormulaCell*)pCell)->IsMultilineResult()) )
         {
             rFirst = nRow;
-            return TRUE;
+            return true;
         }
         ++nIndex;
     }
 
-    return FALSE;
+    return false;
 }
 
 
 SCsROW ScColumn::SearchStyle( SCsROW nRow, const ScStyleSheet* pSearchStyle,
-                                BOOL bUp, BOOL bInSelection, const ScMarkData& rMark )
+                                bool bUp, bool bInSelection, const ScMarkData& rMark )
 {
     if (bInSelection)
     {
@@ -2161,8 +2157,8 @@ SCsROW ScColumn::SearchStyle( SCsROW nRow, const ScStyleSheet* pSearchStyle,
 }
 
 
-BOOL ScColumn::SearchStyleRange( SCsROW& rRow, SCsROW& rEndRow, const ScStyleSheet* pSearchStyle,
-                                    BOOL bUp, BOOL bInSelection, const ScMarkData& rMark )
+bool ScColumn::SearchStyleRange( SCsROW& rRow, SCsROW& rEndRow, const ScStyleSheet* pSearchStyle,
+                                    bool bUp, bool bInSelection, const ScMarkData& rMark )
 {
     if (bInSelection)
     {
@@ -2170,7 +2166,7 @@ BOOL ScColumn::SearchStyleRange( SCsROW& rRow, SCsROW& rEndRow, const ScStyleShe
             return pAttrArray->SearchStyleRange( rRow, rEndRow, pSearchStyle, bUp,
                                     (ScMarkArray*) rMark.GetArray()+nCol );		//! const
         else
-            return FALSE;
+            return false;
     }
     else
         return pAttrArray->SearchStyleRange( rRow, rEndRow, pSearchStyle, bUp, NULL );
