@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -49,7 +49,6 @@
 #include <comphelper/processfactory.hxx>
 #include <svl/PasswordHelper.hxx>
 #include <tools/tenccvt.hxx>
-#include <tools/list.hxx>
 #include <rtl/crc.h>
 #include <basic/basmgr.hxx>
 
@@ -140,6 +139,7 @@ ScDocument::ScDocument( ScDocumentMode	eMode,
         pCondFormList( NULL ),
         pValidationList( NULL ),
         pFormatExchangeList( NULL ),
+        pRangeName(NULL),
         pDPCollection( NULL ),
         pLinkManager( NULL ),
         pFormulaTree( NULL ),
@@ -170,6 +170,7 @@ ScDocument::ScDocument( ScDocumentMode	eMode,
         nUnoObjectId( 0 ),
         nRangeOverflowType( 0 ),
         aCurTextWidthCalcPos(MAXCOL,0,0),
+        aTableOpList( 0 ),
         nFormulaCodeInTree(0),
         nXMLImportedFormulaCount( 0 ),
         nInterpretLevel(0),
@@ -183,40 +184,39 @@ ScDocument::ScDocument( ScDocumentMode	eMode,
         nVisibleTab( 0 ),
         eLinkMode(LM_UNKNOWN),
         bAutoCalc( eMode == SCDOCMODE_DOCUMENT ),
-        bAutoCalcShellDisabled( FALSE ),
-        bForcedFormulaPending( FALSE ),
-        bCalculatingFormulaTree( FALSE ),
+        bAutoCalcShellDisabled( false ),
+        bForcedFormulaPending( false ),
+        bCalculatingFormulaTree( false ),
         bIsClip( eMode == SCDOCMODE_CLIP ),
         bIsUndo( eMode == SCDOCMODE_UNDO ),
-        bIsVisible( FALSE ),
-        bIsEmbedded( FALSE ),
-//		bNoSetDirty( TRUE ),
-        bNoSetDirty( FALSE ),
-        bInsertingFromOtherDoc( FALSE ),
+        bIsVisible( false ),
+        bIsEmbedded( false ),
+        bNoSetDirty( false ),
+        bInsertingFromOtherDoc( false ),
         bLoadingMedium( false ),
         bImportingXML( false ),
-        bXMLFromWrapper( FALSE ),
-        bCalcingAfterLoad( FALSE ),
-        bNoListening( FALSE ),
-        bIdleDisabled( FALSE ),
-        bInLinkUpdate( FALSE ),
-        bChartListenerCollectionNeedsUpdate( FALSE ),
-        bHasForcedFormulas( FALSE ),
-        bInDtorClear( FALSE ),
-        bExpandRefs( FALSE ),
-        bDetectiveDirty( FALSE ),
+        bXMLFromWrapper( false ),
+        bCalcingAfterLoad( false ),
+        bNoListening( false ),
+        bIdleDisabled( false ),
+        bInLinkUpdate( false ),
+        bChartListenerCollectionNeedsUpdate( false ),
+        bHasForcedFormulas( false ),
+        bInDtorClear( false ),
+        bExpandRefs( false ),
+        bDetectiveDirty( false ),
         nMacroCallMode( SC_MACROCALL_ALLOWED ),
-        bHasMacroFunc( FALSE ),
+        bHasMacroFunc( false ),
         nVisSpellState( 0 ),
         nAsianCompression(SC_ASIANCOMPRESSION_INVALID),
         nAsianKerning(SC_ASIANKERNING_INVALID),
-        bSetDrawDefaults( FALSE ),
-        bPastingDrawFromOtherDoc( FALSE ),
+        bSetDrawDefaults( false ),
+        bPastingDrawFromOtherDoc( false ),
         nInDdeLinkUpdate( 0 ),
-        bInUnoBroadcast( FALSE ),
-        bInUnoListenerCall( FALSE ),
+        bInUnoBroadcast( false ),
+        bInUnoListenerCall( false ),
         eGrammar( formula::FormulaGrammar::GRAM_NATIVE ),
-        bStyleSheetUsageInvalid( TRUE ),
+        bStyleSheetUsageInvalid( sal_True ),
         mbUndoEnabled( true ),
         mbAdjustHeightEnabled( true ),
         mbExecuteLinkEnabled( true ),
@@ -251,8 +251,7 @@ ScDocument::ScDocument( ScDocumentMode	eMode,
     for (SCTAB i=1; i<=MAXTAB; i++)
         pTab[i] = NULL;
 
-    pRangeName = new ScRangeName( 4, 4, FALSE, this );
-    pDBCollection = new ScDBCollection( 4, 4, FALSE, this );
+    pDBCollection = new ScDBCollection( 4, 4, false, this );
     pSelectionAttr = NULL;
     pChartCollection = new ScChartCollection;
     apTemporaryChartLock = std::auto_ptr< ScTemporaryChartLock >( new ScTemporaryChartLock(this) );
@@ -267,12 +266,12 @@ ScDocument::ScDocument( ScDocumentMode	eMode,
 }
 
 sfx2::LinkManager*	ScDocument::GetLinkManager()  const
-{ 
+{
     if ( bAutoCalc && !pLinkManager && pShell)
     {
         pLinkManager = new sfx2::LinkManager( pShell );
     }
-    return pLinkManager; 
+    return pLinkManager;
 }
 
 
@@ -294,7 +293,7 @@ void ScDocument::SetStorageGrammar( formula::FormulaGrammar::Grammar eGram )
 }
 
 
-void ScDocument::SetDocVisible( BOOL bSet )
+void ScDocument::SetDocVisible( sal_Bool bSet )
 {
     //	called from view ctor - only for a visible document,
     //	each new sheet's RTL flag is initialized from the locale
@@ -350,7 +349,7 @@ IMPL_LINK( ScDocument, TrackTimeHdl, Timer*, EMPTYARG )
 
         if (!pShell->IsModified())
         {
-            pShell->SetModified( TRUE );
+            pShell->SetModified( sal_True );
             SfxBindings* pBindings = GetViewBindings();
             if (pBindings)
             {
@@ -373,7 +372,7 @@ ScDocument::~ScDocument()
 {
     DBG_ASSERT( !bInLinkUpdate, "bInLinkUpdate in dtor" );
 
-    bInDtorClear = TRUE;
+    bInDtorClear = sal_True;
 
     // first of all disable all refresh timers by deleting the control
     if ( pRefreshTimerControl )
@@ -388,7 +387,7 @@ ScDocument::~ScDocument()
     if ( GetLinkManager() )
     {
         // BaseLinks freigeben
-        for ( USHORT n = pLinkManager->GetServers().Count(); n; )
+        for ( sal_uInt16 n = pLinkManager->GetServers().Count(); n; )
             pLinkManager->GetServers()[ --n ]->Closed();
 
         if ( pLinkManager->GetLinks().Count() )
@@ -418,7 +417,7 @@ ScDocument::~ScDocument()
     delete pUnoRefUndoList;
     delete pUnoListenerCalls;
 
-    Clear( sal_True );              // TRUE = from destructor (needed for SdrModel::ClearModel)
+    Clear( sal_True );              // sal_True = from destructor (needed for SdrModel::ClearModel)
 
     if (pCondFormList)
     {
@@ -531,8 +530,8 @@ ScFieldEditEngine& ScDocument::GetEditEngine()
     if ( !pEditEngine )
     {
         pEditEngine = new ScFieldEditEngine( GetEnginePool(), GetEditPool() );
-        pEditEngine->SetUpdateMode( FALSE );
-        pEditEngine->EnableUndo( FALSE );
+        pEditEngine->SetUpdateMode( false );
+        pEditEngine->EnableUndo( false );
         pEditEngine->SetRefMapMode( MAP_100TH_MM );
         pEditEngine->SetForbiddenCharsTable( xForbiddenCharacters );
     }
@@ -544,8 +543,8 @@ ScNoteEditEngine& ScDocument::GetNoteEngine()
     if ( !pNoteEngine )
     {
         pNoteEngine = new ScNoteEditEngine( GetEnginePool(), GetEditPool() );
-        pNoteEngine->SetUpdateMode( FALSE );
-        pNoteEngine->EnableUndo( FALSE );
+        pNoteEngine->SetUpdateMode( false );
+        pNoteEngine->EnableUndo( false );
         pNoteEngine->SetRefMapMode( MAP_100TH_MM );
         pNoteEngine->SetForbiddenCharsTable( xForbiddenCharacters );
                 const SfxItemSet& rItemSet = GetDefPattern()->GetItemSet();
@@ -576,7 +575,7 @@ void ScDocument::ResetClip( ScDocument* pSourceDoc, const ScMarkData* pMarks )
     }
     else
     {
-        DBG_ERROR("ResetClip");
+        OSL_FAIL("ResetClip");
     }
 }
 
@@ -594,26 +593,26 @@ void ScDocument::ResetClip( ScDocument* pSourceDoc, SCTAB nTab )
     }
     else
     {
-        DBG_ERROR("ResetClip");
+        OSL_FAIL("ResetClip");
     }
 }
 
 void ScDocument::DeleteNumberFormat( const sal_uInt32* /* pDelKeys */, sal_uInt32 /* nCount */ )
 {
 /*
-    for (ULONG i = 0; i < nCount; i++)
+    for (sal_uLong i = 0; i < nCount; i++)
         xPoolHelper->GetFormTable()->DeleteEntry(pDelKeys[i]);
 */
 }
 
 void ScDocument::PutCell( SCCOL nCol, SCROW nRow, SCTAB nTab,
-                          ScBaseCell* pCell, ULONG nFormatIndex, BOOL bForceTab )
+                          ScBaseCell* pCell, sal_uLong nFormatIndex, sal_Bool bForceTab )
 {
     if (VALIDTAB(nTab))
     {
         if ( bForceTab && !pTab[nTab] )
         {
-            BOOL bExtras = !bIsUndo;		// Spaltenbreiten, Zeilenhoehen, Flags
+            sal_Bool bExtras = !bIsUndo;		// Spaltenbreiten, Zeilenhoehen, Flags
 
             pTab[nTab] = new ScTable(this, nTab,
                                 String::CreateFromAscii(RTL_CONSTASCII_STRINGPARAM("temp")),
@@ -626,20 +625,20 @@ void ScDocument::PutCell( SCCOL nCol, SCROW nRow, SCTAB nTab,
 }
 
 
-BOOL ScDocument::GetPrintArea( SCTAB nTab, SCCOL& rEndCol, SCROW& rEndRow,
-                                BOOL bNotes ) const
+sal_Bool ScDocument::GetPrintArea( SCTAB nTab, SCCOL& rEndCol, SCROW& rEndRow,
+                                sal_Bool bNotes ) const
 {
     if (ValidTab(nTab) && pTab[nTab])
     {
-        BOOL bAny = pTab[nTab]->GetPrintArea( rEndCol, rEndRow, bNotes );
+        sal_Bool bAny = pTab[nTab]->GetPrintArea( rEndCol, rEndRow, bNotes );
         if (pDrawLayer)
         {
             ScRange aDrawRange(0,0,nTab, MAXCOL,MAXROW,nTab);
-            if (DrawGetPrintArea( aDrawRange, TRUE, TRUE ))
+            if (DrawGetPrintArea( aDrawRange, sal_True, sal_True ))
             {
                 if (aDrawRange.aEnd.Col()>rEndCol) rEndCol=aDrawRange.aEnd.Col();
                 if (aDrawRange.aEnd.Row()>rEndRow) rEndRow=aDrawRange.aEnd.Row();
-                bAny = TRUE;
+                bAny = sal_True;
             }
         }
         return bAny;
@@ -647,66 +646,66 @@ BOOL ScDocument::GetPrintArea( SCTAB nTab, SCCOL& rEndCol, SCROW& rEndRow,
 
     rEndCol = 0;
     rEndRow = 0;
-    return FALSE;
+    return false;
 }
 
-BOOL ScDocument::GetPrintAreaHor( SCTAB nTab, SCROW nStartRow, SCROW nEndRow,
-                                        SCCOL& rEndCol, BOOL bNotes ) const
+sal_Bool ScDocument::GetPrintAreaHor( SCTAB nTab, SCROW nStartRow, SCROW nEndRow,
+                                        SCCOL& rEndCol, sal_Bool bNotes ) const
 {
     if (ValidTab(nTab) && pTab[nTab])
     {
-        BOOL bAny = pTab[nTab]->GetPrintAreaHor( nStartRow, nEndRow, rEndCol, bNotes );
+        sal_Bool bAny = pTab[nTab]->GetPrintAreaHor( nStartRow, nEndRow, rEndCol, bNotes );
         if (pDrawLayer)
         {
             ScRange aDrawRange(0,nStartRow,nTab, MAXCOL,nEndRow,nTab);
-            if (DrawGetPrintArea( aDrawRange, TRUE, FALSE ))
+            if (DrawGetPrintArea( aDrawRange, sal_True, false ))
             {
                 if (aDrawRange.aEnd.Col()>rEndCol) rEndCol=aDrawRange.aEnd.Col();
-                bAny = TRUE;
+                bAny = sal_True;
             }
         }
         return bAny;
     }
 
     rEndCol = 0;
-    return FALSE;
+    return false;
 }
 
-BOOL ScDocument::GetPrintAreaVer( SCTAB nTab, SCCOL nStartCol, SCCOL nEndCol,
-                                        SCROW& rEndRow, BOOL bNotes ) const
+sal_Bool ScDocument::GetPrintAreaVer( SCTAB nTab, SCCOL nStartCol, SCCOL nEndCol,
+                                        SCROW& rEndRow, sal_Bool bNotes ) const
 {
     if (ValidTab(nTab) && pTab[nTab])
     {
-        BOOL bAny = pTab[nTab]->GetPrintAreaVer( nStartCol, nEndCol, rEndRow, bNotes );
+        sal_Bool bAny = pTab[nTab]->GetPrintAreaVer( nStartCol, nEndCol, rEndRow, bNotes );
         if (pDrawLayer)
         {
             ScRange aDrawRange(nStartCol,0,nTab, nEndCol,MAXROW,nTab);
-            if (DrawGetPrintArea( aDrawRange, FALSE, TRUE ))
+            if (DrawGetPrintArea( aDrawRange, false, sal_True ))
             {
                 if (aDrawRange.aEnd.Row()>rEndRow) rEndRow=aDrawRange.aEnd.Row();
-                bAny = TRUE;
+                bAny = sal_True;
             }
         }
         return bAny;
     }
 
     rEndRow = 0;
-    return FALSE;
+    return false;
 }
 
-BOOL ScDocument::GetDataStart( SCTAB nTab, SCCOL& rStartCol, SCROW& rStartRow ) const
+sal_Bool ScDocument::GetDataStart( SCTAB nTab, SCCOL& rStartCol, SCROW& rStartRow ) const
 {
     if (ValidTab(nTab) && pTab[nTab])
     {
-        BOOL bAny = pTab[nTab]->GetDataStart( rStartCol, rStartRow );
+        sal_Bool bAny = pTab[nTab]->GetDataStart( rStartCol, rStartRow );
         if (pDrawLayer)
         {
             ScRange aDrawRange(0,0,nTab, MAXCOL,MAXROW,nTab);
-            if (DrawGetPrintArea( aDrawRange, TRUE, TRUE ))
+            if (DrawGetPrintArea( aDrawRange, sal_True, sal_True ))
             {
                 if (aDrawRange.aStart.Col()<rStartCol) rStartCol=aDrawRange.aStart.Col();
                 if (aDrawRange.aStart.Row()<rStartRow) rStartRow=aDrawRange.aStart.Row();
-                bAny = TRUE;
+                bAny = sal_True;
             }
         }
         return bAny;
@@ -714,13 +713,13 @@ BOOL ScDocument::GetDataStart( SCTAB nTab, SCCOL& rStartCol, SCROW& rStartRow )
 
     rStartCol = 0;
     rStartRow = 0;
-    return FALSE;
+    return false;
 }
 
-BOOL ScDocument::MoveTab( SCTAB nOldPos, SCTAB nNewPos )
+sal_Bool ScDocument::MoveTab( SCTAB nOldPos, SCTAB nNewPos )
 {
-    if (nOldPos == nNewPos) return FALSE;
-    BOOL bValid = FALSE;
+    if (nOldPos == nNewPos) return false;
+    sal_Bool bValid = false;
     if (VALIDTAB(nOldPos))
     {
         if (pTab[nOldPos])
@@ -728,9 +727,9 @@ BOOL ScDocument::MoveTab( SCTAB nOldPos, SCTAB nNewPos )
             SCTAB nTabCount = GetTableCount();
             if (nTabCount > 1)
             {
-                BOOL bOldAutoCalc = GetAutoCalc();
-                SetAutoCalc( FALSE );	// Mehrfachberechnungen vermeiden
-                SetNoListening( TRUE );
+                sal_Bool bOldAutoCalc = GetAutoCalc();
+                SetAutoCalc( false );	// Mehrfachberechnungen vermeiden
+                SetNoListening( sal_True );
                 ScProgress* pProgress = new ScProgress( GetDocumentShell(),
                     ScGlobal::GetRscString(STR_UNDO_MOVE_TAB), GetCodeCount() );
                 if (nNewPos == SC_TAB_APPEND)
@@ -741,7 +740,8 @@ BOOL ScDocument::MoveTab( SCTAB nOldPos, SCTAB nNewPos )
 
                 SCsTAB nDz = ((SCsTAB)nNewPos) - (SCsTAB)nOldPos;
                 ScRange aSourceRange( 0,0,nOldPos, MAXCOL,MAXROW,nOldPos );
-                pRangeName->UpdateTabRef(nOldPos, 3, nNewPos);
+                if (pRangeName)
+                    pRangeName->UpdateTabRef(nOldPos, 3, nNewPos);
                 pDBCollection->UpdateMoveTab( nOldPos, nNewPos );
                 xColNameRanges->UpdateReference( URM_REORDER, this, aSourceRange, 0,0,nDz );
                 xRowNameRanges->UpdateReference( URM_REORDER, this, aSourceRange, 0,0,nDz );
@@ -775,11 +775,11 @@ BOOL ScDocument::MoveTab( SCTAB nOldPos, SCTAB nNewPos )
                 for (i = 0; i <= MAXTAB; i++)
                     if (pTab[i])
                         pTab[i]->UpdateCompile();
-                SetNoListening( FALSE );
+                SetNoListening( false );
                 for (i = 0; i <= MAXTAB; i++)
                     if (pTab[i])
                         pTab[i]->StartAllListeners();
-                // #81844# sheet names of references may not be valid until sheet is moved
+                // sheet names of references may not be valid until sheet is moved
                 pChartListenerCollection->UpdateScheduledSeriesRanges();
                 SetDirty();
                 SetAutoCalc( bOldAutoCalc );
@@ -787,14 +787,14 @@ BOOL ScDocument::MoveTab( SCTAB nOldPos, SCTAB nNewPos )
                 if (pDrawLayer)
                     DrawMovePage( static_cast<sal_uInt16>(nOldPos), static_cast<sal_uInt16>(nNewPos) );
 
-                bValid = TRUE;
+                bValid = sal_True;
             }
         }
     }
     return bValid;
 }
 
-BOOL ScDocument::CopyTab( SCTAB nOldPos, SCTAB nNewPos, const ScMarkData* pOnlyMarked )
+sal_Bool ScDocument::CopyTab( SCTAB nOldPos, SCTAB nNewPos, const ScMarkData* pOnlyMarked )
 {
     if (SC_TAB_APPEND == nNewPos ) nNewPos = nMaxTableNumber;
     String aName;
@@ -802,20 +802,20 @@ BOOL ScDocument::CopyTab( SCTAB nOldPos, SCTAB nNewPos, const ScMarkData* pOnlyM
 
     //	vorneweg testen, ob der Prefix als gueltig erkannt wird
     //	wenn nicht, nur doppelte vermeiden
-    BOOL bPrefix = ValidTabName( aName );
+    sal_Bool bPrefix = ValidTabName( aName );
     DBG_ASSERT(bPrefix, "ungueltiger Tabellenname");
     SCTAB nDummy;
 
     CreateValidTabName(aName);
 
-    BOOL bValid;
+    sal_Bool bValid;
     if (bPrefix)
         bValid = ( ValidNewTabName(aName) && (nMaxTableNumber <= MAXTAB) );
     else
         bValid = ( !GetTable( aName, nDummy ) && (nMaxTableNumber <= MAXTAB) );
 
-    BOOL bOldAutoCalc = GetAutoCalc();
-    SetAutoCalc( FALSE );	// Mehrfachberechnungen vermeiden
+    sal_Bool bOldAutoCalc = GetAutoCalc();
+    SetAutoCalc( false );	// Mehrfachberechnungen vermeiden
     if (bValid)
     {
         if (nNewPos == nMaxTableNumber)
@@ -827,12 +827,13 @@ BOOL ScDocument::CopyTab( SCTAB nOldPos, SCTAB nNewPos, const ScMarkData* pOnlyM
         {
             if (VALIDTAB(nNewPos) && (nNewPos < nMaxTableNumber))
             {
-                SetNoListening( TRUE );
+                SetNoListening( sal_True );
 
                 ScRange aRange( 0,0,nNewPos, MAXCOL,MAXROW,MAXTAB );
                 xColNameRanges->UpdateReference( URM_INSDEL, this, aRange, 0,0,1 );
                 xRowNameRanges->UpdateReference( URM_INSDEL, this, aRange, 0,0,1 );
-                pRangeName->UpdateTabRef(nNewPos, 1);
+                if (pRangeName)
+                    pRangeName->UpdateTabRef(nNewPos, 1);
                 pDBCollection->UpdateReference(
                                     URM_INSDEL, 0,0,nNewPos, MAXCOL,MAXROW,MAXTAB, 0,0,1 );
                 if (pDPCollection)
@@ -854,11 +855,11 @@ BOOL ScDocument::CopyTab( SCTAB nOldPos, SCTAB nNewPos, const ScMarkData* pOnlyM
                     nOldPos++;
                 pTab[nNewPos] = new ScTable(this, nNewPos, aName);
                 ++nMaxTableNumber;
-                bValid = TRUE;
+                bValid = sal_True;
                 for (i = 0; i <= MAXTAB; i++)
                     if (pTab[i] && i != nOldPos && i != nNewPos)
                         pTab[i]->UpdateCompile();
-                SetNoListening( FALSE );
+                SetNoListening( false );
                 for (i = 0; i <= MAXTAB; i++)
                     if (pTab[i] && i != nOldPos && i != nNewPos)
                         pTab[i]->StartAllListeners();
@@ -868,25 +869,22 @@ BOOL ScDocument::CopyTab( SCTAB nOldPos, SCTAB nNewPos, const ScMarkData* pOnlyM
                     pCondFormList->UpdateReference( URM_INSDEL, aRange, 0,0,1 );
                 if ( pValidationList )
                     pValidationList->UpdateReference( URM_INSDEL, aRange, 0,0,1 );
-                // #81844# sheet names of references may not be valid until sheet is copied
+                // sheet names of references may not be valid until sheet is copied
                 pChartListenerCollection->UpdateScheduledSeriesRanges();
             }
             else
-                bValid = FALSE;
+                bValid = false;
         }
     }
     if (bValid)
     {
-        SetNoListening( TRUE );		// noch nicht bei CopyToTable/Insert
+        SetNoListening( sal_True );		// noch nicht bei CopyToTable/Insert
         pTab[nOldPos]->CopyToTable(0, 0, MAXCOL, MAXROW, IDF_ALL, (pOnlyMarked != NULL),
                                         pTab[nNewPos], pOnlyMarked );
         pTab[nNewPos]->SetTabBgColor(pTab[nOldPos]->GetTabBgColor());
 
         SCsTAB nDz;
-/*		if (nNewPos < nOldPos)
-            nDz = ((short)nNewPos) - (short)nOldPos + 1;
-        else
-*/			nDz = ((short)nNewPos) - (short)nOldPos;
+        nDz = ((short)nNewPos) - (short)nOldPos;
         pTab[nNewPos]->UpdateReference(URM_COPY, 0, 0, nNewPos , MAXCOL, MAXROW,
                                         nNewPos, 0, 0, nDz, NULL);
 
@@ -894,8 +892,8 @@ BOOL ScDocument::CopyTab( SCTAB nOldPos, SCTAB nNewPos, const ScMarkData* pOnlyM
         pTab[nOldPos]->UpdateInsertTab(nNewPos);
 
         pTab[nOldPos]->UpdateCompile();
-        pTab[nNewPos]->UpdateCompile( TRUE );	// #67996# maybe already compiled in Clone, but used names need recompilation
-        SetNoListening( FALSE );
+        pTab[nNewPos]->UpdateCompile( true );	//  maybe already compiled in Clone, but used names need recompilation
+        SetNoListening( false );
         pTab[nOldPos]->StartAllListeners();
         pTab[nNewPos]->StartAllListeners();
         SetDirty();
@@ -906,6 +904,9 @@ BOOL ScDocument::CopyTab( SCTAB nOldPos, SCTAB nNewPos, const ScMarkData* pOnlyM
 
         pTab[nNewPos]->SetPageStyle( pTab[nOldPos]->GetPageStyle() );
         pTab[nNewPos]->SetPendingRowHeights( pTab[nOldPos]->IsPendingRowHeights() );
+
+        // Copy the custom print range if exists.
+        pTab[nNewPos]->CopyPrintRange(*pTab[nOldPos]);
     }
     else
         SetAutoCalc( bOldAutoCalc );
@@ -914,14 +915,14 @@ BOOL ScDocument::CopyTab( SCTAB nOldPos, SCTAB nNewPos, const ScMarkData* pOnlyM
 
 void VBA_InsertModule( ScDocument& rDoc, SCTAB nTab, String& sModuleName, String& sModuleSource );
 
-ULONG ScDocument::TransferTab( ScDocument* pSrcDoc, SCTAB nSrcPos,
-                                SCTAB nDestPos, BOOL bInsertNew,
-                                BOOL bResultsOnly )
+sal_uLong ScDocument::TransferTab( ScDocument* pSrcDoc, SCTAB nSrcPos,
+                                SCTAB nDestPos, sal_Bool bInsertNew,
+                                sal_Bool bResultsOnly )
 {
-    ULONG nRetVal = 1;						// 0 => Fehler 1 = ok
+    sal_uLong nRetVal = 1;						// 0 => Fehler 1 = ok
                                             // 2 => RefBox, 3 => NameBox
                                             // 4 => beides
-    BOOL bValid = TRUE;
+    sal_Bool bValid = sal_True;
     if (bInsertNew)				// neu einfuegen
     {
         String aName;
@@ -936,19 +937,19 @@ ULONG ScDocument::TransferTab( ScDocument* pSrcDoc, SCTAB nSrcPos,
             pTab[nDestPos]->DeleteArea( 0,0, MAXCOL,MAXROW, IDF_ALL );
         }
         else
-            bValid = FALSE;
+            bValid = false;
     }
 
     if (bValid)
     {
-        BOOL bOldAutoCalcSrc = FALSE;
-        BOOL bOldAutoCalc = GetAutoCalc();
-        SetAutoCalc( FALSE );	// Mehrfachberechnungen vermeiden
-        SetNoListening( TRUE );
+        sal_Bool bOldAutoCalcSrc = false;
+        sal_Bool bOldAutoCalc = GetAutoCalc();
+        SetAutoCalc( false );	// Mehrfachberechnungen vermeiden
+        SetNoListening( sal_True );
         if ( bResultsOnly )
         {
             bOldAutoCalcSrc = pSrcDoc->GetAutoCalc();
-            pSrcDoc->SetAutoCalc( TRUE );	// falls was berechnet werden muss
+            pSrcDoc->SetAutoCalc( sal_True );	// falls was berechnet werden muss
         }
 
         {
@@ -959,98 +960,94 @@ ULONG ScDocument::TransferTab( ScDocument* pSrcDoc, SCTAB nSrcPos,
                 ScBulkBroadcast aBulkBroadcast( pBASM);
                 pSrcDoc->pTab[nSrcPos]->CopyToTable(0, 0, MAXCOL, MAXROW,
                         ( bResultsOnly ? IDF_ALL & ~IDF_FORMULA : IDF_ALL),
-                        FALSE, pTab[nDestPos] );
+                        false, pTab[nDestPos] );
             }
         }
         pTab[nDestPos]->SetTabNo(nDestPos);
 
         if ( !bResultsOnly )
         {
-            BOOL bNamesLost = FALSE;
-            USHORT nSrcRangeNames = pSrcDoc->pRangeName->GetCount();
-            // array containing range names which might need update of indices
-            ScRangeData** pSrcRangeNames = nSrcRangeNames ? new ScRangeData* [nSrcRangeNames] : NULL;
+            bool bNamesLost = false;
+            // array containing range names which might need update of indices.
+            // The instances inserted into this vector are managed by the
+            // range name container of this document, so no need to delete
+            // them afterward.
+            ::std::vector<ScRangeData*> aSrcRangeNames;
+
             // the index mapping thereof
             ScRangeData::IndexMap aSrcRangeMap;
-            BOOL bRangeNameReplace = FALSE;
+            bool bRangeNameReplace = false;
 
             // find named ranges that are used in the source sheet
-            std::set<USHORT> aUsedNames;
+            std::set<sal_uInt16> aUsedNames;
             pSrcDoc->pTab[nSrcPos]->FindRangeNamesInUse( 0, 0, MAXCOL, MAXROW, aUsedNames );
 
-            for (USHORT i = 0; i < nSrcRangeNames; i++)		//! DB-Bereiche Pivot-Bereiche auch !!!
+            if (pSrcDoc->pRangeName)
             {
-                ScRangeData* pSrcData = (*pSrcDoc->pRangeName)[i];
-                USHORT nOldIndex = pSrcData->GetIndex();
-                bool bInUse = ( aUsedNames.find(nOldIndex) != aUsedNames.end() );
-                if (bInUse)
+                ScRangeName::const_iterator itr = pSrcDoc->pRangeName->begin(), itrEnd = pSrcDoc->pRangeName->end();
+                for (; itr != itrEnd; ++itr)		//! DB-Bereiche Pivot-Bereiche auch !!!
                 {
-                    USHORT nExisting = 0;
-                    if ( pRangeName->SearchName( pSrcData->GetName(), nExisting ) )
+                    sal_uInt16 nOldIndex = itr->GetIndex();
+                    bool bInUse = ( aUsedNames.find(nOldIndex) != aUsedNames.end() );
+                    if (bInUse)
                     {
-                        // the name exists already in the destination document
-                        // -> use the existing name, but show a warning
-                        // (when refreshing links, the existing name is used and the warning not shown)
-
-                        ScRangeData* pExistingData = (*pRangeName)[nExisting];
-                        USHORT nExistingIndex = pExistingData->GetIndex();
-
-                        pSrcRangeNames[i] = NULL;       // don't modify the named range
-                        aSrcRangeMap.insert(
-                            ScRangeData::IndexMap::value_type(nOldIndex, nExistingIndex));
-                        bRangeNameReplace = TRUE;
-                        bNamesLost = TRUE;
-                    }
-                    else
-                    {
-                        ScRangeData* pData = new ScRangeData( *pSrcData );
-                        pData->SetDocument(this);
-                        if ( pRangeName->FindIndex( pData->GetIndex() ) )
-                            pData->SetIndex(0);		// need new index, done in Insert
-                        if (!pRangeName->Insert(pData))
+                        const ScRangeData* pExistingData = GetRangeName()->findByName(itr->GetName());
+                        if (pExistingData)
                         {
-                            DBG_ERROR("can't insert name");     // shouldn't happen
-                            delete pData;
+                            // the name exists already in the destination document
+                            // -> use the existing name, but show a warning
+                            // (when refreshing links, the existing name is used and the warning not shown)
+
+                            sal_uInt16 nExistingIndex = pExistingData->GetIndex();
+
+                            // don't modify the named range
+                            aSrcRangeMap.insert(
+                                ScRangeData::IndexMap::value_type(nOldIndex, nExistingIndex));
+                            bRangeNameReplace = true;
+                            bNamesLost = true;
                         }
                         else
                         {
-                            pData->TransferTabRef( nSrcPos, nDestPos );
-                            pSrcRangeNames[i] = pData;
-                            USHORT nNewIndex = pData->GetIndex();
-                            aSrcRangeMap.insert(
-                                ScRangeData::IndexMap::value_type(nOldIndex, nNewIndex));
-                            if ( !bRangeNameReplace )
-                                bRangeNameReplace = ( nOldIndex != nNewIndex );
+                            ScRangeData* pData = new ScRangeData( *itr );
+                            pData->SetDocument(this);
+                            if ( pRangeName->findByIndex( pData->GetIndex() ) )
+                                pData->SetIndex(0);		// need new index, done in Insert
+                            if (!pRangeName->insert(pData))
+                            {
+                                OSL_FAIL("can't insert name");     // shouldn't happen
+                                delete pData;
+                            }
+                            else
+                            {
+                                pData->TransferTabRef( nSrcPos, nDestPos );
+                                aSrcRangeNames.push_back(pData);
+                                sal_uInt16 nNewIndex = pData->GetIndex();
+                                aSrcRangeMap.insert(
+                                    ScRangeData::IndexMap::value_type(nOldIndex, nNewIndex));
+                                if ( !bRangeNameReplace )
+                                    bRangeNameReplace = ( nOldIndex != nNewIndex );
+                            }
                         }
                     }
                 }
-                else
-                {
-                    pSrcRangeNames[i] = NULL;
-                    //aSrcRangeMap.SetPair( i, 0, 0 );		// not needed, defaulted
-                }
             }
             if ( bRangeNameReplace )
             {
                 // first update all inserted named formulas if they contain other
                 // range names and used indices changed
-                for (USHORT i = 0; i < nSrcRangeNames; i++)		//! DB-Bereiche Pivot-Bereiche auch
-                {
-                    if ( pSrcRangeNames[i] )
-                        pSrcRangeNames[i]->ReplaceRangeNamesInUse( aSrcRangeMap );
-                }
+                for (size_t i = 0, n = aSrcRangeNames.size(); i < n; ++i)       //! DB-Bereiche Pivot-Bereiche auch
+                    aSrcRangeNames[i]->ReplaceRangeNamesInUse( aSrcRangeMap );
+
                 // then update the formulas, they might need the just updated range names
                 pTab[nDestPos]->ReplaceRangeNamesInUse( 0, 0, MAXCOL, MAXROW, aSrcRangeMap );
             }
-            if ( pSrcRangeNames )
-                delete [] pSrcRangeNames;
 
             SCsTAB nDz = ((SCsTAB)nDestPos) - (SCsTAB)nSrcPos;
             pTab[nDestPos]->UpdateReference(URM_COPY, 0, 0, nDestPos,
                                                      MAXCOL, MAXROW, nDestPos,
                                                      0, 0, nDz, NULL);
             // Test for outside absolute references for info box
-            BOOL bIsAbsRef = pSrcDoc->pTab[nSrcPos]->TestTabRefAbs(nSrcPos);
+            sal_Bool bIsAbsRef = pSrcDoc->pTab[nSrcPos]->TestTabRefAbs(nSrcPos);
             // Readjust self-contained absolute references to this sheet
             pTab[nDestPos]->TestTabRefAbs(nSrcPos);
             if (bIsAbsRef)
@@ -1066,7 +1063,7 @@ ULONG ScDocument::TransferTab( ScDocument* pSrcDoc, SCTAB nSrcPos,
             pTab[nDestPos]->CompileAll();
         }
 
-        SetNoListening( FALSE );
+        SetNoListening( false );
         if ( !bResultsOnly )
             pTab[nDestPos]->StartAllListeners();
         SetDirty( ScRange( 0, 0, nDestPos, MAXCOL, MAXROW, nDestPos));
@@ -1084,7 +1081,7 @@ ULONG ScDocument::TransferTab( ScDocument* pSrcDoc, SCTAB nSrcPos,
     }
     if (!bValid)
         nRetVal = 0;
-    BOOL bVbaEnabled = IsInVBAMode();
+    sal_Bool bVbaEnabled = IsInVBAMode();
 
     if ( bVbaEnabled  )
     {
@@ -1098,7 +1095,7 @@ ULONG ScDocument::TransferTab( ScDocument* pSrcDoc, SCTAB nSrcPos,
                 aLibName = pSrcShell->GetBasicManager()->GetName();
                 pStarBASIC = pSrcShell->GetBasicManager()->GetLib( aLibName );
             }
-    
+
             String sCodeName;
             String sSource;
             uno::Reference< script::XLibraryContainer > xLibContainer = pSrcShell->GetBasicContainer();
@@ -1116,7 +1113,7 @@ ULONG ScDocument::TransferTab( ScDocument* pSrcDoc, SCTAB nSrcPos,
                 rtl::OUString sRTLSource;
                 xLib->getByName( sSrcCodeName ) >>= sRTLSource;
                 sSource = sRTLSource;
-            } 
+            }
             VBA_InsertModule( *this, nDestPos, sCodeName, sSource );
         }
     }
@@ -1126,39 +1123,58 @@ ULONG ScDocument::TransferTab( ScDocument* pSrcDoc, SCTAB nSrcPos,
 
 //	----------------------------------------------------------------------------
 
-void ScDocument::SetError( SCCOL nCol, SCROW nRow, SCTAB nTab, const USHORT nError)
+void ScDocument::SetError( SCCOL nCol, SCROW nRow, SCTAB nTab, const sal_uInt16 nError)
 {
     if (VALIDTAB(nTab))
         if (pTab[nTab])
             pTab[nTab]->SetError( nCol, nRow, nError );
 }
 
-void ScDocument::EraseNonUsedSharedNames(USHORT nLevel)
+namespace {
+
+bool eraseUnusedSharedName(ScRangeName* pRangeName, ScTable* pTab[], sal_uInt16 nLevel)
 {
-    for (USHORT i = 0; i < pRangeName->GetCount(); i++)
+    if (!pRangeName)
+        return false;
+
+    ScRangeName::iterator itr = pRangeName->begin(), itrEnd = pRangeName->end();
+    for (; itr != itrEnd; ++itr)
     {
-        ScRangeData* pRangeData = (*pRangeName)[i];
-        if (pRangeData && pRangeData->HasType(RT_SHARED))
+        if (!itr->HasType(RT_SHARED))
+            continue;
+
+        String aName;
+        itr->GetName(aName);
+        aName.Erase(0, 6);						// !!! vgl. Table4, FillFormula !!
+        sal_uInt16 nInd = static_cast<sal_uInt16>(aName.ToInt32());
+        if (nInd > nLevel)
+            continue;
+
+        sal_uInt16 nIndex = itr->GetIndex();
+
+        bool bInUse = false;
+        for (SCTAB j = 0; !bInUse && (j <= MAXTAB); ++j)
         {
-            String aName;
-            pRangeData->GetName(aName);
-            aName.Erase(0, 6);						// !!! vgl. Table4, FillFormula !!
-            USHORT nInd = (USHORT) aName.ToInt32();
-            if (nInd <= nLevel)
-            {
-                USHORT nIndex = pRangeData->GetIndex();
-                BOOL bInUse = FALSE;
-                for (SCTAB j = 0; !bInUse && (j <= MAXTAB); j++)
-                {
-                    if (pTab[j])
-                        bInUse = pTab[j]->IsRangeNameInUse(0, 0, MAXCOL-1, MAXROW-1,
-                                                           nIndex);
-                }
-                if (!bInUse)
-                    pRangeName->AtFree(i);
-            }
+            if (pTab[j])
+                bInUse = pTab[j]->IsRangeNameInUse(0, 0, MAXCOL-1, MAXROW-1, nIndex);
+        }
+        if (!bInUse)
+        {
+            pRangeName->erase(itr);
+            return true;
         }
     }
+    return false;
+}
+
+}
+
+void ScDocument::EraseNonUsedSharedNames(sal_uInt16 nLevel)
+{
+    if (!pRangeName)
+        return;
+    while (eraseUnusedSharedName(pRangeName, pTab, nLevel))
+        ;
 }
 
 //	----------------------------------------------------------------------------
@@ -1191,16 +1207,16 @@ ScFieldEditEngine* ScDocument::CreateFieldEditEngine()
     if (!pCacheFieldEditEngine)
     {
         pNewEditEngine = new ScFieldEditEngine( GetEnginePool(),
-            GetEditPool(), FALSE );
+            GetEditPool(), false );
     }
     else
     {
         if ( !bImportingXML )
         {
             // #i66209# previous use might not have restored update mode,
-            // ensure same state as for a new EditEngine (UpdateMode = TRUE)
+            // ensure same state as for a new EditEngine (UpdateMode = sal_True)
             if ( !pCacheFieldEditEngine->GetUpdateMode() )
-                pCacheFieldEditEngine->SetUpdateMode(TRUE);
+                pCacheFieldEditEngine->SetUpdateMode(sal_True);
         }
 
         pNewEditEngine = pCacheFieldEditEngine;
@@ -1223,7 +1239,6 @@ void ScDocument::DisposeFieldEditEngine(ScFieldEditEngine*& rpEditEngine)
 
 //	----------------------------------------------------------------------------
 
-// static
 ScRecursionHelper* ScDocument::CreateRecursionHelperInstance()
 {
     return new ScRecursionHelper;
