@@ -35,19 +35,27 @@
 
 #include "dbcolect.hxx"
 #include "global.hxx"
+#include "globalnames.hxx"
 #include "refupdat.hxx"
 #include "rechead.hxx"
 #include "document.hxx"
 #include "queryparam.hxx"
 #include "globstr.hrc"
+#include "subtotalparam.hxx"
 
+#include <memory>
+
+using ::std::unary_function;
+using ::std::for_each;
+using ::std::find_if;
+using ::std::remove_if;
 
 //---------------------------------------------------------------------------------------
 
 ScDBData::ScDBData( const String& rName,
                     SCTAB nTab,
                     SCCOL nCol1, SCROW nRow1, SCCOL nCol2, SCROW nRow2,
-                    BOOL bByR, BOOL bHasH) :
+                    bool bByR, bool bHasH) :
     aName		(rName),
     nTable		(nTab),
     nStartCol	(nCol1),
@@ -56,35 +64,26 @@ ScDBData::ScDBData( const String& rName,
     nEndRow		(nRow2),
     bByRow		(bByR),
     bHasHeader	(bHasH),
-    bDoSize		(FALSE),
-    bKeepFmt	(FALSE),
-    bStripData	(FALSE),
-    bIsAdvanced	(FALSE),
-    bDBSelection(FALSE),
+    bDoSize		(false),
+    bKeepFmt	(false),
+    bStripData	(false),
+    bIsAdvanced	(false),
+    bDBSelection(false),
     nIndex 		(0),
-    bAutoFilter (FALSE),
-    bModified	(FALSE)
+    bAutoFilter (false),
+    bModified	(false)
 {
-    USHORT i;
+    sal_uInt16 i;
 
     ScSortParam aSortParam;
     ScQueryParam aQueryParam;
-    ScSubTotalParam aSubTotalParam;
     ScImportParam aImportParam;
 
     for (i=0; i<MAXQUERY; i++)
         pQueryStr[i] = new String;
 
-    for (i=0; i<MAXSUBTOTAL; i++)
-    {
-        nSubTotals[i] = 0;
-        pSubTotals[i] = NULL;
-        pFunctions[i] = NULL;
-    }
-
     SetSortParam( aSortParam );
     SetQueryParam( aQueryParam );
-    SetSubTotalParam( aSubTotalParam );
     SetImportParam( aImportParam );
 }
 
@@ -122,15 +121,7 @@ ScDBData::ScDBData( const ScDBData& rData ) :
     nQueryDestRow  		(rData.nQueryDestRow),
     bIsAdvanced			(rData.bIsAdvanced),
     aAdvSource			(rData.aAdvSource),
-    bSubRemoveOnly		(rData.bSubRemoveOnly),
-    bSubReplace			(rData.bSubReplace),
-    bSubPagebreak		(rData.bSubPagebreak),
-    bSubCaseSens		(rData.bSubCaseSens),
-    bSubDoSort			(rData.bSubDoSort),
-    bSubAscending		(rData.bSubAscending),
-    bSubIncludePattern	(rData.bSubIncludePattern),
-    bSubUserDef			(rData.bSubUserDef),
-    nSubUserIndex		(rData.nSubUserIndex),
+    maSubTotal          (rData.maSubTotal),
     bDBImport			(rData.bDBImport),
     aDBName				(rData.aDBName),
     aDBStatement		(rData.aDBStatement),
@@ -142,8 +133,7 @@ ScDBData::ScDBData( const ScDBData& rData ) :
     bAutoFilter			(rData.bAutoFilter),
     bModified			(rData.bModified)
 {
-    USHORT i;
-    USHORT j;
+    sal_uInt16 i;
 
     for (i=0; i<MAXSORT; i++)
     {
@@ -162,28 +152,11 @@ ScDBData::ScDBData( const ScDBData& rData ) :
         nQueryVal[i]		= rData.nQueryVal[i];
         eQueryConnect[i]	= rData.eQueryConnect[i];
     }
-    for (i=0; i<MAXSUBTOTAL; i++)
-    {
-        bDoSubTotal[i]		= rData.bDoSubTotal[i];
-        nSubField[i]		= rData.nSubField[i];
-
-        SCCOL nCount	= rData.nSubTotals[i];
-        nSubTotals[i]	= nCount;
-        pFunctions[i]	= nCount > 0 ? new ScSubTotalFunc [nCount] : NULL;
-        pSubTotals[i]	= nCount > 0 ? new SCCOL		  [nCount] : NULL;
-
-        for (j=0; j<nCount; j++)
-        {
-            pSubTotals[i][j] = rData.pSubTotals[i][j];
-            pFunctions[i][j] = rData.pFunctions[i][j];
-        }
-    }
 }
 
 ScDBData& ScDBData::operator= (const ScDBData& rData)
 {
-    USHORT i;
-    USHORT j;
+    sal_uInt16 i;
 
     ScRefreshTimer::operator=( rData );
     aName				= rData.aName;
@@ -216,16 +189,8 @@ ScDBData& ScDBData::operator= (const ScDBData& rData)
     nQueryDestCol	  	= rData.nQueryDestCol;
     nQueryDestRow  		= rData.nQueryDestRow;
     bIsAdvanced			= rData.bIsAdvanced;
+    maSubTotal          = rData.maSubTotal;
     aAdvSource			= rData.aAdvSource;
-    bSubRemoveOnly		= rData.bSubRemoveOnly;
-    bSubReplace			= rData.bSubReplace;
-    bSubPagebreak		= rData.bSubPagebreak;
-    bSubCaseSens		= rData.bSubCaseSens;
-    bSubDoSort			= rData.bSubDoSort;
-    bSubAscending		= rData.bSubAscending;
-    bSubIncludePattern	= rData.bSubIncludePattern;
-    bSubUserDef			= rData.bSubUserDef;
-    nSubUserIndex		= rData.nSubUserIndex;
     bDBImport			= rData.bDBImport;
     aDBName				= rData.aDBName;
     aDBStatement		= rData.aDBStatement;
@@ -253,29 +218,16 @@ ScDBData& ScDBData::operator= (const ScDBData& rData)
         nQueryVal[i]		= rData.nQueryVal[i];
         eQueryConnect[i]	= rData.eQueryConnect[i];
     }
-    for (i=0; i<MAXSUBTOTAL; i++)
-    {
-        bDoSubTotal[i]		= rData.bDoSubTotal[i];
-        nSubField[i]		= rData.nSubField[i];
-        SCCOL nCount	= rData.nSubTotals[i];
-        nSubTotals[i]	= nCount;
-
-        delete[] pSubTotals[i];
-        delete[] pFunctions[i];
-
-        pSubTotals[i] = nCount > 0 ? new SCCOL			[nCount] : NULL;
-        pFunctions[i] = nCount > 0 ? new ScSubTotalFunc [nCount] : NULL;
-        for (j=0; j<nCount; j++)
-        {
-            pSubTotals[i][j] = rData.pSubTotals[i][j];
-            pFunctions[i][j] = rData.pFunctions[i][j];
-        }
-    }
 
     return *this;
 }
 
-BOOL ScDBData::operator== (const ScDBData& rData) const
+SCTAB ScDBData::GetTable() const
+{
+    return nTable;
+}
+
+bool ScDBData::operator== (const ScDBData& rData) const
 {
     //	Daten, die nicht in den Params sind
 
@@ -288,50 +240,45 @@ BOOL ScDBData::operator== (const ScDBData& rData) const
 //         bAutoFilter!= rData.bAutoFilter||
          ScRefreshTimer::operator!=( rData )
         )
-        return FALSE;
+        return false;
 
     if ( bIsAdvanced && aAdvSource != rData.aAdvSource )
-        return FALSE;
+        return false;
 
     ScSortParam aSort1, aSort2;
     GetSortParam(aSort1);
     rData.GetSortParam(aSort2);
     if (!(aSort1 == aSort2))
-        return FALSE;
+        return false;
 
     ScQueryParam aQuery1, aQuery2;
     GetQueryParam(aQuery1);
     rData.GetQueryParam(aQuery2);
     if (!(aQuery1 == aQuery2))
-        return FALSE;
+        return false;
 
     ScSubTotalParam aSubTotal1, aSubTotal2;
     GetSubTotalParam(aSubTotal1);
     rData.GetSubTotalParam(aSubTotal2);
     if (!(aSubTotal1 == aSubTotal2))
-        return FALSE;
+        return false;
 
     ScImportParam aImport1, aImport2;
     GetImportParam(aImport1);
     rData.GetImportParam(aImport2);
     if (!(aImport1 == aImport2))
-        return FALSE;
+        return false;
 
-    return TRUE;
+    return true;
 }
 
 ScDBData::~ScDBData()
 {
     StopRefreshTimer();
-    USHORT i;
+    sal_uInt16 i;
 
     for (i=0; i<MAXQUERY; i++)
         delete pQueryStr[i];
-    for (i=0; i<MAXSUBTOTAL; i++)
-    {
-        delete[] pSubTotals[i];
-        delete[] pFunctions[i];
-    }
 }
 
 
@@ -360,7 +307,7 @@ String ScDBData::GetOperations() const
         aVal += ScGlobal::GetRscString(STR_OPERATION_SORT);
     }
 
-    if (bDoSubTotal[0] && !bSubRemoveOnly)
+    if (maSubTotal.bGroupActive[0] && !maSubTotal.bRemoveOnly)
     {
         if (aVal.Len())
             aVal.AppendAscii( RTL_CONSTASCII_STRINGPARAM(", ") );
@@ -373,19 +320,18 @@ String ScDBData::GetOperations() const
     return aVal;
 }
 
-void ScDBData::GetArea(SCTAB& rTab, SCCOL& rCol1, SCROW& rRow1, SCCOL& rCol2, SCROW& rRow2,
-                       bool bUseDynamicRange) const
+void ScDBData::GetArea(SCTAB& rTab, SCCOL& rCol1, SCROW& rRow1, SCCOL& rCol2, SCROW& rRow2) const
 {
     rTab  = nTable;
     rCol1 = nStartCol;
     rRow1 = nStartRow;
     rCol2 = nEndCol;
-    rRow2 = bUseDynamicRange ? nDynamicEndRow : nEndRow;
+    rRow2 = nEndRow;
 }
 
-void ScDBData::GetArea(ScRange& rRange, bool bUseDynamicRange) const
+void ScDBData::GetArea(ScRange& rRange) const
 {
-    SCROW nNewEndRow = bUseDynamicRange ? nDynamicEndRow : nEndRow;
+    SCROW nNewEndRow = nEndRow;
     rRange = ScRange( nStartCol, nStartRow, nTable, nEndCol, nNewEndRow, nTable );
 }
 
@@ -398,14 +344,9 @@ void ScDBData::SetArea(SCTAB nTab, SCCOL nCol1, SCROW nRow1, SCCOL nCol2, SCROW
     nEndRow   = nRow2;
 }
 
-void ScDBData::SetDynamicEndRow(SCROW nRow)
-{
-    nDynamicEndRow = nRow;
-}
-
 void ScDBData::MoveTo(SCTAB nTab, SCCOL nCol1, SCROW nRow1, SCCOL nCol2, SCROW nRow2)
 {
-    USHORT i;
+    sal_uInt16 i;
     long nDifX = ((long) nCol1) - ((long) nStartCol);
     long nDifY = ((long) nRow1) - ((long) nStartRow);
 
@@ -418,7 +359,7 @@ void ScDBData::MoveTo(SCTAB nTab, SCCOL nCol1, SCROW nRow1, SCCOL nCol2, SCROW n
         if (nSortField[i] > nSortEnd)
         {
             nSortField[i] = 0;
-            bDoSort[i]	  = FALSE;
+            bDoSort[i]	  = false;
         }
     }
     for (i=0; i<MAXQUERY; i++)
@@ -427,16 +368,16 @@ void ScDBData::MoveTo(SCTAB nTab, SCCOL nCol1, SCROW nRow1, SCCOL nCol2, SCROW n
         if (nQueryField[i] > nCol2)
         {
             nQueryField[i] = 0;
-            bDoQuery[i]	   = FALSE;
+            bDoQuery[i]	   = false;
         }
     }
     for (i=0; i<MAXSUBTOTAL; i++)
     {
-        nSubField[i] = sal::static_int_cast<SCCOL>( nSubField[i] + nDifX );
-        if (nSubField[i] > nCol2)
+        maSubTotal.nField[i] = sal::static_int_cast<SCCOL>( maSubTotal.nField[i] + nDifX );
+        if (maSubTotal.nField[i] > nCol2)
         {
-            nSubField[i]   = 0;
-            bDoSubTotal[i] = FALSE;
+            maSubTotal.nField[i] = 0;
+            maSubTotal.bGroupActive[i] = false;
         }
     }
 
@@ -460,7 +401,7 @@ void ScDBData::GetSortParam( ScSortParam& rSortParam ) const
     rSortParam.bIncludePattern = bIncludePattern;
     rSortParam.bUserDef	= bSortUserDef;
     rSortParam.nUserIndex = nSortUserIndex;
-    for (USHORT i=0; i<MAXSORT; i++)
+    for (sal_uInt16 i=0; i<MAXSORT; i++)
     {
         rSortParam.bDoSort[i] 	 = bDoSort[i];
         rSortParam.nField[i] 	 = nSortField[i];
@@ -481,7 +422,7 @@ void ScDBData::SetSortParam( const ScSortParam& rSortParam )
     nSortDestRow = rSortParam.nDestRow;
     bSortUserDef = rSortParam.bUserDef;
     nSortUserIndex = rSortParam.nUserIndex;
-    for (USHORT i=0; i<MAXSORT; i++)
+    for (sal_uInt16 i=0; i<MAXSORT; i++)
     {
         bDoSort[i]	  = rSortParam.bDoSort[i];
         nSortField[i] = rSortParam.nField[i];
@@ -510,7 +451,6 @@ void ScDBData::GetQueryParam( ScQueryParam& rQueryParam ) const
     rQueryParam.nDestTab = nQueryDestTab;
     rQueryParam.nDestCol = nQueryDestCol;
     rQueryParam.nDestRow = nQueryDestRow;
-    rQueryParam.nDynamicEndRow = nDynamicEndRow;
 
     rQueryParam.Resize( MAXQUERY );
     for (SCSIZE i=0; i<MAXQUERY; i++)
@@ -534,9 +474,9 @@ void ScDBData::SetQueryParam(const ScQueryParam& rQueryParam)
                 !rQueryParam.GetEntry(MAXQUERY).bDoQuery,
                 "zuviele Eintraege bei ScDBData::SetQueryParam" );
 
-    //	set bIsAdvanced to FALSE for everything that is not from the
+    //	set bIsAdvanced to false for everything that is not from the
     //	advanced filter dialog
-    bIsAdvanced = FALSE;
+    bIsAdvanced = false;
 
     bQueryInplace = rQueryParam.bInplace;
     bQueryCaseSens = rQueryParam.bCaseSens;
@@ -565,13 +505,13 @@ void ScDBData::SetAdvancedQuerySource(const ScRange* pSource)
     if (pSource)
     {
         aAdvSource = *pSource;
-        bIsAdvanced = TRUE;
+        bIsAdvanced = true;
     }
     else
-        bIsAdvanced = FALSE;
+        bIsAdvanced = false;
 }
 
-BOOL ScDBData::GetAdvancedQuerySource(ScRange& rSource) const
+bool ScDBData::GetAdvancedQuerySource(ScRange& rSource) const
 {
     rSource = aAdvSource;
     return bIsAdvanced;
@@ -579,76 +519,19 @@ BOOL ScDBData::GetAdvancedQuerySource(ScRange& rSource) const
 
 void ScDBData::GetSubTotalParam(ScSubTotalParam& rSubTotalParam) const
 {
-    USHORT i;
-    USHORT j;
+    rSubTotalParam = maSubTotal;
 
+    // Share the data range with the parent db data.  The range in the subtotal
+    // param struct is not used.
     rSubTotalParam.nCol1 = nStartCol;
     rSubTotalParam.nRow1 = nStartRow;
     rSubTotalParam.nCol2 = nEndCol;
     rSubTotalParam.nRow2 = nEndRow;
-
-    rSubTotalParam.bRemoveOnly		= bSubRemoveOnly;
-    rSubTotalParam.bReplace			= bSubReplace;
-    rSubTotalParam.bPagebreak		= bSubPagebreak;
-    rSubTotalParam.bCaseSens		= bSubCaseSens;
-    rSubTotalParam.bDoSort			= bSubDoSort;
-    rSubTotalParam.bAscending		= bSubAscending;
-    rSubTotalParam.bIncludePattern	= bSubIncludePattern;
-    rSubTotalParam.bUserDef			= bSubUserDef;
-    rSubTotalParam.nUserIndex		= nSubUserIndex;
-
-    for (i=0; i<MAXSUBTOTAL; i++)
-    {
-        rSubTotalParam.bGroupActive[i]	= bDoSubTotal[i];
-        rSubTotalParam.nField[i]		= nSubField[i];
-        SCCOL nCount = nSubTotals[i];
-
-        rSubTotalParam.nSubTotals[i] = nCount;
-        delete[] rSubTotalParam.pSubTotals[i];
-        delete[] rSubTotalParam.pFunctions[i];
-        rSubTotalParam.pSubTotals[i] = nCount > 0 ? new SCCOL[nCount] : NULL;
-        rSubTotalParam.pFunctions[i] = nCount > 0 ? new ScSubTotalFunc[nCount]
-                                              : NULL;
-        for (j=0; j<nCount; j++)
-        {
-            rSubTotalParam.pSubTotals[i][j] = pSubTotals[i][j];
-            rSubTotalParam.pFunctions[i][j] = pFunctions[i][j];
-        }
-    }
 }
 
 void ScDBData::SetSubTotalParam(const ScSubTotalParam& rSubTotalParam)
 {
-    USHORT i;
-    USHORT j;
-
-    bSubRemoveOnly		= rSubTotalParam.bRemoveOnly;
-    bSubReplace			= rSubTotalParam.bReplace;
-    bSubPagebreak		= rSubTotalParam.bPagebreak;
-    bSubCaseSens		= rSubTotalParam.bCaseSens;
-    bSubDoSort			= rSubTotalParam.bDoSort;
-    bSubAscending		= rSubTotalParam.bAscending;
-    bSubIncludePattern	= rSubTotalParam.bIncludePattern;
-    bSubUserDef			= rSubTotalParam.bUserDef;
-    nSubUserIndex		= rSubTotalParam.nUserIndex;
-
-    for (i=0; i<MAXSUBTOTAL; i++)
-    {
-        bDoSubTotal[i]	= rSubTotalParam.bGroupActive[i];
-        nSubField[i]	= rSubTotalParam.nField[i];
-        SCCOL nCount = rSubTotalParam.nSubTotals[i];
-
-        nSubTotals[i] = nCount;
-        delete[] pSubTotals[i];
-        delete[] pFunctions[i];
-        pSubTotals[i] = nCount > 0 ? new SCCOL			[nCount] : NULL;
-        pFunctions[i] = nCount > 0 ? new ScSubTotalFunc [nCount] : NULL;
-        for (j=0; j<nCount; j++)
-        {
-            pSubTotals[i][j] = rSubTotalParam.pSubTotals[i][j];
-            pFunctions[i][j] = rSubTotalParam.pFunctions[i][j];
-        }
-    }
+    maSubTotal = rSubTotalParam;
 }
 
 void ScDBData::GetImportParam(ScImportParam& rImportParam) const
@@ -676,7 +559,7 @@ void ScDBData::SetImportParam(const ScImportParam& rImportParam)
     nDBType			= rImportParam.nType;
 }
 
-BOOL ScDBData::IsDBAtCursor(SCCOL nCol, SCROW nRow, SCTAB nTab, BOOL bStartOnly) const
+bool ScDBData::IsDBAtCursor(SCCOL nCol, SCROW nRow, SCTAB nTab, bool bStartOnly) const
 {
     if (nTab == nTable)
     {
@@ -687,12 +570,12 @@ BOOL ScDBData::IsDBAtCursor(SCCOL nCol, SCROW nRow, SCTAB nTab, BOOL bStartOnly)
                      nRow >= nStartRow && nRow <= nEndRow );
     }
 
-    return FALSE;
+    return false;
 }
 
-BOOL ScDBData::IsDBAtArea(SCTAB nTab, SCCOL nCol1, SCROW nRow1, SCCOL nCol2, SCROW nRow2) const
+bool ScDBData::IsDBAtArea(SCTAB nTab, SCCOL nCol1, SCROW nRow1, SCCOL nCol2, SCROW nRow2) const
 {
-    return (BOOL)((nTab == nTable)
+    return (bool)((nTab == nTable)
                     && (nCol1 == nStartCol) && (nRow1 == nStartRow)
                     && (nCol2 == nEndCol) && (nRow2 == nEndRow));
 }
@@ -702,142 +585,10 @@ ScDataObject*	ScDBData::Clone() const
     return new ScDBData(*this);
 }
 
-
-//---------------------------------------------------------------------------------------
-//	Compare zum Sortieren
-
-short ScDBCollection::Compare(ScDataObject* pKey1, ScDataObject* pKey2) const
+void ScDBData::UpdateMoveTab(SCTAB nOldPos, SCTAB nNewPos)
 {
-    const String& rStr1 = ((ScDBData*)pKey1)->GetName();
-    const String& rStr2 = ((ScDBData*)pKey2)->GetName();
-    return (short) ScGlobal::GetpTransliteration()->compareString( rStr1, rStr2 );
-}
-
-//	IsEqual - alles gleich
-
-BOOL ScDBCollection::IsEqual(ScDataObject* pKey1, ScDataObject* pKey2) const
-{
-    return *(ScDBData*)pKey1 == *(ScDBData*)pKey2;
-}
-
-ScDBData* ScDBCollection::GetDBAtCursor(SCCOL nCol, SCROW nRow, SCTAB nTab, BOOL bStartOnly) const
-{
-    ScDBData* pNoNameData = NULL;
-    if (pItems)
-    {
-        const String& rNoName = ScGlobal::GetRscString( STR_DB_NONAME );
-
-        for (USHORT i = 0; i < nCount; i++)
-            if (((ScDBData*)pItems[i])->IsDBAtCursor(nCol, nRow, nTab, bStartOnly))
-            {
-                ScDBData* pDB = (ScDBData*)pItems[i];
-                if ( pDB->GetName() == rNoName )
-                    pNoNameData = pDB;
-                else
-                    return pDB;
-            }
-    }
-    return pNoNameData;				// "unbenannt" nur zurueck, wenn sonst nichts gefunden
-}
-
-ScDBData* ScDBCollection::GetDBAtArea(SCTAB nTab, SCCOL nCol1, SCROW nRow1, SCCOL nCol2, SCROW nRow2) const
-{
-    ScDBData* pNoNameData = NULL;
-    if (pItems)
-    {
-        const String& rNoName = ScGlobal::GetRscString( STR_DB_NONAME );
-
-        for (USHORT i = 0; i < nCount; i++)
-            if (((ScDBData*)pItems[i])->IsDBAtArea(nTab, nCol1, nRow1, nCol2, nRow2))
-            {
-                ScDBData* pDB = (ScDBData*)pItems[i];
-                if ( pDB->GetName() == rNoName )
-                    pNoNameData = pDB;
-                else
-                    return pDB;
-            }
-    }
-    return pNoNameData;				// "unbenannt" nur zurueck, wenn sonst nichts gefunden
-}
-
-BOOL ScDBCollection::SearchName( const String& rName, USHORT& rIndex ) const
-{
-    ScDBData aDataObj( rName, 0,0,0,0,0 );
-    return Search( &aDataObj, rIndex );
-}
-
-void ScDBCollection::DeleteOnTab( SCTAB nTab )
-{
-    USHORT nPos = 0;
-    while ( nPos < nCount )
-    {
-        // look for output positions on the deleted sheet
-
-        SCCOL nEntryCol1, nEntryCol2;
-        SCROW nEntryRow1, nEntryRow2;
-        SCTAB nEntryTab;
-        static_cast<const ScDBData*>(At(nPos))->GetArea( nEntryTab, nEntryCol1, nEntryRow1, nEntryCol2, nEntryRow2 );
-        if ( nEntryTab == nTab )
-            AtFree(nPos);
-        else
-            ++nPos;
-    }
-}
-
-void ScDBCollection::UpdateReference(UpdateRefMode eUpdateRefMode,
-                                SCCOL nCol1, SCROW nRow1, SCTAB nTab1,
-                                SCCOL nCol2, SCROW nRow2, SCTAB nTab2,
-                                SCsCOL nDx, SCsROW nDy, SCsTAB nDz )
-{
-    for (USHORT i=0; i<nCount; i++)
-    {
-        SCCOL theCol1;
-        SCROW theRow1;
-        SCTAB theTab1;
-        SCCOL theCol2;
-        SCROW theRow2;
-        SCTAB theTab2;
-        ((ScDBData*)pItems[i])->GetArea( theTab1, theCol1, theRow1, theCol2, theRow2 );
-        theTab2 = theTab1;
-
-        BOOL bDoUpdate = ScRefUpdate::Update( pDoc, eUpdateRefMode,
-                                                nCol1,nRow1,nTab1, nCol2,nRow2,nTab2, nDx,nDy,nDz,
-                                                theCol1,theRow1,theTab1, theCol2,theRow2,theTab2 ) != UR_NOTHING;
-        if (bDoUpdate)
-            ((ScDBData*)pItems[i])->MoveTo( theTab1, theCol1, theRow1, theCol2, theRow2 );
-
-        ScRange aAdvSource;
-        if ( ((ScDBData*)pItems[i])->GetAdvancedQuerySource(aAdvSource) )
-        {
-            aAdvSource.GetVars( theCol1,theRow1,theTab1, theCol2,theRow2,theTab2 );
-            if ( ScRefUpdate::Update( pDoc, eUpdateRefMode,
-                                        nCol1,nRow1,nTab1, nCol2,nRow2,nTab2, nDx,nDy,nDz,
-                                        theCol1,theRow1,theTab1, theCol2,theRow2,theTab2 ) )
-            {
-                aAdvSource.aStart.Set( theCol1,theRow1,theTab1 );
-                aAdvSource.aEnd.Set( theCol2,theRow2,theTab2 );
-                ((ScDBData*)pItems[i])->SetAdvancedQuerySource( &aAdvSource );
-
-                bDoUpdate = TRUE;		// DBData is modified
-            }
-        }
-
-        ((ScDBData*)pItems[i])->SetModified(bDoUpdate);
-
-        //!		Testen, ob mitten aus dem Bereich geloescht/eingefuegt wurde !!!
-    }
-}
-
-
-void ScDBCollection::UpdateMoveTab( SCTAB nOldPos, SCTAB nNewPos )
-{
-    //	wenn nOldPos vor nNewPos liegt, ist nNewPos schon angepasst
-
-    for (USHORT i=0; i<nCount; i++)
-    {
         ScRange aRange;
-        ScDBData* pData = (ScDBData*)pItems[i];
-        pData->GetArea( aRange );
+        GetArea( aRange );
         SCTAB nTab = aRange.aStart.Tab();				// hat nur eine Tabelle
 
         //	anpassen wie die aktuelle Tabelle bei ScTablesHint (tabvwsh5.cxx)
@@ -855,21 +606,323 @@ void ScDBCollection::UpdateMoveTab( SCTAB nOldPos, SCTAB nNewPos )
                 ++nTab;
         }
 
-        BOOL bChanged = ( nTab != aRange.aStart.Tab() );
+        bool bChanged = ( nTab != aRange.aStart.Tab() );
         if (bChanged)
-            pData->SetArea( nTab, aRange.aStart.Col(), aRange.aStart.Row(),
+            SetArea( nTab, aRange.aStart.Col(), aRange.aStart.Row(),
                                     aRange.aEnd.Col(),aRange.aEnd .Row() );
 
         //	MoveTo ist nicht noetig, wenn nur die Tabelle geaendert ist
 
-        pData->SetModified(bChanged);
+        SetModified(bChanged);
+
+}
+
+void ScDBData::UpdateReference(ScDocument* pDoc, UpdateRefMode eUpdateRefMode,
+                                SCCOL nCol1, SCROW nRow1, SCTAB nTab1,
+                                SCCOL nCol2, SCROW nRow2, SCTAB nTab2,
+                                SCsCOL nDx, SCsROW nDy, SCsTAB nDz)
+{
+    SCCOL theCol1;
+    SCROW theRow1;
+    SCTAB theTab1;
+    SCCOL theCol2;
+    SCROW theRow2;
+    SCTAB theTab2;
+    GetArea( theTab1, theCol1, theRow1, theCol2, theRow2 );
+    theTab2 = theTab1;
+
+    bool bDoUpdate = ScRefUpdate::Update( pDoc, eUpdateRefMode,
+                                            nCol1,nRow1,nTab1, nCol2,nRow2,nTab2, nDx,nDy,nDz,
+                                            theCol1,theRow1,theTab1, theCol2,theRow2,theTab2 ) != UR_NOTHING;
+    if (bDoUpdate)
+        MoveTo( theTab1, theCol1, theRow1, theCol2, theRow2 );
+
+    ScRange aRangeAdvSource;
+    if ( GetAdvancedQuerySource(aRangeAdvSource) )
+    {
+        aRangeAdvSource.GetVars( theCol1,theRow1,theTab1, theCol2,theRow2,theTab2 );
+        if ( ScRefUpdate::Update( pDoc, eUpdateRefMode,
+                                    nCol1,nRow1,nTab1, nCol2,nRow2,nTab2, nDx,nDy,nDz,
+                                    theCol1,theRow1,theTab1, theCol2,theRow2,theTab2 ) )
+        {
+            aRangeAdvSource.aStart.Set( theCol1,theRow1,theTab1 );
+            aRangeAdvSource.aEnd.Set( theCol2,theRow2,theTab2 );
+            SetAdvancedQuerySource( &aRangeAdvSource );
+
+            bDoUpdate = true;		// DBData is modified
+        }
     }
+
+    SetModified(bDoUpdate);
+
+    //!		Testen, ob mitten aus dem Bereich geloescht/eingefuegt wurde !!!
+}
+
+void ScDBData::ExtendDataArea(ScDocument* pDoc)
+{
+    // Extend the DB area to include data rows immediately below.
+    SCCOL nCol1a = nStartCol, nCol2a = nEndCol;
+    SCROW nRow1a = nStartRow, nRow2a = nEndRow;
+    pDoc->GetDataArea(nTable, nCol1a, nRow1a, nCol2a, nRow2a, false, false);
+    nEndRow = nRow2a;
+}
+
+namespace {
+
+class FindByTable : public ::std::unary_function<ScDBData, bool>
+{
+    SCTAB mnTab;
+public:
+    FindByTable(SCTAB nTab) : mnTab(nTab) {}
+
+    bool operator() (const ScDBData& r) const
+    {
+        ScRange aRange;
+        r.GetArea(aRange);
+        return aRange.aStart.Tab() == mnTab;
+    }
+};
+
+class UpdateRefFunc : public unary_function<ScDBData, void>
+{
+    ScDocument* mpDoc;
+    UpdateRefMode meMode;
+    SCCOL mnCol1;
+    SCROW mnRow1;
+    SCTAB mnTab1;
+    SCCOL mnCol2;
+    SCROW mnRow2;
+    SCTAB mnTab2;
+    SCsCOL mnDx;
+    SCsROW mnDy;
+    SCsTAB mnDz;
+
+public:
+    UpdateRefFunc(ScDocument* pDoc, UpdateRefMode eMode,
+                    SCCOL nCol1, SCROW nRow1, SCTAB nTab1,
+                    SCCOL nCol2, SCROW nRow2, SCTAB nTab2,
+                    SCsCOL nDx, SCsROW nDy, SCsTAB nDz) :
+        mpDoc(pDoc), meMode(eMode),
+        mnCol1(nCol1), mnRow1(nRow1), mnTab1(nTab1),
+        mnCol2(nCol2), mnRow2(nRow2), mnTab2(nTab2),
+        mnDx(nDx), mnDy(nDy), mnDz(nDz) {}
+
+    void operator() (ScDBData& r)
+    {
+        r.UpdateReference(mpDoc, meMode, mnCol1, mnRow1, mnTab1, mnCol2, mnRow2, mnTab2, mnDx, mnDy, mnDz);
+    }
+};
+
+class UpdateMoveTabFunc : public unary_function<ScDBData, void>
+{
+    SCTAB mnOldTab;
+    SCTAB mnNewTab;
+public:
+    UpdateMoveTabFunc(SCTAB nOld, SCTAB nNew) : mnOldTab(nOld), mnNewTab(nNew) {}
+    void operator() (ScDBData& r)
+    {
+        r.UpdateMoveTab(mnOldTab, mnNewTab);
+    }
+};
+
+class FindByCursor : public unary_function<ScDBData, bool>
+{
+    SCCOL mnCol;
+    SCROW mnRow;
+    SCTAB mnTab;
+    bool mbStartOnly;
+public:
+    FindByCursor(SCCOL nCol, SCROW nRow, SCTAB nTab, bool bStartOnly) :
+        mnCol(nCol), mnRow(nRow), mnTab(nTab), mbStartOnly(bStartOnly) {}
+
+    bool operator() (const ScDBData& r)
+    {
+        return r.IsDBAtCursor(mnCol, mnRow, mnTab, mbStartOnly);
+    }
+};
+
+class FindByRange : public unary_function<ScDBData, bool>
+{
+    const ScRange& mrRange;
+public:
+    FindByRange(const ScRange& rRange) : mrRange(rRange) {}
+
+    bool operator() (const ScDBData& r)
+    {
+        return r.IsDBAtArea(
+            mrRange.aStart.Tab(), mrRange.aStart.Col(), mrRange.aStart.Row(), mrRange.aEnd.Col(), mrRange.aEnd.Row());
+    }
+};
+
+}
+
+ScDBCollection::ScDBCollection(const ScDBCollection& r) :
+    ScSortedCollection(r), pDoc(r.pDoc), nEntryIndex(r.nEntryIndex), maAnonDBs(r.maAnonDBs)
+{}
+
+short ScDBCollection::Compare(ScDataObject* pKey1, ScDataObject* pKey2) const
+{
+    const String& rStr1 = ((ScDBData*)pKey1)->GetName();
+    const String& rStr2 = ((ScDBData*)pKey2)->GetName();
+    return (short) ScGlobal::GetpTransliteration()->compareString( rStr1, rStr2 );
+}
+
+//	IsEqual - alles gleich
+
+sal_Bool ScDBCollection::IsEqual(ScDataObject* pKey1, ScDataObject* pKey2) const
+{
+    return *(ScDBData*)pKey1 == *(ScDBData*)pKey2;
+}
+
+ScDBData* ScDBCollection::GetDBAtCursor(SCCOL nCol, SCROW nRow, SCTAB nTab, sal_Bool bStartOnly) const
+{
+    ScDBData* pNoNameData = pDoc->GetAnonymousDBData(nTab);
+    if (pItems)
+    {
+        for (sal_uInt16 i = 0; i < nCount; i++)
+        {
+            if (((ScDBData*)pItems[i])->IsDBAtCursor(nCol, nRow, nTab, bStartOnly))
+            {
+                ScDBData* pDB = (ScDBData*)pItems[i];
+                return pDB; //return AnonymousDBData only if nothing else was found
+            }
+        }    
+    }
+    if (pNoNameData)
+        if (pNoNameData->IsDBAtCursor(nCol,nRow,nTab,bStartOnly))
+            return pNoNameData;
+
+    // Check the anonymous db ranges.
+    const ScDBData* pData = findAnonAtCursor(nCol, nRow, nTab, bStartOnly);
+    if (pData)
+        return const_cast<ScDBData*>(pData);
+
+    return NULL;
+}
+
+ScDBData* ScDBCollection::GetDBAtArea(SCTAB nTab, SCCOL nCol1, SCROW nRow1, SCCOL nCol2, SCROW nRow2) const
+{
+    ScDBData* pNoNameData = pDoc->GetAnonymousDBData(nTab);
+    if (pItems)
+    {
+        for (sal_uInt16 i = 0; i < nCount; i++)
+            if (((ScDBData*)pItems[i])->IsDBAtArea(nTab, nCol1, nRow1, nCol2, nRow2))
+            {
+                ScDBData* pDB = (ScDBData*)pItems[i];
+                return pDB; //return AnonymousDBData only if nothing else was found
+            }
+    }
+    if (pNoNameData)
+        if (pNoNameData->IsDBAtArea(nTab, nCol1, nRow1, nCol2, nRow2))
+            return pNoNameData;
+
+    // Check the anonymous db ranges.
+    ScRange aRange(nCol1, nRow1, nTab, nCol2, nRow2, nTab);
+    const ScDBData* pData = findAnonByRange(aRange);
+    if (pData)
+        return const_cast<ScDBData*>(pData);
+
+    return NULL;	
+}
+
+ScDBData* ScDBCollection::GetFilterDBAtTable(SCTAB nTab) const
+{
+    ScDBData* pDataEmpty = NULL;
+    if (pItems)
+    {
+        for (sal_uInt16 i = 0; i < nCount; i++)
+        {
+            ScDBData* pDBTemp = (ScDBData*)pItems[i];
+            if ( pDBTemp->GetTable() == nTab )
+            {                
+                sal_Bool bFilter = pDBTemp->HasAutoFilter() || pDBTemp->HasQueryParam();              
+              
+                if ( bFilter )                 
+                    return pDBTemp;
+            }
+        }
+    }
+
+    return pDataEmpty;
+}
+
+sal_Bool ScDBCollection::SearchName( const String& rName, sal_uInt16& rIndex ) const
+{
+    if (rtl::OUString(rName)==rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(STR_DB_LOCAL_NONAME)))
+        DBG_ASSERT(false,"search for noname string");
+    ScDBData aDataObj( rName, 0,0,0,0,0 );
+    return Search( &aDataObj, rIndex );
+}
+
+void ScDBCollection::DeleteOnTab( SCTAB nTab )
+{
+    sal_uInt16 nPos = 0;
+    while ( nPos < nCount )
+    {
+        // look for output positions on the deleted sheet
+
+        SCCOL nEntryCol1, nEntryCol2;
+        SCROW nEntryRow1, nEntryRow2;
+        SCTAB nEntryTab;
+        static_cast<const ScDBData*>(At(nPos))->GetArea( nEntryTab, nEntryCol1, nEntryRow1, nEntryCol2, nEntryRow2 );
+        if ( nEntryTab == nTab )
+            AtFree(nPos);
+        else
+            ++nPos;
+    }
+
+    remove_if(maAnonDBs.begin(), maAnonDBs.end(), FindByTable(nTab));
+}
+
+void ScDBCollection::UpdateReference(UpdateRefMode eUpdateRefMode,
+                                SCCOL nCol1, SCROW nRow1, SCTAB nTab1,
+                                SCCOL nCol2, SCROW nRow2, SCTAB nTab2,
+                                SCsCOL nDx, SCsROW nDy, SCsTAB nDz )
+{
+    for (sal_uInt16 i=0; i<nCount; i++)
+    {
+        ((ScDBData*)pItems[i])->UpdateReference(
+            pDoc, eUpdateRefMode,
+            nCol1, nRow1, nTab1, nCol2, nRow2, nTab2, nDx, nDy, nDz);
+    }
+    ScDBData* pData = pDoc->GetAnonymousDBData(nTab1);
+    if (pData)
+    {
+        if (nTab1 == nTab2 && nDz == 0)
+        {
+            pData->UpdateReference(
+                pDoc, eUpdateRefMode,
+                nCol1, nRow1, nTab1, nCol2, nRow2, nTab2, nDx, nDy, nDz);
+        }
+        else
+        {
+            //this will perhabs break undo
+        }
+    }
+
+    UpdateRefFunc func(pDoc, eUpdateRefMode, nCol1, nRow1, nTab1, nCol2, nRow2, nTab2, nDx, nDy, nDz);
+    for_each(maAnonDBs.begin(), maAnonDBs.end(), func);
 }
 
 
-ScDBData* ScDBCollection::FindIndex(USHORT nIndex)
+void ScDBCollection::UpdateMoveTab( SCTAB nOldPos, SCTAB nNewPos )
 {
-    USHORT i = 0;
+    //	wenn nOldPos vor nNewPos liegt, ist nNewPos schon angepasst
+
+    for (sal_uInt16 i=0; i<nCount; i++)
+    {
+        ScDBData* pData = (ScDBData*)pItems[i];
+        pData->UpdateMoveTab(nOldPos, nNewPos);
+    }
+
+    UpdateMoveTabFunc func(nOldPos, nNewPos);
+    for_each(maAnonDBs.begin(), maAnonDBs.end(), func);
+}
+
+
+ScDBData* ScDBCollection::FindIndex(sal_uInt16 nIndex)
+{
+    sal_uInt16 i = 0;
     while (i < nCount)
     {
         if ((*this)[i]->GetIndex() == nIndex)
@@ -879,12 +932,12 @@ ScDBData* ScDBCollection::FindIndex(USHORT nIndex)
     return NULL;
 }
 
-BOOL ScDBCollection::Insert(ScDataObject* pScDataObject)
+sal_Bool ScDBCollection::Insert(ScDataObject* pScDataObject)
 {
     ScDBData* pData = (ScDBData*) pScDataObject;
     if (!pData->GetIndex())		// schon gesetzt?
         pData->SetIndex(nEntryIndex++);
-    BOOL bInserted = ScSortedCollection::Insert(pScDataObject);
+    sal_Bool bInserted = ScSortedCollection::Insert(pScDataObject);
     if ( bInserted && pData->HasImportParam() && !pData->HasImportSelection() )
     {
         pData->SetRefreshHandler( GetRefreshHandler() );
@@ -893,7 +946,73 @@ BOOL ScDBCollection::Insert(ScDataObject* pScDataObject)
     return bInserted;
 }
 
+ScDBData* ScDBCollection::GetDBNearCursor(SCCOL nCol, SCROW nRow, SCTAB nTab )
+{
+    ScDBData* pNearData = NULL;
+    SCTAB nAreaTab;
+    SCCOL nStartCol, nEndCol;
+    SCROW nStartRow, nEndRow;
+    for (sal_uInt16 i = 0; i < nCount; i++)
+    {
+        ScDBData* pDB = (ScDBData*)pItems[i];
+        pDB->GetArea( nAreaTab, nStartCol, nStartRow, nEndCol, nEndRow );
+        if ( nTab == nAreaTab && nCol+1 >= nStartCol && nCol <= nEndCol+1 &&
+                                 nRow+1 >= nStartRow && nRow <= nEndRow+1 )
+        {
+            if ( nCol < nStartCol || nCol > nEndCol || nRow < nStartRow || nRow > nEndRow )
+            {
+                if (!pNearData)
+                    pNearData = pDB;	// ersten angrenzenden Bereich merken
+            }
+            else
+                return pDB;				// nicht "unbenannt" und Cursor steht wirklich drin
+        }
+    }
+    if (pNearData)
+        return pNearData;				// angrenzender, wenn nichts direkt getroffen
+    return pDoc->GetAnonymousDBData(nTab);					// "unbenannt" nur zurueck, wenn sonst nichts gefunden
+}
 
+const ScDBData* ScDBCollection::findAnonAtCursor(SCCOL nCol, SCROW nRow, SCTAB nTab, bool bStartOnly) const
+{
+    AnonDBsType::const_iterator itr = find_if(
+        maAnonDBs.begin(), maAnonDBs.end(), FindByCursor(nCol, nRow, nTab, bStartOnly));
+    return itr == maAnonDBs.end() ? NULL : &(*itr);
+}
 
+const ScDBData* ScDBCollection::findAnonByRange(const ScRange& rRange) const
+{
+    AnonDBsType::const_iterator itr = find_if(
+        maAnonDBs.begin(), maAnonDBs.end(), FindByRange(rRange));
+    return itr == maAnonDBs.end() ? NULL : &(*itr);
+}
+
+ScDBData* ScDBCollection::getAnonByRange(const ScRange& rRange)
+{
+    const ScDBData* pData = findAnonByRange(rRange);
+    if (!pData)
+    {
+        // Insert a new db data.  They all have identical names.
+        rtl::OUString aName(RTL_CONSTASCII_USTRINGPARAM(STR_DB_GLOBAL_NONAME));
+        ::std::auto_ptr<ScDBData> pNew(new ScDBData(
+            aName, rRange.aStart.Tab(), rRange.aStart.Col(), rRange.aStart.Row(),
+            rRange.aEnd.Col(), rRange.aEnd.Row(), true, false));
+        pData = pNew.get();
+        maAnonDBs.push_back(pNew);
+    }
+    return const_cast<ScDBData*>(pData);
+}
+
+void ScDBCollection::insertAnonRange(ScDBData* pData)
+{
+    rtl::OUString aName(RTL_CONSTASCII_USTRINGPARAM(STR_DB_GLOBAL_NONAME));
+    ::std::auto_ptr<ScDBData> pNew(pData);
+    maAnonDBs.push_back(pNew);
+}
+
+const ScDBCollection::AnonDBsType& ScDBCollection::getAnonRanges() const
+{
+    return maAnonDBs;
+}
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
