@@ -33,16 +33,13 @@
 
 // INCLUDE ---------------------------------------------------------------
 
-#if STLPORT_VERSION<321
-#include <stddef.h>
-#else
 #include <cstddef>
-#endif
 #include <cstdio>
 
 #include <string.h>
 #include <tools/mempool.hxx>
 #include <tools/debug.hxx>
+#include <osl/diagnose.h>
 
 #include "token.hxx"
 #include "tokenarray.hxx"
@@ -109,10 +106,6 @@ namespace
     }
 //
 } // namespace
-// 
-// ImpTokenIterator wird je Interpreter angelegt, mehrfache auch durch
-// SubCode via FormulaTokenIterator Push/Pop moeglich
-IMPL_FIXEDMEMPOOL_NEWDEL( ImpTokenIterator, 32, 16 )
 
 // Align MemPools on 4k boundaries - 64 bytes (4k is a MUST for OS/2)
 
@@ -120,19 +113,19 @@ IMPL_FIXEDMEMPOOL_NEWDEL( ImpTokenIterator, 32, 16 )
 // ScRawToken size is FixMembers + MAXSTRLEN + ~4 ~= 1036
 IMPL_FIXEDMEMPOOL_NEWDEL( ScRawToken, 8, 4 )
 // Some ScDoubleRawToken, FixMembers + sizeof(double) ~= 16
-const USHORT nMemPoolDoubleRawToken = 0x0400 / sizeof(ScDoubleRawToken);
+const sal_uInt16 nMemPoolDoubleRawToken = 0x0400 / sizeof(ScDoubleRawToken);
 IMPL_FIXEDMEMPOOL_NEWDEL( ScDoubleRawToken, nMemPoolDoubleRawToken, nMemPoolDoubleRawToken )
 
 // Need a whole bunch of ScSingleRefToken
-const USHORT nMemPoolSingleRefToken = (0x4000 - 64) / sizeof(ScSingleRefToken);
+const sal_uInt16 nMemPoolSingleRefToken = (0x4000 - 64) / sizeof(ScSingleRefToken);
 IMPL_FIXEDMEMPOOL_NEWDEL( ScSingleRefToken, nMemPoolSingleRefToken, nMemPoolSingleRefToken )
 // Need quite a lot of ScDoubleRefToken
-const USHORT nMemPoolDoubleRefToken = (0x2000 - 64) / sizeof(ScDoubleRefToken);
+const sal_uInt16 nMemPoolDoubleRefToken = (0x2000 - 64) / sizeof(ScDoubleRefToken);
 IMPL_FIXEDMEMPOOL_NEWDEL( ScDoubleRefToken, nMemPoolDoubleRefToken, nMemPoolDoubleRefToken )
 
 // --- helpers --------------------------------------------------------------
 
-inline BOOL lcl_IsReference( OpCode eOp, StackVar eType )
+inline sal_Bool lcl_IsReference( OpCode eOp, StackVar eType )
 {
     return
         (eOp == ocPush && (eType == svSingleRef || eType == svDoubleRef))
@@ -231,12 +224,14 @@ void ScRawToken::SetDouble(double rVal)
     nRefCnt = 0;
 }
 
-void ScRawToken::SetName( USHORT n )
+void ScRawToken::SetName(bool bGlobal, sal_uInt16 nIndex)
 {
-    eOp    = ocName;
-    eType  = svIndex;
-    nIndex = n;
+    eOp = ocName;
+    eType = svIndex;
     nRefCnt = 0;
+
+    name.bGlobal = bGlobal;
+    name.nIndex = nIndex;
 }
 
 void ScRawToken::SetExternalSingleRef( sal_uInt16 nFileId, const String& rTabName, const ScSingleRefData& rRef )
@@ -296,13 +291,13 @@ void ScRawToken::SetExternal( const sal_Unicode* pStr )
     nRefCnt = 0;
 }
 
-USHORT lcl_ScRawTokenOffset()
+sal_uInt16 lcl_ScRawTokenOffset()
 {
     // offset of sbyte in ScRawToken
     // offsetof(ScRawToken, sbyte) gives a warning with gcc, because ScRawToken is no POD
 
     ScRawToken aToken;
-    return static_cast<USHORT>( reinterpret_cast<char*>(&aToken.sbyte) - reinterpret_cast<char*>(&aToken) );
+    return static_cast<sal_uInt16>( reinterpret_cast<char*>(&aToken.sbyte) - reinterpret_cast<char*>(&aToken) );
 }
 
 ScRawToken* ScRawToken::Clone() const
@@ -317,21 +312,21 @@ ScRawToken* ScRawToken::Clone() const
     }
     else
     {
-        static USHORT nOffset = lcl_ScRawTokenOffset();     // offset of sbyte
-        USHORT n = nOffset;
+        static sal_uInt16 nOffset = lcl_ScRawTokenOffset();     // offset of sbyte
+        sal_uInt16 n = nOffset;
 
         switch( eType )
         {
             case svSep:         break;
             case svByte:        n += sizeof(ScRawToken::sbyte); break;
             case svDouble:      n += sizeof(double); break;
-            case svString:      n = sal::static_int_cast<USHORT>( n + GetStrLenBytes( cStr ) + GetStrLenBytes( 1 ) ); break;
+            case svString:      n = sal::static_int_cast<sal_uInt16>( n + GetStrLenBytes( cStr ) + GetStrLenBytes( 1 ) ); break;
             case svSingleRef:
             case svDoubleRef:   n += sizeof(aRef); break;
             case svMatrix:      n += sizeof(ScMatrix*); break;
-            case svIndex:       n += sizeof(USHORT); break;
+            case svIndex:       n += sizeof(name); break;
             case svJump:        n += nJump[ 0 ] * 2 + 2; break;
-            case svExternal:    n = sal::static_int_cast<USHORT>( n + GetStrLenBytes( cStr+1 ) + GetStrLenBytes( 2 ) ); break;
+            case svExternal:    n = sal::static_int_cast<sal_uInt16>( n + GetStrLenBytes( cStr+1 ) + GetStrLenBytes( 2 ) ); break;
 
             // external references
             case svExternalSingleRef:
@@ -339,22 +334,22 @@ ScRawToken* ScRawToken::Clone() const
             case svExternalName:      n += sizeof(extname); break;
             default:
             {
-                DBG_ERROR1( "unknown ScRawToken::Clone() type %d", int(eType));
+                OSL_TRACE( "unknown ScRawToken::Clone() type %d", int(eType));
             }
         }
-        p = (ScRawToken*) new BYTE[ n ];
-        memcpy( p, this, n * sizeof(BYTE) );
+        p = (ScRawToken*) new sal_uInt8[ n ];
+        memcpy( p, this, n * sizeof(sal_uInt8) );
     }
     p->nRefCnt = 0;
-    p->bRaw = FALSE;
+    p->bRaw = false;
     return p;
 }
 
 
 FormulaToken* ScRawToken::CreateToken() const
 {
-#ifdef DBG_UTIL
-#define IF_NOT_OPCODE_ERROR(o,c) if (eOp!=o) DBG_ERROR1( #c "::ctor: OpCode %d lost, converted to " #o "; maybe inherit from FormulaToken instead!", int(eOp))
+#if OSL_DEBUG_LEVEL > 1
+#define IF_NOT_OPCODE_ERROR(o,c) if (eOp!=o) OSL_TRACE( #c "::ctor: OpCode %d lost, converted to " #o "; maybe inherit from FormulaToken instead!", int(eOp))
 #else
 #define IF_NOT_OPCODE_ERROR(o,c)
 #endif
@@ -384,7 +379,7 @@ FormulaToken* ScRawToken::CreateToken() const
             IF_NOT_OPCODE_ERROR( ocPush, ScMatrixToken);
             return new ScMatrixToken( pMat );
         case svIndex :
-            return new FormulaIndexToken( eOp, nIndex );
+            return new ScNameToken(name.nIndex, name.bGlobal);
         case svExternalSingleRef:
             {
                 String aTabName(extref.cTabName);
@@ -415,7 +410,7 @@ FormulaToken* ScRawToken::CreateToken() const
             return new FormulaUnknownToken( eOp );
         default:
             {
-                DBG_ERROR1( "unknown ScRawToken::CreateToken() type %d", int(GetType()));
+                OSL_TRACE( "unknown ScRawToken::CreateToken() type %d", int(GetType()));
                 return new FormulaUnknownToken( ocBad );
             }
     }
@@ -435,7 +430,7 @@ void ScRawToken::Delete()
                 delete (ScDoubleRawToken*) this;    // FixedMemPool ScDoubleRawToken
             break;
             default:
-                delete [] (BYTE*) this;
+                delete [] (sal_uInt8*) this;
         }
     }
 }
@@ -463,14 +458,14 @@ ScToken::~ScToken()
 }
 
 //  TextEqual: if same formula entered (for optimization in sort)
-BOOL ScToken::TextEqual( const FormulaToken& _rToken ) const
+bool ScToken::TextEqual( const FormulaToken& _rToken ) const
 {
     if ( eType == svSingleRef || eType == svDoubleRef )
     {
         //  in relative Refs only compare relative parts
 
         if ( eType != _rToken.GetType() || GetOpCode() != _rToken.GetOpCode() )
-            return FALSE;
+            return false;
 
         const ScToken& rToken = static_cast<const ScToken&>(_rToken);
         ScComplexRefData aTemp1;
@@ -511,27 +506,26 @@ BOOL ScToken::TextEqual( const FormulaToken& _rToken ) const
 }
 
 
-BOOL ScToken::Is3DRef() const
+bool ScToken::Is3DRef() const
 {
     switch ( eType )
     {
         case svDoubleRef :
             if ( GetSingleRef2().IsFlag3D() )
-                return TRUE;
+                return sal_True;
         //! fallthru
         case svSingleRef :
             if ( GetSingleRef().IsFlag3D() )
-                return TRUE;
+                return sal_True;
             break;
         default:
         {
             // added to avoid warnings
         }
     }
-    return FALSE;
+    return false;
 }
 
-// static
 FormulaTokenRef ScToken::ExtendRangeReference( FormulaToken & rTok1, FormulaToken & rTok2,
         const ScAddress & rPos, bool bReuseDoubleRef )
 {
@@ -753,7 +747,7 @@ void                    ScSingleRefToken::CalcAbsIfRel( const ScAddress& rPos )
                             { aSingleRef.CalcAbsIfRel( rPos ); }
 void                    ScSingleRefToken::CalcRelFromAbs( const ScAddress& rPos )
                             { aSingleRef.CalcRelFromAbs( rPos ); }
-BOOL ScSingleRefToken::operator==( const FormulaToken& r ) const
+bool ScSingleRefToken::operator==( const FormulaToken& r ) const
 {
     return FormulaToken::operator==( r ) && aSingleRef == static_cast<const ScToken&>(r).GetSingleRef();
 }
@@ -769,7 +763,7 @@ void                    ScDoubleRefToken::CalcAbsIfRel( const ScAddress& rPos )
                             { aDoubleRef.CalcAbsIfRel( rPos ); }
 void                    ScDoubleRefToken::CalcRelFromAbs( const ScAddress& rPos )
                             { aDoubleRef.CalcRelFromAbs( rPos ); }
-BOOL ScDoubleRefToken::operator==( const FormulaToken& r ) const
+bool ScDoubleRefToken::operator==( const FormulaToken& r ) const
 {
     return FormulaToken::operator==( r ) && aDoubleRef == static_cast<const ScToken&>(r).GetDoubleRef();
 }
@@ -787,15 +781,15 @@ void                    ScRefListToken::CalcRelFromAbs( const ScAddress& rPos )
     for (ScRefList::iterator it( aRefList.begin()); it != aRefList.end(); ++it)
         (*it).CalcRelFromAbs( rPos);
 }
-BOOL ScRefListToken::operator==( const FormulaToken& r ) const
+bool ScRefListToken::operator==( const FormulaToken& r ) const
 {
     return FormulaToken::operator==( r ) && &aRefList == static_cast<const ScToken&>(r).GetRefList();
 }
 
 
-const ScMatrix* ScMatrixToken::GetMatrix() const        { return pMatrix; }
-ScMatrix*       ScMatrixToken::GetMatrix()              { return pMatrix; }
-BOOL ScMatrixToken::operator==( const FormulaToken& r ) const
+const ScMatrix* ScMatrixToken::GetMatrix() const        { return pMatrix.get(); }
+ScMatrix*       ScMatrixToken::GetMatrix()              { return pMatrix.get(); }
+bool ScMatrixToken::operator==( const FormulaToken& r ) const
 {
     return FormulaToken::operator==( r ) && pMatrix == static_cast<const ScToken&>(r).GetMatrix();
 }
@@ -822,7 +816,7 @@ ScExternalSingleRefToken::~ScExternalSingleRefToken()
 {
 }
 
-USHORT ScExternalSingleRefToken::GetIndex() const
+sal_uInt16 ScExternalSingleRefToken::GetIndex() const
 {
     return mnFileId;
 }
@@ -852,7 +846,7 @@ void ScExternalSingleRefToken::CalcRelFromAbs( const ScAddress& rPos )
     maSingleRef.CalcRelFromAbs( rPos );
 }
 
-BOOL ScExternalSingleRefToken::operator ==( const FormulaToken& r ) const
+bool ScExternalSingleRefToken::operator ==( const FormulaToken& r ) const
 {
     if (!FormulaToken::operator==(r))
         return false;
@@ -888,7 +882,7 @@ ScExternalDoubleRefToken::~ScExternalDoubleRefToken()
 {
 }
 
-USHORT ScExternalDoubleRefToken::GetIndex() const
+sal_uInt16 ScExternalDoubleRefToken::GetIndex() const
 {
     return mnFileId;
 }
@@ -938,7 +932,7 @@ void ScExternalDoubleRefToken::CalcRelFromAbs( const ScAddress& rPos )
     maDoubleRef.CalcRelFromAbs( rPos );
 }
 
-BOOL ScExternalDoubleRefToken::operator ==( const FormulaToken& r ) const
+bool ScExternalDoubleRefToken::operator ==( const FormulaToken& r ) const
 {
     if (!ScToken::operator==(r))
         return false;
@@ -954,6 +948,37 @@ BOOL ScExternalDoubleRefToken::operator ==( const FormulaToken& r ) const
 
 // ============================================================================
 
+ScNameToken::ScNameToken(sal_uInt16 nIndex, bool bGlobal) :
+    ScToken(svIndex, ocName), mnIndex(nIndex), mbGlobal(bGlobal) {}
+
+ScNameToken::ScNameToken(const ScNameToken& r) :
+    ScToken(r), mnIndex(r.mnIndex), mbGlobal(r.mbGlobal) {}
+
+ScNameToken::~ScNameToken() {}
+
+sal_uInt8 ScNameToken::GetByte() const
+{
+    return static_cast<sal_uInt8>(mbGlobal);
+}
+
+sal_uInt16 ScNameToken::GetIndex() const
+{
+    return mnIndex;
+}
+
+bool ScNameToken::operator==( const FormulaToken& r ) const
+{
+    if ( !FormulaToken::operator==(r) )
+        return false;
+
+    if (mbGlobal != static_cast<bool>(r.GetByte()))
+        return false;
+
+    return mnIndex == r.GetIndex();
+}
+
+// ============================================================================
+
 ScExternalNameToken::ScExternalNameToken( sal_uInt16 nFileId, const String& rName ) :
     ScToken( svExternalName, ocPush),
     mnFileId(nFileId),
@@ -970,7 +995,7 @@ ScExternalNameToken::ScExternalNameToken( const ScExternalNameToken& r ) :
 
 ScExternalNameToken::~ScExternalNameToken() {}
 
-USHORT ScExternalNameToken::GetIndex() const
+sal_uInt16 ScExternalNameToken::GetIndex() const
 {
     return mnFileId;
 }
@@ -980,7 +1005,7 @@ const String& ScExternalNameToken::GetString() const
     return maName;
 }
 
-BOOL ScExternalNameToken::operator==( const FormulaToken& r ) const
+bool ScExternalNameToken::operator==( const FormulaToken& r ) const
 {
     if ( !FormulaToken::operator==(r) )
         return false;
@@ -1006,7 +1031,7 @@ BOOL ScExternalNameToken::operator==( const FormulaToken& r ) const
 // ============================================================================
 
 ScJumpMatrix* ScJumpMatrixToken::GetJumpMatrix() const  { return pJumpMatrix; }
-BOOL ScJumpMatrixToken::operator==( const FormulaToken& r ) const
+bool ScJumpMatrixToken::operator==( const FormulaToken& r ) const
 {
     return FormulaToken::operator==( r ) && pJumpMatrix == static_cast<const ScToken&>(r).GetJumpMatrix();
 }
@@ -1021,7 +1046,7 @@ const String &  ScEmptyCellToken::GetString() const
     static  String              aDummyString;
     return aDummyString; 
 }
-BOOL ScEmptyCellToken::operator==( const FormulaToken& r ) const
+bool ScEmptyCellToken::operator==( const FormulaToken& r ) const
 {
     return FormulaToken::operator==( r ) &&
         bInherited == static_cast< const ScEmptyCellToken & >(r).IsInherited() &&
@@ -1031,14 +1056,14 @@ BOOL ScEmptyCellToken::operator==( const FormulaToken& r ) const
 
 double          ScMatrixCellResultToken::GetDouble() const  { return xUpperLeft->GetDouble(); }
 const String &  ScMatrixCellResultToken::GetString() const  { return xUpperLeft->GetString(); }
-const ScMatrix* ScMatrixCellResultToken::GetMatrix() const  { return xMatrix; }
+const ScMatrix* ScMatrixCellResultToken::GetMatrix() const  { return xMatrix.get(); }
 // Non-const GetMatrix() is private and unused but must be implemented to
 // satisfy vtable linkage.
 ScMatrix* ScMatrixCellResultToken::GetMatrix()
 {
     return const_cast<ScMatrix*>(xMatrix.operator->());
 }
-BOOL ScMatrixCellResultToken::operator==( const FormulaToken& r ) const
+bool ScMatrixCellResultToken::operator==( const FormulaToken& r ) const
 {
     return FormulaToken::operator==( r ) &&
         xUpperLeft == static_cast<const ScMatrixCellResultToken &>(r).xUpperLeft &&
@@ -1046,7 +1071,7 @@ BOOL ScMatrixCellResultToken::operator==( const FormulaToken& r ) const
 }
 
 
-BOOL ScMatrixFormulaCellToken::operator==( const FormulaToken& r ) const
+bool ScMatrixFormulaCellToken::operator==( const FormulaToken& r ) const
 {
     const ScMatrixFormulaCellToken* p = dynamic_cast<const ScMatrixFormulaCellToken*>(&r);
     return p && ScMatrixCellResultToken::operator==( r ) &&
@@ -1098,7 +1123,7 @@ void ScMatrixFormulaCellToken::SetUpperLeftDouble( double f )
 
 double          ScHybridCellToken::GetDouble() const    { return fDouble; }
 const String &  ScHybridCellToken::GetString() const    { return aString; }
-BOOL ScHybridCellToken::operator==( const FormulaToken& r ) const
+bool ScHybridCellToken::operator==( const FormulaToken& r ) const
 {
     return FormulaToken::operator==( r ) &&
         fDouble == r.GetDouble() && aString == r.GetString() &&
@@ -1232,9 +1257,9 @@ bool ScTokenArray::AddFormulaToken(const com::sun::star::sheet::FormulaToken& _a
     }
     return bError;
 }
-BOOL ScTokenArray::ImplGetReference( ScRange& rRange, BOOL bValidOnly ) const
+sal_Bool ScTokenArray::ImplGetReference( ScRange& rRange, sal_Bool bValidOnly ) const
 {
-    BOOL bIs = FALSE;
+    sal_Bool bIs = false;
     if ( pCode && nLen == 1 )
     {
         const FormulaToken* pToken = pCode[0];
@@ -1260,14 +1285,14 @@ BOOL ScTokenArray::ImplGetReference( ScRange& rRange, BOOL bValidOnly ) const
     return bIs;
 }
 
-BOOL ScTokenArray::IsReference( ScRange& rRange ) const
+sal_Bool ScTokenArray::IsReference( ScRange& rRange ) const
 {
-    return ImplGetReference( rRange, FALSE );
+    return ImplGetReference( rRange, false );
 }
 
-BOOL ScTokenArray::IsValidReference( ScRange& rRange ) const
+sal_Bool ScTokenArray::IsValidReference( ScRange& rRange ) const
 {
-    return ImplGetReference( rRange, TRUE );
+    return ImplGetReference( rRange, sal_True );
 }
 
 ////////////////////////////////////////////////////////////////////////////
@@ -1307,7 +1332,7 @@ ScTokenArray* ScTokenArray::Clone() const
     {
         pp = p->pCode = new FormulaToken*[ nLen ];
         memcpy( pp, pCode, nLen * sizeof( ScToken* ) );
-        for( USHORT i = 0; i < nLen; i++, pp++ )
+        for( sal_uInt16 i = 0; i < nLen; i++, pp++ )
         {
             *pp = (*pp)->Clone();
             (*pp)->IncRef();
@@ -1317,14 +1342,14 @@ ScTokenArray* ScTokenArray::Clone() const
     {
         pp = p->pRPN = new FormulaToken*[ nRPN ];
         memcpy( pp, pRPN, nRPN * sizeof( ScToken* ) );
-        for( USHORT i = 0; i < nRPN; i++, pp++ )
+        for( sal_uInt16 i = 0; i < nRPN; i++, pp++ )
         {
             FormulaToken* t = *pp;
             if( t->GetRef() > 1 )
             {
                 FormulaToken** p2 = pCode;
-                USHORT nIdx = 0xFFFF;
-                for( USHORT j = 0; j < nLen; j++, p2++ )
+                sal_uInt16 nIdx = 0xFFFF;
+                for( sal_uInt16 j = 0; j < nLen; j++, p2++ )
                 {
                     if( *p2 == t )
                     {
@@ -1478,8 +1503,6 @@ FormulaToken* ScTokenArray::MergeArray( )
     if( nCol <= 0 || nRow <= 0 )
         return NULL;
 
-    // fprintf (stderr, "Array (cols = %d, rows = %d)\n", nCol, nRow );
-
     int nSign = 1;
     ScMatrix* pArray = new ScMatrix( nCol, nRow );
     for ( i = nStart, nCol = 0, nRow = 0 ; i < nLen ; i++ )
@@ -1531,7 +1554,7 @@ FormulaToken* ScTokenArray::MergeArray( )
         pCode[i] = NULL;
         t->DecRef();
     }
-    nLen = USHORT( nStart );
+    nLen = sal_uInt16( nStart );
     return AddMatrix( pArray );
 }
 
@@ -1540,7 +1563,7 @@ FormulaToken* ScTokenArray::MergeRangeReference( const ScAddress & rPos )
 {
     if (!pCode || !nLen)
         return NULL;
-    USHORT nIdx = nLen;
+    sal_uInt16 nIdx = nLen;
     FormulaToken *p1, *p2, *p3;      // ref, ocRange, ref
     // The actual types are checked in ExtendRangeReference().
     if (((p3 = PeekPrev(nIdx)) != 0) &&
@@ -1555,7 +1578,7 @@ FormulaToken* ScTokenArray::MergeRangeReference( const ScAddress & rPos )
             p2->DecRef();
             p3->DecRef();
             nLen -= 2;
-            pCode[ nLen-1 ] = p;
+            pCode[ nLen-1 ] = p.get();
             nRefs--;
         }
     }
@@ -1584,11 +1607,16 @@ FormulaToken* ScTokenArray::AddDoubleReference( const ScComplexRefData& rRef )
     return Add( new ScDoubleRefToken( rRef ) );
 }
 
-FormulaToken* ScTokenArray::AddMatrix( ScMatrix* p )
+FormulaToken* ScTokenArray::AddMatrix( const ScMatrixRef& p )
 {
     return Add( new ScMatrixToken( p ) );
 }
 
+FormulaToken* ScTokenArray::AddRangeName( sal_uInt16 n, bool bGlobal )
+{
+    return Add(new ScNameToken(n, bGlobal));
+}
+
 FormulaToken* ScTokenArray::AddExternalName( sal_uInt16 nFileId, const String& rName )
 {
     return Add( new ScExternalNameToken(nFileId, rName) );
@@ -1609,7 +1637,7 @@ FormulaToken* ScTokenArray::AddColRowName( const ScSingleRefData& rRef )
     return Add( new ScSingleRefToken( rRef, ocColRowName ) );
 }
 
-BOOL ScTokenArray::GetAdjacentExtendOfOuterFuncRefs( SCCOLROW& nExtend,
+sal_Bool ScTokenArray::GetAdjacentExtendOfOuterFuncRefs( SCCOLROW& nExtend,
         const ScAddress& rPos, ScDirection eDir )
 {
     SCCOL nCol = 0;
@@ -1620,40 +1648,40 @@ BOOL ScTokenArray::GetAdjacentExtendOfOuterFuncRefs( SCCOLROW& nExtend,
             if ( rPos.Row() < MAXROW )
                 nRow = (nExtend = rPos.Row()) + 1;
             else
-                return FALSE;
+                return false;
         break;
         case DIR_RIGHT :
             if ( rPos.Col() < MAXCOL )
                 nCol = static_cast<SCCOL>(nExtend = rPos.Col()) + 1;
             else
-                return FALSE;
+                return false;
         break;
         case DIR_TOP :
             if ( rPos.Row() > 0 )
                 nRow = (nExtend = rPos.Row()) - 1;
             else
-                return FALSE;
+                return false;
         break;
         case DIR_LEFT :
             if ( rPos.Col() > 0 )
                 nCol = static_cast<SCCOL>(nExtend = rPos.Col()) - 1;
             else
-                return FALSE;
+                return false;
         break;
         default:
             DBG_ERRORFILE( "unknown Direction" );
-            return FALSE;
+            return false;
     }
     if ( pRPN && nRPN )
     {
         FormulaToken* t = pRPN[nRPN-1];
         if ( t->GetType() == svByte )
         {
-            BYTE nParamCount = t->GetByte();
+            sal_uInt8 nParamCount = t->GetByte();
             if ( nParamCount && nRPN > nParamCount )
             {
-                BOOL bRet = FALSE;
-                USHORT nParam = nRPN - nParamCount - 1;
+                sal_Bool bRet = false;
+                sal_uInt16 nParam = nRPN - nParamCount - 1;
                 for ( ; nParam < nRPN-1; nParam++ )
                 {
                     FormulaToken* p = pRPN[nParam];
@@ -1670,7 +1698,7 @@ BOOL ScTokenArray::GetAdjacentExtendOfOuterFuncRefs( SCCOLROW& nExtend,
                                             && rRef.nRow > nExtend )
                                     {
                                         nExtend = rRef.nRow;
-                                        bRet = TRUE;
+                                        bRet = sal_True;
                                     }
                                 break;
                                 case DIR_RIGHT :
@@ -1679,7 +1707,7 @@ BOOL ScTokenArray::GetAdjacentExtendOfOuterFuncRefs( SCCOLROW& nExtend,
                                             > nExtend )
                                     {
                                         nExtend = rRef.nCol;
-                                        bRet = TRUE;
+                                        bRet = sal_True;
                                     }
                                 break;
                                 case DIR_TOP :
@@ -1687,7 +1715,7 @@ BOOL ScTokenArray::GetAdjacentExtendOfOuterFuncRefs( SCCOLROW& nExtend,
                                             && rRef.nRow < nExtend )
                                     {
                                         nExtend = rRef.nRow;
-                                        bRet = TRUE;
+                                        bRet = sal_True;
                                     }
                                 break;
                                 case DIR_LEFT :
@@ -1696,7 +1724,7 @@ BOOL ScTokenArray::GetAdjacentExtendOfOuterFuncRefs( SCCOLROW& nExtend,
                                             < nExtend )
                                     {
                                         nExtend = rRef.nCol;
-                                        bRet = TRUE;
+                                        bRet = sal_True;
                                     }
                                 break;
                             }
@@ -1713,7 +1741,7 @@ BOOL ScTokenArray::GetAdjacentExtendOfOuterFuncRefs( SCCOLROW& nExtend,
                                             && rRef.Ref2.nRow > nExtend )
                                     {
                                         nExtend = rRef.Ref2.nRow;
-                                        bRet = TRUE;
+                                        bRet = sal_True;
                                     }
                                 break;
                                 case DIR_RIGHT :
@@ -1722,7 +1750,7 @@ BOOL ScTokenArray::GetAdjacentExtendOfOuterFuncRefs( SCCOLROW& nExtend,
                                             > nExtend )
                                     {
                                         nExtend = rRef.Ref2.nCol;
-                                        bRet = TRUE;
+                                        bRet = sal_True;
                                     }
                                 break;
                                 case DIR_TOP :
@@ -1730,7 +1758,7 @@ BOOL ScTokenArray::GetAdjacentExtendOfOuterFuncRefs( SCCOLROW& nExtend,
                                             && rRef.Ref1.nRow < nExtend )
                                     {
                                         nExtend = rRef.Ref1.nRow;
-                                        bRet = TRUE;
+                                        bRet = sal_True;
                                     }
                                 break;
                                 case DIR_LEFT :
@@ -1739,7 +1767,7 @@ BOOL ScTokenArray::GetAdjacentExtendOfOuterFuncRefs( SCCOLROW& nExtend,
                                             < nExtend )
                                     {
                                         nExtend = rRef.Ref1.nCol;
-                                        bRet = TRUE;
+                                        bRet = sal_True;
                                     }
                                 break;
                             }
@@ -1755,14 +1783,14 @@ BOOL ScTokenArray::GetAdjacentExtendOfOuterFuncRefs( SCCOLROW& nExtend,
             }
         }
     }
-    return FALSE;
+    return false;
 }
 
 
 void ScTokenArray::ReadjustRelative3DReferences( const ScAddress& rOldPos,
         const ScAddress& rNewPos )
 {
-    for ( USHORT j=0; j<nLen; ++j )
+    for ( sal_uInt16 j=0; j<nLen; ++j )
     {
         switch ( pCode[j]->GetType() )
         {
