@@ -29,23 +29,22 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_sc.hxx"
 
-//------------------------------------------------------------------------
+#include <math.h>
 
-#include "scitems.hxx"
 #include <svl/zforlist.hxx>
+#include <tools/debug.hxx>
 
+#include "attrib.hxx"
+#include "cell.hxx"
 #include "dif.hxx"
+#include "docpool.hxx"
+#include "document.hxx"
 #include "filter.hxx"
 #include "fprogressbar.hxx"
-#include "scerrors.hxx"
-#include "document.hxx"
-#include "cell.hxx"
-#include "patattr.hxx"
-#include "docpool.hxx"
-#include "attrib.hxx"
 #include "ftools.hxx"
-
-#include <math.h>
+#include "patattr.hxx"
+#include "scerrors.hxx"
+#include "scitems.hxx"
 
 const sal_Unicode pKeyTABLE[]   = { 'T', 'A', 'B', 'L', 'E', 0 };
 const sal_Unicode pKeyVECTORS[] = { 'V', 'E', 'C', 'T', 'O', 'R', 'S', 0 };
@@ -62,23 +61,20 @@ const sal_Unicode pKey1_0[]     = { '1', ',', '0', 0 };
 
 
 FltError ScFormatFilterPluginImpl::ScImportDif( SvStream& rIn, ScDocument* pDoc, const ScAddress& rInsPos,
-                        const CharSet eVon, UINT32 nDifOption )
+                        const CharSet eVon, sal_uInt32 nDifOption )
 {
     DifParser	aDifParser( rIn, nDifOption, *pDoc, eVon );
 
-    const BOOL	bPlain = aDifParser.IsPlain();
+    const sal_Bool	bPlain = aDifParser.IsPlain();
 
     SCTAB		nBaseTab = rInsPos.Tab();
 
     TOPIC		eTopic = T_UNKNOWN;
-    BOOL		bSyntErrWarn = FALSE;
-    BOOL		bOverflowWarn = FALSE;
+    sal_Bool		bSyntErrWarn = false;
+    sal_Bool		bOverflowWarn = false;
 
     String&	    rData = aDifParser.aData;
-    BOOL		bData = FALSE;
-
-    SCCOL		nNumCols = 0;
-    SCROW		nNumRows = 0;
+    sal_Bool		bData = false;
 
     rIn.Seek( 0 );
 
@@ -97,7 +93,7 @@ FltError ScFormatFilterPluginImpl::ScImportDif( SvStream& rIn, ScDocument* pDoc,
             case T_TABLE:
             {
                 if( aDifParser.nVector != 0 || aDifParser.nVal != 1 )
-                    bSyntErrWarn = TRUE;
+                    bSyntErrWarn = sal_True;
                 if( bData )
                     pDoc->RenameTab( nBaseTab, rData );
             }
@@ -105,27 +101,19 @@ FltError ScFormatFilterPluginImpl::ScImportDif( SvStream& rIn, ScDocument* pDoc,
             case T_VECTORS:
             {
                 if( aDifParser.nVector != 0 )
-                    bSyntErrWarn = TRUE;
-                if( aDifParser.nVal > MAXCOL + 1 )
-                    nNumCols = SCCOL_MAX;
-                else
-                    nNumCols = static_cast<SCCOL>(aDifParser.nVal);
+                    bSyntErrWarn = true;
             }
                 break;
             case T_TUPLES:
             {
                 if( aDifParser.nVector != 0 )
-                    bSyntErrWarn = TRUE;
-                if( aDifParser.nVal > MAXROW + 1 )
-                    nNumRows = SCROW_MAX;
-                else
-                    nNumRows = static_cast<SCROW>(aDifParser.nVal);
+                    bSyntErrWarn = true;
             }
                 break;
             case T_DATA:
             {
                 if( aDifParser.nVector != 0 || aDifParser.nVal != 0 )
-                    bSyntErrWarn = TRUE;
+                    bSyntErrWarn = sal_True;
             }
                 break;
             case T_LABEL:
@@ -205,10 +193,10 @@ FltError ScFormatFilterPluginImpl::ScImportDif( SvStream& rIn, ScDocument* pDoc,
                             pCell = new ScStringCell( aTmp );
                         }
 
-                        pDoc->PutCell( nColCnt, nRowCnt, nBaseTab, pCell, ( BOOL ) TRUE );
+                        pDoc->PutCell( nColCnt, nRowCnt, nBaseTab, pCell, ( sal_Bool ) sal_True );
                     }
                     else
-                        bOverflowWarn = TRUE;
+                        bOverflowWarn = sal_True;
 
                     nColCnt++;
                     break;
@@ -221,11 +209,11 @@ FltError ScFormatFilterPluginImpl::ScImportDif( SvStream& rIn, ScDocument* pDoc,
                         if( rData.Len() > 0 )
                         {
                             pDoc->PutCell( nColCnt, nRowCnt, nBaseTab,
-                                ScBaseCell::CreateTextCell( rData, pDoc ), ( BOOL ) TRUE );
+                                ScBaseCell::CreateTextCell( rData, pDoc ), ( sal_Bool ) sal_True );
                         }
                     }
                     else
-                        bOverflowWarn = TRUE;
+                        bOverflowWarn = sal_True;
 
                     nColCnt++;
                     break;
@@ -234,7 +222,7 @@ FltError ScFormatFilterPluginImpl::ScImportDif( SvStream& rIn, ScDocument* pDoc,
                 case D_SYNT_ERROR:
                     break;
                 default:
-                    DBG_ERROR( "ScImportDif - missing enum" );
+                    OSL_FAIL( "ScImportDif - missing enum" );
             }
         }
 
@@ -255,7 +243,7 @@ FltError ScFormatFilterPluginImpl::ScImportDif( SvStream& rIn, ScDocument* pDoc,
 }
 
 
-DifParser::DifParser( SvStream& rNewIn, const UINT32 nOption, ScDocument& rDoc, CharSet e ) :
+DifParser::DifParser( SvStream& rNewIn, const sal_uInt32 nOption, ScDocument& rDoc, CharSet e ) :
     rIn( rNewIn )
 {
     eCharSet = e;
@@ -264,8 +252,7 @@ DifParser::DifParser( SvStream& rNewIn, const UINT32 nOption, ScDocument& rDoc,
         DBG_ERRORFILE( "CharSet passed overrides and modifies StreamCharSet" );
         rIn.SetStreamCharSet( eCharSet );
     }
-    if ( eCharSet == RTL_TEXTENCODING_UNICODE )
-        rIn.StartReadingUnicodeText();
+    rIn.StartReadingUnicodeText( eCharSet );
 
     bPlain = ( nOption == SC_DIFOPT_PLAIN );
 
@@ -347,8 +334,8 @@ TOPIC DifParser::GetNextTopic( void )
             case S_START:
             {
                 const sal_Unicode*	pRef;
-                UINT16			nCnt = 0;
-                BOOL			bSearch = TRUE;
+                sal_uInt16			nCnt = 0;
+                sal_Bool			bSearch = sal_True;
 
                 pRef = ppKeys[ nCnt ];
 
@@ -357,14 +344,14 @@ TOPIC DifParser::GetNextTopic( void )
                     if( aLine == pRef )
                     {
                         eRet = pTopics[ nCnt ];
-                        bSearch = FALSE;
+                        bSearch = false;
                     }
                     else
                     {
                         nCnt++;
                         pRef = ppKeys[ nCnt ];
                         if( !*pRef )
-                            bSearch = FALSE;
+                            bSearch = false;
                     }
                 }
 
@@ -628,7 +615,7 @@ DATASET	DifParser::GetNextDataset( void )
 }
 
 
-const sal_Unicode* DifParser::ScanIntVal( const sal_Unicode* pStart, UINT32& rRet )
+const sal_Unicode* DifParser::ScanIntVal( const sal_Unicode* pStart, sal_uInt32& rRet )
 {
     // eat leading whitespace, not specified, but seen in the wild
     while (*pStart == ' ' || *pStart == '\t')
@@ -637,7 +624,7 @@ const sal_Unicode* DifParser::ScanIntVal( const sal_Unicode* pStart, UINT32& rRe
     sal_Unicode		cAkt = *pStart;
 
     if( IsNumber( cAkt ) )
-        rRet = ( UINT32 ) ( cAkt - '0' );
+        rRet = ( sal_uInt32 ) ( cAkt - '0' );
     else
         return NULL;
 
@@ -647,7 +634,7 @@ const sal_Unicode* DifParser::ScanIntVal( const sal_Unicode* pStart, UINT32& rRe
     while( IsNumber( cAkt ) && rRet < ( 0xFFFFFFFF / 10 ) )
     {
         rRet *= 10;
-        rRet += ( UINT32 ) ( cAkt - '0' );
+        rRet += ( sal_uInt32 ) ( cAkt - '0' );
 
         pStart++;
         cAkt = *pStart;
@@ -657,18 +644,18 @@ const sal_Unicode* DifParser::ScanIntVal( const sal_Unicode* pStart, UINT32& rRe
 }
 
 
-BOOL DifParser::ScanFloatVal( const sal_Unicode* pStart )
+sal_Bool DifParser::ScanFloatVal( const sal_Unicode* pStart )
     {
     double					fNewVal = 0.0;
-    BOOL					bNeg = FALSE;
+    sal_Bool					bNeg = false;
     double                  fFracPos = 1.0;
-    INT32					nExp = 0;
-    BOOL					bExpNeg = FALSE;
-    BOOL					bExpOverflow = FALSE;
-    static const UINT16		nExpLimit = 4096;	// ACHTUNG: muss genauer ermittelt werden!
+    sal_Int32					nExp = 0;
+    sal_Bool					bExpNeg = false;
+    sal_Bool					bExpOverflow = false;
+    static const sal_uInt16		nExpLimit = 4096;	// ACHTUNG: muss genauer ermittelt werden!
 
     sal_Unicode				cAkt;
-    BOOL					bRet = FALSE;
+    sal_Bool					bRet = false;
 
     enum STATE { S_FIRST, S_PRE, S_POST, S_EXP_FIRST, S_EXP, S_END, S_FINDEND };
 
@@ -729,7 +716,7 @@ BOOL DifParser::ScanFloatVal( const sal_Unicode* pStart )
                             eS = S_EXP;
                             break;
                         case 0x00:				// IsNumberEnding( cAkt )
-                            bRet = TRUE;		// no
+                            bRet = sal_True;		// no
                         default:				// break!
                             eS = S_END;
                     }
@@ -750,7 +737,7 @@ BOOL DifParser::ScanFloatVal( const sal_Unicode* pStart )
                             eS = S_EXP_FIRST;
                             break;
                         case 0x00:				// IsNumberEnding( cAkt )
-                            bRet = TRUE;		// no
+                            bRet = sal_True;		// no
                         default:				// break!
                             eS = S_END;
                     }
@@ -762,7 +749,7 @@ BOOL DifParser::ScanFloatVal( const sal_Unicode* pStart )
                     if( nExp < nExpLimit )
                     {
                         nExp *= 10;
-                        nExp += ( UINT16 ) ( cAkt - '0' );
+                        nExp += ( sal_uInt16 ) ( cAkt - '0' );
                     }
                     eS = S_EXP;
                 }
@@ -786,11 +773,11 @@ BOOL DifParser::ScanFloatVal( const sal_Unicode* pStart )
                     if( nExp < ( 0xFFFF / 10 ) )
                     {
                         nExp *= 10;
-                        nExp += ( UINT16 ) ( cAkt - '0' );
+                        nExp += ( sal_uInt16 ) ( cAkt - '0' );
                     }
                     else
                     {
-                        bExpOverflow = TRUE;
+                        bExpOverflow = sal_True;
                         eS = S_FINDEND;
                     }
                 }
@@ -803,7 +790,7 @@ BOOL DifParser::ScanFloatVal( const sal_Unicode* pStart )
             case S_FINDEND:
                 if( IsNumberEnding( cAkt ) )
                 {
-                    bRet = TRUE;		// damit sinnvoll weitergeparst werden kann
+                    bRet = sal_True;		// damit sinnvoll weitergeparst werden kann
                     eS = S_END;
                 }
                 break;
@@ -819,7 +806,7 @@ BOOL DifParser::ScanFloatVal( const sal_Unicode* pStart )
     if( bRet )
     {
         if( bExpOverflow )
-            return sal_False;		// ACHTUNG: hier muss noch differenziert werden
+            return false;		// ACHTUNG: hier muss noch differenziert werden
 
         if( bNeg )
             fNewVal *= 1.0;
@@ -835,19 +822,11 @@ BOOL DifParser::ScanFloatVal( const sal_Unicode* pStart )
     return bRet;
 }
 
-
-DifColumn::~DifColumn( void )
+DifColumn::DifColumn ()
+    : pAkt(NULL)
 {
-    ENTRY*  pEntry = ( ENTRY* ) List::First();
-
-    while( pEntry )
-    {
-        delete pEntry;
-        pEntry = ( ENTRY* ) List::Next();
-    }
 }
 
-
 void DifColumn::SetLogical( SCROW nRow )
 {
     DBG_ASSERT( ValidRow(nRow), "*DifColumn::SetLogical(): Row zu gross!" );
@@ -855,7 +834,9 @@ void DifColumn::SetLogical( SCROW nRow )
     if( pAkt )
     {
         DBG_ASSERT( nRow > 0, "*DifColumn::SetLogical(): weitere koennen nicht 0 sein!" );
+
         nRow--;
+
         if( pAkt->nEnd == nRow )
             pAkt->nEnd++;
         else
@@ -865,18 +846,19 @@ void DifColumn::SetLogical( SCROW nRow )
     {
         pAkt = new ENTRY;
         pAkt->nStart = pAkt->nEnd = nRow;
-        List::Insert( pAkt, LIST_APPEND );
+
+        aEntries.push_back(pAkt);
     }
 }
 
 
-void DifColumn::SetNumFormat( SCROW nRow, const UINT32 nNumFormat )
+void DifColumn::SetNumFormat( SCROW nRow, const sal_uInt32 nNumFormat )
 {
     DBG_ASSERT( ValidRow(nRow), "*DifColumn::SetNumFormat(): Row zu gross!" );
 
     if( nNumFormat > 0 )
     {
-        if( pAkt )
+        if(pAkt)
         {
             DBG_ASSERT( nRow > 0,
                 "*DifColumn::SetNumFormat(): weitere koennen nicht 0 sein!" );
@@ -887,60 +869,52 @@ void DifColumn::SetNumFormat( SCROW nRow, const UINT32 nNumFormat )
                 pAkt->nEnd = nRow;
             else
                 NewEntry( nRow, nNumFormat );
-            }
-        else
-            NewEntry( nRow, nNumFormat );
         }
+        else
+            NewEntry(nRow,nNumFormat );
+    }
     else
         pAkt = NULL;
 }
 
 
-void DifColumn::NewEntry( const SCROW nPos, const UINT32 nNumFormat )
+void DifColumn::NewEntry( const SCROW nPos, const sal_uInt32 nNumFormat )
 {
     pAkt = new ENTRY;
     pAkt->nStart = pAkt->nEnd = nPos;
     pAkt->nNumFormat = nNumFormat;
-    List::Insert( pAkt, LIST_APPEND );
+
+    aEntries.push_back(pAkt);
 }
 
 
 void DifColumn::Apply( ScDocument& rDoc, const SCCOL nCol, const SCTAB nTab, const ScPatternAttr& rPattAttr )
 {
-    ENTRY*  pEntry = ( ENTRY* ) List::First();
-
-    while( pEntry )
-    {
-        rDoc.ApplyPatternAreaTab( nCol, pEntry->nStart, nCol, pEntry->nEnd,
-                nTab, rPattAttr );
-        pEntry = ( ENTRY* ) List::Next();
-    }
+    for (boost::ptr_vector<ENTRY>::const_iterator it = aEntries.begin(); it != aEntries.end(); ++it)
+        rDoc.ApplyPatternAreaTab( nCol, it->nStart, nCol, it->nEnd, nTab, rPattAttr );
 }
 
 
 void DifColumn::Apply( ScDocument& rDoc, const SCCOL nCol, const SCTAB nTab )
 {
-    ScPatternAttr	aAttr( rDoc.GetPool() );
-    SfxItemSet&		rItemSet = aAttr.GetItemSet();
+    ScPatternAttr aAttr( rDoc.GetPool() );
+    SfxItemSet &rItemSet = aAttr.GetItemSet();
 
-    ENTRY*          pEntry = ( ENTRY* ) List::First();
-
-    while( pEntry )
-        {
-        DBG_ASSERT( pEntry->nNumFormat > 0,
+    for (boost::ptr_vector<ENTRY>::const_iterator it = aEntries.begin(); it != aEntries.end(); ++it)
+    {
+        DBG_ASSERT( it->nNumFormat > 0,
             "+DifColumn::Apply(): Numberformat darf hier nicht 0 sein!" );
-        rItemSet.Put( SfxUInt32Item( ATTR_VALUE_FORMAT, pEntry->nNumFormat ) );
 
-        rDoc.ApplyPatternAreaTab( nCol, pEntry->nStart, nCol, pEntry->nEnd, nTab, aAttr );
+        rItemSet.Put( SfxUInt32Item( ATTR_VALUE_FORMAT, it->nNumFormat ) );
+
+        rDoc.ApplyPatternAreaTab( nCol, it->nStart, nCol, it->nEnd, nTab, aAttr );
 
         rItemSet.ClearItem();
-
-        pEntry = ( ENTRY* ) List::Next();
     }
 }
 
 
-DifAttrCache::DifAttrCache( const BOOL bNewPlain )
+DifAttrCache::DifAttrCache( const sal_Bool bNewPlain )
 {
     bPlain = bNewPlain;
     ppCols = new DifColumn *[ MAXCOL + 1 ];
@@ -958,8 +932,18 @@ DifAttrCache::~DifAttrCache()
     }
 }
 
+void DifAttrCache::SetLogical( const SCCOL nCol, const SCROW nRow )
+{
+    DBG_ASSERT( ValidCol(nCol), "-DifAttrCache::SetLogical(): Col zu gross!" );
+    DBG_ASSERT( bPlain, "*DifAttrCache::SetLogical(): muss Plain sein!" );
 
-void DifAttrCache::SetNumFormat( const SCCOL nCol, const SCROW nRow, const UINT32 nNumFormat )
+    if( !ppCols[ nCol ] )
+        ppCols[ nCol ] = new DifColumn;
+
+    ppCols[ nCol ]->SetLogical( nRow );
+}
+
+void DifAttrCache::SetNumFormat( const SCCOL nCol, const SCROW nRow, const sal_uInt32 nNumFormat )
 {
     DBG_ASSERT( ValidCol(nCol), "-DifAttrCache::SetNumFormat(): Col zu gross!" );
     DBG_ASSERT( !bPlain, "*DifAttrCache::SetNumFormat(): sollte nicht Plain sein!" );
