@@ -89,7 +89,7 @@
 #include "excimp8.hxx"
 #include "excform.hxx"
 
-#if defined( WNT ) || defined( WIN )
+#if defined( WNT )
 #include <math.h>
 #else
 #include <stdlib.h>
@@ -139,7 +139,7 @@ ImportExcel::ImportExcel( XclImpRootData& rImpData, SvStream& rStrm ):
     pExcRoot->pShrfmlaBuff = new ShrfmlaBuffer( pExcRoot );		//&aShrfrmlaBuff;
     pExcRoot->pExtNameBuff = new ExtNameBuff ( *this );
 
-    pExtNameBuff = new NameBuffer( pExcRoot );          //#94039# prevent empty rootdata
+    pExtNameBuff = new NameBuffer( pExcRoot );          //prevent empty rootdata
     pExtNameBuff->SetBase( 1 );
 
     pOutlineListBuffer = new XclImpOutlineListBuffer( );
@@ -147,7 +147,7 @@ ImportExcel::ImportExcel( XclImpRootData& rImpData, SvStream& rStrm ):
     // ab Biff8
     pFormConv = pExcRoot->pFmlaConverter = new ExcelToSc( GetRoot() );
 
-    bTabTruncated = FALSE;
+    bTabTruncated = false;
 
     // Excel-Dokument per Default auf 31.12.1899, entspricht Excel-Einstellungen mit 1.1.1900
     ScDocOptions aOpt = pD->GetDocOptions();
@@ -156,9 +156,9 @@ ImportExcel::ImportExcel( XclImpRootData& rImpData, SvStream& rStrm ):
     pD->GetFormatTable()->ChangeNullDate( 30, 12, 1899 );
 
     ScDocOptions aDocOpt( pD->GetDocOptions() );
-    aDocOpt.SetIgnoreCase( TRUE );              // always in Excel
-    aDocOpt.SetFormulaRegexEnabled( FALSE );    // regular expressions? what's that?
-    aDocOpt.SetLookUpColRowNames( FALSE );      // default: no natural language refs
+    aDocOpt.SetIgnoreCase( sal_True );              // always in Excel
+    aDocOpt.SetFormulaRegexEnabled( false );    // regular expressions? what's that?
+    aDocOpt.SetLookUpColRowNames( false );      // default: no natural language refs
     pD->SetDocOptions( aDocOpt );
 }
 
@@ -183,7 +183,7 @@ void ImportExcel::ReadFileSharing()
     if( (nRecommendReadOnly != 0) || (nPasswordHash != 0) )
     {
         if( SfxItemSet* pItemSet = GetMedium().GetItemSet() )
-            pItemSet->Put( SfxBoolItem( SID_DOC_READONLY, TRUE ) );
+            pItemSet->Put( SfxBoolItem( SID_DOC_READONLY, sal_True ) );
             
         if( SfxObjectShell* pShell = GetDocShell() )
         {
@@ -384,7 +384,7 @@ void ImportExcel::Window1()
 
 void ImportExcel::Row25( void )
 {
-    UINT16	nRow, nRowHeight;
+    sal_uInt16	nRow, nRowHeight;
 
     aIn >> nRow;
     aIn.Ignore( 4 );   // Mic und Mac ueberspringen
@@ -400,7 +400,7 @@ void ImportExcel::Row25( void )
         }
         else
         {// -------------------- BIFF5
-            UINT16	nGrbit;
+            sal_uInt16	nGrbit;
 
             aIn.Ignore( 2 );   // reserved
             aIn >> nGrbit;
@@ -467,8 +467,8 @@ void ImportExcel:: WinProtection( void )
 
 void ImportExcel::Columndefault( void )
 {// Default Cell Attributes
-    UINT16	nColMic, nColMac;
-    BYTE	nOpt0;
+    sal_uInt16	nColMic, nColMac;
+    sal_uInt8	nOpt0;
 
     aIn >> nColMic >> nColMac;
 
@@ -478,9 +478,9 @@ void ImportExcel::Columndefault( void )
     nColMac--;
 
     if( nColMac > MAXCOL )
-        nColMac = static_cast<UINT16>(MAXCOL);
+        nColMac = static_cast<sal_uInt16>(MAXCOL);
 
-    for( UINT16 nCol = nColMic ; nCol <= nColMac ; nCol++ )
+    for( sal_uInt16 nCol = nColMic ; nCol <= nColMac ; nCol++ )
     {
         aIn >> nOpt0;
         aIn.Ignore( 2 );   // nur 0. Attribut-Byte benutzt
@@ -493,8 +493,8 @@ void ImportExcel::Columndefault( void )
 
 void ImportExcel::Array25( void )
 {
-    UINT16		nFirstRow, nLastRow, nFormLen;
-    BYTE		nFirstCol, nLastCol;
+    sal_uInt16		nFirstRow, nLastRow, nFormLen;
+    sal_uInt8		nFirstCol, nLastCol;
 
     aIn >> nFirstRow >> nLastRow >> nFirstCol >> nLastCol;
 
@@ -532,7 +532,7 @@ void ImportExcel::Array25( void )
 
 void ImportExcel::Rec1904( void )
 {
-    UINT16	n1904;
+    sal_uInt16	n1904;
 
     aIn >> n1904;
 
@@ -548,12 +548,12 @@ void ImportExcel::Rec1904( void )
 
 void ImportExcel::Externname25( void )
 {
-    UINT32		nRes;
-    UINT16		nOpt;
+    sal_uInt32		nRes;
+    sal_uInt16		nOpt;
 
     aIn >> nOpt >> nRes;
 
-    String aName( aIn.ReadByteString( FALSE ) );
+    String aName( aIn.ReadByteString( false ) );
 
     if( ( nOpt & 0x0001 ) || ( ( nOpt & 0xFFFE ) == 0x0000 ) )
     {// external name
@@ -573,16 +573,16 @@ void ImportExcel::Externname25( void )
 
 void ImportExcel::Colwidth( void )
 {// Column Width
-    BYTE	nColFirst, nColLast;
-    UINT16	nColWidth;
+    sal_uInt8	nColFirst, nColLast;
+    sal_uInt16	nColWidth;
 
     aIn >> nColFirst >> nColLast >> nColWidth;
 
 //! TODO: add a check for the unlikely case of changed MAXCOL (-> XclImpAddressConverter)
 //   if( nColLast > MAXCOL )
-//       nColLast = static_cast<UINT16>(MAXCOL);
+//       nColLast = static_cast<sal_uInt16>(MAXCOL);
 
-    USHORT nScWidth = XclTools::GetScColumnWidth( nColWidth, GetCharWidth() );
+    sal_uInt16 nScWidth = XclTools::GetScColumnWidth( nColWidth, GetCharWidth() );
     pColRowBuff->SetWidthRange( nColFirst, nColLast, nScWidth );
 }
 
@@ -641,7 +641,7 @@ void ImportExcel::DefColWidth( void )
     long nFontHt = GetFontBuffer().GetAppFontData().mnHeight;
     fDefWidth += XclTools::GetXclDefColWidthCorrection( nFontHt );
 
-    USHORT nScWidth = XclTools::GetScColumnWidth( limit_cast< sal_uInt16 >( fDefWidth ), GetCharWidth() );
+    sal_uInt16 nScWidth = XclTools::GetScColumnWidth( limit_cast< sal_uInt16 >( fDefWidth ), GetCharWidth() );
     pColRowBuff->SetDefWidth( nScWidth );
 }
 
@@ -653,8 +653,8 @@ void ImportExcel::Builtinfmtcnt( void )
 
 void ImportExcel::Colinfo( void )
 {// Column Formatting Information
-    UINT16	nColFirst, nColLast, nColWidth, nXF;
-    UINT16	nOpt;
+    sal_uInt16	nColFirst, nColLast, nColWidth, nXF;
+    sal_uInt16	nOpt;
 
     aIn >> nColFirst >> nColLast >> nColWidth >> nXF >> nOpt;
 
@@ -662,7 +662,7 @@ void ImportExcel::Colinfo( void )
         return;
 
     if( nColLast > MAXCOL )
-        nColLast = static_cast<UINT16>(MAXCOL);
+        nColLast = static_cast<sal_uInt16>(MAXCOL);
 
     bool bHidden = ::get_flag( nOpt, EXC_COLINFO_HIDDEN );
     bool bCollapsed = ::get_flag( nOpt, EXC_COLINFO_COLLAPSED );
@@ -672,7 +672,7 @@ void ImportExcel::Colinfo( void )
     if( bHidden )
         pColRowBuff->HideColRange( nColFirst, nColLast );
 
-    USHORT nScWidth = XclTools::GetScColumnWidth( nColWidth, GetCharWidth() );
+    sal_uInt16 nScWidth = XclTools::GetScColumnWidth( nColWidth, GetCharWidth() );
     pColRowBuff->SetWidthRange( nColFirst, nColLast, nScWidth );
     pColRowBuff->SetDefaultXF( nColFirst, nColLast, nXF );
 }
@@ -680,7 +680,7 @@ void ImportExcel::Colinfo( void )
 
 void ImportExcel::Wsbool( void )
 {
-    UINT16 nFlags;
+    sal_uInt16 nFlags;
     aIn >> nFlags;
 
     pRowOutlineBuff->SetButtonMode( ::get_flag( nFlags, EXC_WSBOOL_ROWBELOW ) );
@@ -692,7 +692,7 @@ void ImportExcel::Wsbool( void )
 
 void ImportExcel::Boundsheet( void )
 {
-    UINT16 nGrbit = 0;
+    sal_uInt16 nGrbit = 0;
 
     if( GetBiff() == EXC_BIFF5 )
     {
@@ -702,7 +702,7 @@ void ImportExcel::Boundsheet( void )
         aIn >> nGrbit;
     }
 
-    String aName( aIn.ReadByteString( FALSE ) );
+    String aName( aIn.ReadByteString( false ) );
 
     SCTAB nScTab = static_cast< SCTAB >( nBdshtTab );
     if( nScTab > 0 )
@@ -712,7 +712,7 @@ void ImportExcel::Boundsheet( void )
     }
 
     if( ( nGrbit & 0x0001 ) || ( nGrbit & 0x0002 ) )
-        pD->SetVisible( nScTab, FALSE );
+        pD->SetVisible( nScTab, false );
 
     if( !pD->RenameTab( nScTab, aName ) )
     {
@@ -746,7 +746,7 @@ void ImportExcel::ReadUsesElfs()
     if( maStrm.ReaduInt16() != 0 )
     {
         ScDocOptions aDocOpt = GetDoc().GetDocOptions();
-        aDocOpt.SetLookUpColRowNames( TRUE );
+        aDocOpt.SetLookUpColRowNames( sal_True );
         GetDoc().SetDocOptions( aDocOpt );
     }
 }
@@ -754,7 +754,7 @@ void ImportExcel::ReadUsesElfs()
 
 void ImportExcel::Hideobj( void )
 {
-    UINT16		nHide;
+    sal_uInt16		nHide;
     ScVObjMode	eOle, eChart, eDraw;
 
     aIn >> nHide;
@@ -795,15 +795,15 @@ void ImportExcel::Bundleheader( void )
 
 void ImportExcel::Standardwidth( void )
 {
-    USHORT nScWidth = XclTools::GetScColumnWidth( maStrm.ReaduInt16(), GetCharWidth() );
-    pColRowBuff->SetDefWidth( nScWidth, TRUE );
+    sal_uInt16 nScWidth = XclTools::GetScColumnWidth( maStrm.ReaduInt16(), GetCharWidth() );
+    pColRowBuff->SetDefWidth( nScWidth, sal_True );
 }
 
 
 void ImportExcel::Shrfmla( void )
 {
-    UINT16				nFirstRow, nLastRow, nLenExpr;
-    BYTE				nFirstCol, nLastCol;
+    sal_uInt16				nFirstRow, nLastRow, nLenExpr;
+    sal_uInt8				nFirstCol, nLastCol;
 
     aIn >> nFirstRow >> nLastRow >> nFirstCol >> nLastCol;
     aIn.Ignore( 2 );
@@ -829,8 +829,8 @@ void ImportExcel::Shrfmla( void )
 void ImportExcel::Mulrk( void )
 {
     XclAddress aXclPos;
-    UINT16  nXF;
-    INT32   nRkNum;
+    sal_uInt16  nXF;
+    sal_Int32   nRkNum;
 
     aIn >> aXclPos;
 
@@ -851,7 +851,7 @@ void ImportExcel::Mulrk( void )
 void ImportExcel::Mulblank( void )
 {
     XclAddress aXclPos;
-    UINT16  nXF;
+    sal_uInt16  nXF;
 
     aIn >> aXclPos;
 
@@ -927,7 +927,7 @@ void ImportExcel::Olesize( void )
 
 void ImportExcel::Row34( void )
 {
-    UINT16	nRow, nRowHeight, nGrbit, nXF;
+    sal_uInt16	nRow, nRowHeight, nGrbit, nXF;
 
     aIn >> nRow;
     aIn.Ignore( 4 );   // Mic und Mac ueberspringen
@@ -972,8 +972,8 @@ void ImportExcel::Bof3( void )
 
 void ImportExcel::Array34( void )
 {
-    UINT16					nFirstRow, nLastRow, nFormLen;
-    BYTE					nFirstCol, nLastCol;
+    sal_uInt16					nFirstRow, nLastRow, nFormLen;
+    sal_uInt8					nFirstCol, nLastCol;
 
     aIn >> nFirstRow >> nLastRow >> nFirstCol >> nLastCol;
     aIn.Ignore( (GetBiff() >= EXC_BIFF5) ? 6 : 2 );
@@ -1015,10 +1015,10 @@ void ImportExcel::Defrowheight345( void )
 
 void ImportExcel::TableOp( void )
 {
-    UINT16 nFirstRow, nLastRow;
-    UINT8 nFirstCol, nLastCol;
-    UINT16 nGrbit;
-    UINT16 nInpRow, nInpCol, nInpRow2, nInpCol2;
+    sal_uInt16 nFirstRow, nLastRow;
+    sal_uInt8 nFirstCol, nLastCol;
+    sal_uInt16 nGrbit;
+    sal_uInt16 nInpRow, nInpCol, nInpRow2, nInpCol2;
 
     aIn >> nFirstRow >> nLastRow >> nFirstCol >> nLastCol >> nGrbit
         >> nInpRow >> nInpCol >> nInpRow2 >> nInpCol2;
@@ -1029,50 +1029,50 @@ void ImportExcel::TableOp( void )
         {
             ScTabOpParam aTabOpParam;
             aTabOpParam.nMode = (nGrbit & EXC_TABLEOP_BOTH) ? 2 : ((nGrbit & EXC_TABLEOP_ROW) ? 1 : 0 );
-            USHORT nCol = nFirstCol - 1;
-            USHORT nRow = nFirstRow - 1;
+            sal_uInt16 nCol = nFirstCol - 1;
+            sal_uInt16 nRow = nFirstRow - 1;
             SCTAB nTab = GetCurrScTab();
             switch( aTabOpParam.nMode )
             {
                 case 0:		// COL
                     aTabOpParam.aRefFormulaCell.Set(
                             static_cast<SCCOL>(nFirstCol),
-                            static_cast<SCROW>(nFirstRow - 1), nTab, FALSE,
-                            FALSE, FALSE );
+                            static_cast<SCROW>(nFirstRow - 1), nTab, false,
+                            false, false );
                     aTabOpParam.aRefFormulaEnd.Set(
                             static_cast<SCCOL>(nLastCol),
-                            static_cast<SCROW>(nFirstRow - 1), nTab, FALSE,
-                            FALSE, FALSE );
+                            static_cast<SCROW>(nFirstRow - 1), nTab, false,
+                            false, false );
                     aTabOpParam.aRefColCell.Set( static_cast<SCCOL>(nInpCol),
-                            static_cast<SCROW>(nInpRow), nTab, FALSE, FALSE,
-                            FALSE );
+                            static_cast<SCROW>(nInpRow), nTab, false, false,
+                            false );
                     nRow++;
                 break;
                 case 1:		// ROW
                     aTabOpParam.aRefFormulaCell.Set(
                             static_cast<SCCOL>(nFirstCol - 1),
-                            static_cast<SCROW>(nFirstRow), nTab, FALSE, FALSE,
-                            FALSE );
+                            static_cast<SCROW>(nFirstRow), nTab, false, false,
+                            false );
                     aTabOpParam.aRefFormulaEnd.Set(
                             static_cast<SCCOL>(nFirstCol - 1),
-                            static_cast<SCROW>(nLastRow), nTab, FALSE, FALSE,
-                            FALSE );
+                            static_cast<SCROW>(nLastRow), nTab, false, false,
+                            false );
                     aTabOpParam.aRefRowCell.Set( static_cast<SCCOL>(nInpCol),
-                            static_cast<SCROW>(nInpRow), nTab, FALSE, FALSE,
-                            FALSE );
+                            static_cast<SCROW>(nInpRow), nTab, false, false,
+                            false );
                     nCol++;
                 break;
                 case 2:		// TWO-INPUT
                     aTabOpParam.aRefFormulaCell.Set(
                             static_cast<SCCOL>(nFirstCol - 1),
-                            static_cast<SCROW>(nFirstRow - 1), nTab, FALSE,
-                            FALSE, FALSE );
+                            static_cast<SCROW>(nFirstRow - 1), nTab, false,
+                            false, false );
                     aTabOpParam.aRefRowCell.Set( static_cast<SCCOL>(nInpCol),
-                            static_cast<SCROW>(nInpRow), nTab, FALSE, FALSE,
-                            FALSE );
+                            static_cast<SCROW>(nInpRow), nTab, false, false,
+                            false );
                     aTabOpParam.aRefColCell.Set( static_cast<SCCOL>(nInpCol2),
-                            static_cast<SCROW>(nInpRow2), nTab, FALSE, FALSE,
-                            FALSE );
+                            static_cast<SCROW>(nInpRow2), nTab, false, false,
+                            false );
                 break;
             }
 
@@ -1085,7 +1085,7 @@ void ImportExcel::TableOp( void )
     }
     else
     {
-        bTabTruncated = TRUE;
+        bTabTruncated = sal_True;
         GetTracer().TraceInvalidRow(GetCurrScTab(), nLastRow, MAXROW);
     }
 }
@@ -1112,7 +1112,7 @@ void ImportExcel::Bof4( void )
 void ImportExcel::Bof5( void )
 {
     //POST:	eDateiTyp = Typ der zu lesenden Datei
-    UINT16		nSubType, nVers;
+    sal_uInt16		nSubType, nVers;
     BiffTyp		eDatei;
 
     maStrm.DisableDecryption();
@@ -1168,15 +1168,15 @@ void ImportExcel::NeueTabelle( void )
 
     InitializeTable( nTab );
 
-    pOutlineListBuffer->Append( new XclImpOutlineDataBuffer( GetRoot(), nTab ) );
-
-    pExcRoot->pColRowBuff = pColRowBuff = pOutlineListBuffer->Last()->GetColRowBuff();
-    pColOutlineBuff = pOutlineListBuffer->Last()->GetColOutline();
-    pRowOutlineBuff = pOutlineListBuffer->Last()->GetRowOutline();
+    XclImpOutlineDataBuffer* pNewItem = new XclImpOutlineDataBuffer( GetRoot(), nTab );
+    pOutlineListBuffer->push_back( pNewItem );
+    pExcRoot->pColRowBuff = pColRowBuff = pNewItem->GetColRowBuff();
+    pColOutlineBuff = pNewItem->GetColOutline();
+    pRowOutlineBuff = pNewItem->GetRowOutline();
 }
 
 
-const ScTokenArray* ImportExcel::ErrorToFormula( BYTE bErrOrVal, BYTE nError, double& rVal )
+const ScTokenArray* ImportExcel::ErrorToFormula( sal_uInt8 bErrOrVal, sal_uInt8 nError, double& rVal )
 {
     return pFormConv->GetBoolErr( XclTools::ErrorToEnum( rVal, bErrOrVal, nError ) );
 }
@@ -1184,7 +1184,7 @@ const ScTokenArray* ImportExcel::ErrorToFormula( BYTE bErrOrVal, BYTE nError, do
 
 void ImportExcel::AdjustRowHeight()
 {
-    /*  #93255# Speed up chart import: import all sheets without charts, then
+    /*  Speed up chart import: import all sheets without charts, then
         update row heights (here), last load all charts -> do not any longer
         update inside of ScDocShell::ConvertFrom() (causes update of existing
         charts during each and every change of row height). */
@@ -1202,8 +1202,8 @@ void ImportExcel::PostDocLoad( void )
         pStyleSheet->GetItemSet().Put( SfxUInt16Item( ATTR_PAGE_FIRSTPAGENO, 0 ) );
 
     // outlines for all sheets, sets hidden rows and columns (#i11776# after filtered ranges)
-    for( XclImpOutlineDataBuffer* pBuffer = pOutlineListBuffer->First(); pBuffer; pBuffer = pOutlineListBuffer->Next() )
-        pBuffer->Convert();
+    for (XclImpOutlineListBuffer::iterator itBuffer = pOutlineListBuffer->begin(); itBuffer != pOutlineListBuffer->end(); ++itBuffer)
+        itBuffer->Convert();
 
     // document view settings (before visible OLE area)
     GetDocViewSettings().Finalize();
@@ -1242,7 +1242,7 @@ void ImportExcel::PostDocLoad( void )
         }
     }
 
-    // #111099# open forms in alive mode (has no effect, if no controls in document)
+    // open forms in alive mode (has no effect, if no controls in document)
     if( ScModelObj* pDocObj = GetDocModelObj() )
         pDocObj->setPropertyValue( CREATE_OUSTRING( SC_UNO_APPLYFMDES ), uno::Any( false ) );
 
@@ -1259,12 +1259,9 @@ void ImportExcel::PostDocLoad( void )
     {
         for( SCTAB n = 0 ; n < nLast ; n++ )
         {
-            p = pExcRoot->pPrintRanges->First( static_cast<UINT16>(n) );
+            p = pExcRoot->pPrintRanges->First(n);
             if( p )
             {
-                DBG_ASSERT( pExcRoot->pPrintRanges->GetActList(),
-                            "-ImportExcel::PostDocLoad(): Imaginaere Tabelle gefunden!" );
-
                 pD->ClearPrintRanges( n );
                 while( p )
                 {
@@ -1285,27 +1282,24 @@ void ImportExcel::PostDocLoad( void )
     {
         for( SCTAB n = 0 ; n < nLast ; n++ )
         {
-            p = pExcRoot->pPrintTitles->First( static_cast<UINT16>(n) );
+            p = pExcRoot->pPrintTitles->First(n);
             if( p )
             {
-                DBG_ASSERT( pExcRoot->pPrintTitles->GetActList(),
-                    "-ImportExcel::PostDocLoad(): Imaginaere Tabelle gefunden!" );
-
-                BOOL	bRowVirgin = TRUE;
-                BOOL	bColVirgin = TRUE;
+                sal_Bool	bRowVirgin = sal_True;
+                sal_Bool	bColVirgin = sal_True;
 
                 while( p )
                 {
                     if( p->aStart.Col() == 0 && p->aEnd.Col() == MAXCOL && bRowVirgin )
                     {
                         pD->SetRepeatRowRange( n, p );
-                        bRowVirgin = FALSE;
+                        bRowVirgin = false;
                     }
 
                     if( p->aStart.Row() == 0 && p->aEnd.Row() == MAXROW && bColVirgin )
                     {
                         pD->SetRepeatColRange( n, p );
-                        bColVirgin = FALSE;
+                        bColVirgin = false;
                     }
 
                     p = pExcRoot->pPrintTitles->Next();
@@ -1330,10 +1324,10 @@ XclImpOutlineDataBuffer::~XclImpOutlineDataBuffer()
 
 void XclImpOutlineDataBuffer::Convert()
 {
-    mxColOutlineBuff->SetOutlineArray( GetDoc().GetOutlineTable( mnScTab, TRUE )->GetColArray() );
+    mxColOutlineBuff->SetOutlineArray( GetDoc().GetOutlineTable( mnScTab, sal_True )->GetColArray() );
     mxColOutlineBuff->MakeScOutline();
 
-    mxRowOutlineBuff->SetOutlineArray( GetDoc().GetOutlineTable( mnScTab, TRUE )->GetRowArray() );
+    mxRowOutlineBuff->SetOutlineArray( GetDoc().GetOutlineTable( mnScTab, sal_True )->GetRowArray() );
     mxRowOutlineBuff->MakeScOutline();
 
     mxColRowBuff->ConvertHiddenFlags( mnScTab );
