@@ -49,7 +49,7 @@
 #include <set>
 #include <limits>
 
-#include <oox/core/tokens.hxx>
+using namespace ::oox;
 
 using ::rtl::OString;
 using ::std::set;
