@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -102,29 +102,30 @@
 #include <com/sun/star/document/XDocumentProperties.hpp>
 #include <com/sun/star/document/XDocumentPropertiesSupplier.hpp>
 
+using ::editeng::SvxBorderLine;
 
 //========================================================================
 
-const static sal_Char __FAR_DATA sMyBegComment[]	= "<!-- ";
-const static sal_Char __FAR_DATA sMyEndComment[]	= " -->";
-const static sal_Char __FAR_DATA sFontFamily[]		= "font-family:";
-const static sal_Char __FAR_DATA sFontSize[]		= "font-size:";
+const static sal_Char sMyBegComment[]	= "<!-- ";
+const static sal_Char sMyEndComment[]	= " -->";
+const static sal_Char sFontFamily[]		= "font-family:";
+const static sal_Char sFontSize[]		= "font-size:";
 
-const USHORT __FAR_DATA ScHTMLExport::nDefaultFontSize[SC_HTML_FONTSIZES] =
+const sal_uInt16 ScHTMLExport::nDefaultFontSize[SC_HTML_FONTSIZES] =
 {
     HTMLFONTSZ1_DFLT, HTMLFONTSZ2_DFLT, HTMLFONTSZ3_DFLT, HTMLFONTSZ4_DFLT,
     HTMLFONTSZ5_DFLT, HTMLFONTSZ6_DFLT, HTMLFONTSZ7_DFLT
 };
 
-USHORT ScHTMLExport::nFontSize[SC_HTML_FONTSIZES] = { 0 };
+sal_uInt16 ScHTMLExport::nFontSize[SC_HTML_FONTSIZES] = { 0 };
 
-const char* __FAR_DATA ScHTMLExport::pFontSizeCss[SC_HTML_FONTSIZES] =
+const char* ScHTMLExport::pFontSizeCss[SC_HTML_FONTSIZES] =
 {
     "xx-small", "x-small", "small", "medium", "large", "x-large", "xx-large"
 };
 
-const USHORT ScHTMLExport::nCellSpacing = 0;
-const sal_Char __FAR_DATA ScHTMLExport::sIndentSource[nIndentMax+1] =
+const sal_uInt16 ScHTMLExport::nCellSpacing = 0;
+const sal_Char ScHTMLExport::sIndentSource[nIndentMax+1] =
     "\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t";
 
 //========================================================================
@@ -133,7 +134,7 @@ const sal_Char __FAR_DATA ScHTMLExport::sIndentSource[nIndentMax+1] =
 #define OUT_PROLOGUE()		(rStrm << sHTML30_Prologue << ScExportBase::sNewLine \
                                 << ScExportBase::sNewLine)
 #define TAG_ON( tag )		HTMLOutFuncs::Out_AsciiTag( rStrm, tag )
-#define TAG_OFF( tag )		HTMLOutFuncs::Out_AsciiTag( rStrm, tag, FALSE )
+#define TAG_OFF( tag )		HTMLOutFuncs::Out_AsciiTag( rStrm, tag, false )
 #define OUT_STR( str )      HTMLOutFuncs::Out_String( rStrm, str, eDestEnc, &aNonConvertibleChars )
 #define OUT_STR_NO_CONV( str )  HTMLOutFuncs::Out_String( rStrm, str, eDestEnc )
 #define OUT_LF()			rStrm << ScExportBase::sNewLine << GetIndentStr()
@@ -157,7 +158,7 @@ const sal_Char __FAR_DATA ScHTMLExport::sIndentSource[nIndentMax+1] =
 //========================================================================
 
 FltError ScFormatFilterPluginImpl::ScExportHTML( SvStream& rStrm, const String& rBaseURL, ScDocument* pDoc,
-        const ScRange& rRange, const CharSet /*eNach*/, BOOL bAll,
+        const ScRange& rRange, const CharSet /*eNach*/, sal_Bool bAll,
         const String& rStreamPath, String& rNonConvertibleChars )
 {
     ScHTMLExport aEx( rStrm, rBaseURL, pDoc, rRange, bAll, rStreamPath );
@@ -207,38 +208,18 @@ void lcl_AppendHTMLColorTripel( ByteString& rStr, const Color& rColor )
     sal_Char*	p = buf;
 
     rStr += "\"#";
-    p += sprintf( p, "%02X", rColor.GetRed() );     // #100211# - checked
-    p += sprintf( p, "%02X", rColor.GetGreen() );   // #100211# - checked
-    p += sprintf( p, "%02X", rColor.GetBlue() );    // #100211# - checked
+    p += sprintf( p, "%02X", rColor.GetRed() );
+    p += sprintf( p, "%02X", rColor.GetGreen() );
+    p += sprintf( p, "%02X", rColor.GetBlue() );
     rStr += buf;
     rStr += '\"';
 }
 
-
-/*void lcl_TagOn( String& rResult, const String& rTag, const String* pStrOpt )
-{
-    rResult  = '<';
-    rResult += rTag;
-    if ( pStrOpt )
-    {
-        rResult += ' ';
-        rResult += *pStrOpt;
-    }
-    rResult += '>';
-}
-*/
-
-/*void lcl_TagOff( String& rResult, const String& rTag )
-{
-    rResult = '<'; rResult += rTag; rResult += '>';
-}
-*/
-
 //////////////////////////////////////////////////////////////////////////////
 
 ScHTMLExport::ScHTMLExport( SvStream& rStrmP, const String& rBaseURL, ScDocument* pDocP,
                             const ScRange& rRangeP,
-                            BOOL bAllP, const String& rStreamPathP ) :
+                            sal_Bool bAllP, const String& rStreamPathP ) :
     ScExportBase( rStrmP, pDocP, rRangeP ),
     aBaseURL( rBaseURL ),
     aStreamPath( rStreamPathP ),
@@ -248,21 +229,21 @@ ScHTMLExport::ScHTMLExport( SvStream& rStrmP, const String& rBaseURL, ScDocument
     nUsedTables( 0 ),
     nIndent( 0 ),
     bAll( bAllP ),
-    bTabHasGraphics( FALSE ),
+    bTabHasGraphics( false ),
     bCalcAsShown( pDocP->GetDocOptions().IsCalcAsShown() ),
-    bTableDataWidth( TRUE ),
-    bTableDataHeight( TRUE )
+    bTableDataWidth( sal_True ),
+    bTableDataHeight( sal_True )
 {
-    strcpy( sIndent, sIndentSource );       // #100211# - checked
+    strcpy( sIndent, sIndentSource );
     sIndent[0] = 0;
 
     // set HTML configuration
     SvxHtmlOptions* pHtmlOptions = SvxHtmlOptions::Get();
     eDestEnc = (pDoc->IsClipOrUndo() ? RTL_TEXTENCODING_UTF8 : pHtmlOptions->GetTextEncoding());
     bCopyLocalFileToINet = pHtmlOptions->IsSaveGraphicsLocal();
-    for ( USHORT j=0; j < SC_HTML_FONTSIZES; j++ )
+    for ( sal_uInt16 j=0; j < SC_HTML_FONTSIZES; j++ )
     {
-        USHORT nSize = pHtmlOptions->GetFontSize( j );
+        sal_uInt16 nSize = pHtmlOptions->GetFontSize( j );
         // remember in Twips, like our SvxFontHeightItem
         if ( nSize )
             nFontSize[j] = nSize * 20;
@@ -293,17 +274,16 @@ ScHTMLExport::ScHTMLExport( SvStream& rStrmP, const String& rBaseURL, ScDocument
 
 ScHTMLExport::~ScHTMLExport()
 {
-    for ( ScHTMLGraphEntry* pE = aGraphList.First(); pE; pE = aGraphList.Next() )
-        delete pE;
+    aGraphList.clear();
     delete pSrcArr;
     delete pDestArr;
 }
 
 
-USHORT ScHTMLExport::GetFontSizeNumber( USHORT nHeight )
+sal_uInt16 ScHTMLExport::GetFontSizeNumber( sal_uInt16 nHeight )
 {
-    USHORT nSize = 1;
-    for ( USHORT j=SC_HTML_FONTSIZES-1; j>0; j-- )
+    sal_uInt16 nSize = 1;
+    for ( sal_uInt16 j=SC_HTML_FONTSIZES-1; j>0; j-- )
     {
         if( nHeight > (nFontSize[j] + nFontSize[j-1]) / 2 )
         {	// der naechstgelegene
@@ -314,18 +294,18 @@ USHORT ScHTMLExport::GetFontSizeNumber( USHORT nHeight )
     return nSize;
 }
 
-const char* ScHTMLExport::GetFontSizeCss( USHORT nHeight )
+const char* ScHTMLExport::GetFontSizeCss( sal_uInt16 nHeight )
 {
-    USHORT nSize = GetFontSizeNumber( nHeight );
+    sal_uInt16 nSize = GetFontSizeNumber( nHeight );
     return pFontSizeCss[ nSize-1 ];
 }
 
 
-USHORT ScHTMLExport::ToPixel( USHORT nVal )
+sal_uInt16 ScHTMLExport::ToPixel( sal_uInt16 nVal )
 {
     if( nVal )
     {
-        nVal = (USHORT)pAppWin->LogicToPixel(
+        nVal = (sal_uInt16)pAppWin->LogicToPixel(
                     Size( nVal, nVal ), MapMode( MAP_TWIP ) ).Width();
         if( !nVal )		// wo ein Twip ist sollte auch ein Pixel sein
             nVal = 1;
@@ -347,7 +327,7 @@ Size ScHTMLExport::MMToPixel( const Size& rSize )
 }
 
 
-ULONG ScHTMLExport::Write()
+sal_uLong ScHTMLExport::Write()
 {
     rStrm << '<' << OOO_STRING_SVTOOLS_HTML_doctype << ' ' << OOO_STRING_SVTOOLS_HTML_doctype32 << '>'
         << sNewLine << sNewLine;
@@ -382,7 +362,7 @@ void ScHTMLExport::WriteHeader()
         OUT_LF();
 
         //----------------------------------------------------------
-        if (!xDocProps->getPrintedBy().equalsAscii(""))
+        if (xDocProps->getPrintedBy().getLength())
         {
             OUT_COMMENT( GLOBSTR( STR_DOC_INFO ) );
             String aStrOut( GLOBSTR( STR_DOC_PRINTED ) );
@@ -424,7 +404,7 @@ void ScHTMLExport::WriteHeader()
         }
     }
     rStrm << "; " << sFontSize
-        << GetFontSizeCss( ( USHORT ) aHTMLStyle.nFontHeight ) << " }";
+        << GetFontSizeCss( ( sal_uInt16 ) aHTMLStyle.nFontHeight ) << " }";
     OUT_LF();
     rStrm << sMyEndComment;
     IncIndent(-1); OUT_LF(); TAG_OFF_LF( OOO_STRING_SVTOOLS_HTML_style );
@@ -494,7 +474,7 @@ const SfxItemSet& ScHTMLExport::PageDefaults( SCTAB nTab )
                         ScGlobal::GetScriptedWhichID(
                             aHTMLStyle.nDefaultScriptType, ATTR_FONT_HEIGHT
                             )))).GetHeight();
-        aHTMLStyle.nFontSizeNumber = GetFontSizeNumber( static_cast< USHORT >( aHTMLStyle.nFontHeight ) );
+        aHTMLStyle.nFontSizeNumber = GetFontSizeNumber( static_cast< sal_uInt16 >( aHTMLStyle.nFontHeight ) );
     }
 
     // Page style sheet printer settings, e.g. for background graphics.
@@ -509,7 +489,7 @@ const SfxItemSet& ScHTMLExport::PageDefaults( SCTAB nTab )
     {
         const SvxBrushItem* pBrushItem = (const SvxBrushItem*)&rSet.Get( ATTR_BACKGROUND );
         aHTMLStyle.aBackgroundColor = pBrushItem->GetColor();
-        aHTMLStyle.bInitialized = TRUE;
+        aHTMLStyle.bInitialized = sal_True;
     }
     return rSet;
 }
@@ -527,14 +507,28 @@ void ScHTMLExport::BorderToStyle( ByteString& rOut, const char* pBorderName,
         ((rOut += "border-") += pBorderName) += ": ";
 
         // thickness
-        int nWidth = pLine->GetOutWidth();
+        int nWidth = pLine->GetWidth();
         int nPxWidth = ( nWidth > 0 )? std::max( int( nWidth / TWIPS_PER_PIXEL ), 1 ): 0;
         (rOut += ByteString::CreateFromInt32( nPxWidth )) += "px ";
         switch ( pLine->GetStyle() )
         {
-            case DOTTED:    rOut += "dotted"; break;
-            case DASHED:    rOut += "dashed"; break;
-            default:        rOut += "solid";
+            case ::editeng::SOLID:     rOut += "solid"; break;
+            case ::editeng::DOTTED:    rOut += "dotted"; break;
+            case ::editeng::DASHED:    rOut += "dashed"; break;
+            case ::editeng::DOUBLE:
+            case ::editeng::THINTHICK_SMALLGAP:
+            case ::editeng::THINTHICK_MEDIUMGAP:
+            case ::editeng::THINTHICK_LARGEGAP:
+            case ::editeng::THICKTHIN_SMALLGAP:
+            case ::editeng::THICKTHIN_MEDIUMGAP:
+            case ::editeng::THICKTHIN_LARGEGAP:
+                            rOut += "double";
+                            break;
+            case ::editeng::EMBOSSED:  rOut += "ridge"; break;
+            case ::editeng::ENGRAVED:  rOut += "groove"; break;
+            case ::editeng::OUTSET:    rOut += "outset"; break;
+            case ::editeng::INSET:     rOut += "inset"; break;
+            default:        rOut += "hidden";
         }
         rOut += " #";
 
@@ -570,7 +564,7 @@ void ScHTMLExport::WriteBody()
             {
                 // Grafik als (JPG-)File speichern
                 aGrfNm = aStreamPath;
-                USHORT nErr = XOutBitmap::WriteGraphic( *pGrf, aGrfNm,
+                sal_uInt16 nErr = XOutBitmap::WriteGraphic( *pGrf, aGrfNm,
                     CREATE_STRING( "JPG" ), XOUTBMP_USE_NATIVE_IF_POSSIBLE );
                 if( !nErr )		// fehlerhaft, da ist nichts auszugeben
                 {
@@ -705,12 +699,11 @@ void ScHTMLExport::WriteTables()
 
         // <TABLE ...>
         ByteString	aByteStrOut = OOO_STRING_SVTOOLS_HTML_table;
-//		aStrOut  = OOO_STRING_SVTOOLS_HTML_table;
 
         // FRAME=VOID, we do the styling of the cells in <TD>
         (((aByteStrOut += ' ') += OOO_STRING_SVTOOLS_HTML_frame) += '=') += OOO_STRING_SVTOOLS_HTML_TF_void;
 
-        bTabHasGraphics = bTabAlignedLeft = FALSE;
+        bTabHasGraphics = bTabAlignedLeft = false;
         if ( bAll && pDrawLayer )
             PrepareGraphics( pDrawLayer, nTab, nStartCol, nStartRow,
                 nEndCol, nEndRow );
@@ -762,7 +755,7 @@ void ScHTMLExport::WriteTables()
         IncIndent(1); TAG_ON_LF( OOO_STRING_SVTOOLS_HTML_tbody );
         // At least old (3.x, 4.x?) Netscape doesn't follow <TABLE COLS=n> and
         // <COL WIDTH=x> specified, but needs a width at every column.
-        bTableDataWidth = TRUE;     // widths in first row
+        bTableDataWidth = sal_True;     // widths in first row
         bool bHasHiddenRows = pDoc->HasHiddenRows(nStartRow, nEndRow, nTab);
         for ( SCROW nRow=nStartRow; nRow<=nEndRow; nRow++ )
         {
@@ -774,7 +767,7 @@ void ScHTMLExport::WriteTables()
             }
 
             IncIndent(1); TAG_ON_LF( OOO_STRING_SVTOOLS_HTML_tablerow );
-            bTableDataHeight = TRUE;  // height at every first cell of each row
+            bTableDataHeight = sal_True;  // height at every first cell of each row
             for ( SCCOL nCol2=nStartCol; nCol2<=nEndCol; nCol2++ )
             {
                 if ( pDoc->ColHidden(nCol2, nTab) )
@@ -783,9 +776,9 @@ void ScHTMLExport::WriteTables()
                 if ( nCol2 == nEndCol )
                     IncIndent(-1);
                 WriteCell( nCol2, nRow, nTab );
-                bTableDataHeight = FALSE;
+                bTableDataHeight = false;
             }
-            bTableDataWidth = FALSE;    // widths only in first row
+            bTableDataWidth = false;    // widths only in first row
 
             if ( nRow == nEndRow )
                 IncIndent(-1);
@@ -798,13 +791,14 @@ void ScHTMLExport::WriteTables()
         if ( bTabHasGraphics )
         {
             // the rest that is not in a cell
-            for ( ScHTMLGraphEntry* pE = aGraphList.First(); pE; pE = aGraphList.Next() )
+            size_t ListSize = aGraphList.size();
+            for ( size_t i = 0; i < ListSize; ++i )
             {
+                ScHTMLGraphEntry* pE = &aGraphList[ i ];
                 if ( !pE->bWritten )
                     WriteGraphEntry( pE );
-                delete pE;
             }
-            aGraphList.Clear();
+            aGraphList.clear();
             if ( bTabAlignedLeft )
             {	// clear <TABLE ALIGN=LEFT> with <BR CLEAR=LEFT>
                 aByteStrOut = OOO_STRING_SVTOOLS_HTML_linebreak;
@@ -832,9 +826,10 @@ void ScHTMLExport::WriteCell( SCCOL nCol, SCROW nRow, SCTAB nTab )
     ScHTMLGraphEntry* pGraphEntry = NULL;
     if ( bTabHasGraphics )
     {
-        for ( pGraphEntry = aGraphList.First();	pGraphEntry;
-              pGraphEntry = aGraphList.Next() )
+        size_t ListSize = aGraphList.size();
+        for ( size_t i = 0; i < ListSize; ++i )
         {
+            pGraphEntry = &aGraphList[ i ];
             if ( pGraphEntry->bInCell && pGraphEntry->aRange.In( aPos ) )
             {
                 if ( pGraphEntry->aRange.aStart == aPos )
@@ -846,9 +841,9 @@ void ScHTMLExport::WriteCell( SCCOL nCol, SCROW nRow, SCTAB nTab )
     }
 
     ScBaseCell* pCell = pDoc->GetCell( aPos );
-    ULONG nFormat = pAttr->GetNumberFormat( pFormatter );
-    BOOL bValueData;
-    BYTE nScriptType;
+    sal_uLong nFormat = pAttr->GetNumberFormat( pFormatter );
+    sal_Bool bValueData;
+    sal_uInt8 nScriptType;
     if ( pCell )
     {
         bValueData = pCell->HasValueData();
@@ -856,7 +851,7 @@ void ScHTMLExport::WriteCell( SCCOL nCol, SCROW nRow, SCTAB nTab )
     }
     else
     {
-        bValueData = FALSE;
+        bValueData = false;
         nScriptType = 0;
     }
     if ( nScriptType == 0 )
@@ -881,15 +876,15 @@ void ScHTMLExport::WriteCell( SCCOL nCol, SCROW nRow, SCTAB nTab )
     }
 
     const sal_Char* pChar;
-    USHORT nWidthPixel;
-    USHORT nHeightPixel;
+    sal_uInt16 nWidthPixel;
+    sal_uInt16 nHeightPixel;
 
     const ScMergeAttr& rMergeAttr = (const ScMergeAttr&) pAttr->GetItem( ATTR_MERGE, pCondItemSet );
     if ( pGraphEntry || rMergeAttr.IsMerged() )
     {
         SCCOL nC, jC;
         SCROW nR;
-        ULONG v;
+        sal_uLong v;
         if ( pGraphEntry )
             nC = Max( SCCOL(pGraphEntry->aRange.aEnd.Col() - nCol + 1),
                 SCCOL(rMergeAttr.GetColMerge()) );
@@ -901,7 +896,7 @@ void ScHTMLExport::WriteCell( SCCOL nCol, SCROW nRow, SCTAB nTab )
             nC = nC + nCol;
             for ( jC=nCol, v=0; jC<nC; jC++ )
                 v += pDoc->GetColWidth( jC, nTab );
-            nWidthPixel = ToPixel( static_cast< USHORT >( v ) );
+            nWidthPixel = ToPixel( static_cast< sal_uInt16 >( v ) );
         }
         else
             nWidthPixel = ToPixel( pDoc->GetColWidth( nCol, nTab ) );
@@ -916,7 +911,7 @@ void ScHTMLExport::WriteCell( SCCOL nCol, SCROW nRow, SCTAB nTab )
             (((aStrTD += ' ') += OOO_STRING_SVTOOLS_HTML_O_rowspan) += '=') += ByteString::CreateFromInt32( nR );
             nR += nRow;
             v = pDoc->GetRowHeight( nRow, nR-1, nTab );
-            nHeightPixel = ToPixel( static_cast< USHORT >( v ) );
+            nHeightPixel = ToPixel( static_cast< sal_uInt16 >( v ) );
         }
         else
             nHeightPixel = ToPixel( pDoc->GetRowHeight( nRow, nTab ) );
@@ -965,25 +960,25 @@ void ScHTMLExport::WriteCell( SCCOL nCol, SCROW nRow, SCTAB nTab )
 
     Color aBgColor;
     if ( rBrushItem.GetColor().GetTransparency() == 255 )
-        aBgColor = aHTMLStyle.aBackgroundColor;		// #55121# keine ungewollte Hintergrundfarbe
+        aBgColor = aHTMLStyle.aBackgroundColor;		// keine ungewollte Hintergrundfarbe
     else
         aBgColor = rBrushItem.GetColor();
 
-    BOOL bBold			= ( WEIGHT_BOLD		<= rWeightItem.GetWeight() );
-    BOOL bItalic		= ( ITALIC_NONE		!= rPostureItem.GetPosture() );
-    BOOL bUnderline		= ( UNDERLINE_NONE	!= rUnderlineItem.GetLineStyle() );
-    BOOL bSetFontColor	= ( COL_AUTO		!= rColorItem.GetValue().GetColor() );	// #97650# default is AUTO now
-    BOOL bSetFontName	= ( aHTMLStyle.aFontFamilyName	!= rFontItem.GetFamilyName() );
-    USHORT nSetFontSizeNumber = 0;
-    UINT32 nFontHeight = rFontHeightItem.GetHeight();
+    sal_Bool bBold			= ( WEIGHT_BOLD		<= rWeightItem.GetWeight() );
+    sal_Bool bItalic		= ( ITALIC_NONE		!= rPostureItem.GetPosture() );
+    sal_Bool bUnderline		= ( UNDERLINE_NONE	!= rUnderlineItem.GetLineStyle() );
+    sal_Bool bSetFontColor	= ( COL_AUTO		!= rColorItem.GetValue().GetColor() );	// default is AUTO now
+    sal_Bool bSetFontName	= ( aHTMLStyle.aFontFamilyName	!= rFontItem.GetFamilyName() );
+    sal_uInt16 nSetFontSizeNumber = 0;
+    sal_uInt32 nFontHeight = rFontHeightItem.GetHeight();
     if ( nFontHeight != aHTMLStyle.nFontHeight )
     {
-        nSetFontSizeNumber = GetFontSizeNumber( (USHORT) nFontHeight );
+        nSetFontSizeNumber = GetFontSizeNumber( (sal_uInt16) nFontHeight );
         if ( nSetFontSizeNumber == aHTMLStyle.nFontSizeNumber )
             nSetFontSizeNumber = 0;   // no difference, don't set
     }
 
-    BOOL bSetFont = (bSetFontColor || bSetFontName || nSetFontSizeNumber);
+    sal_Bool bSetFont = (bSetFontColor || bSetFontName || nSetFontSizeNumber);
 
     //! TODO: we could entirely use CSS1 here instead, but that would exclude
     //! Netscape 3.0 and Netscape 4.x without JavaScript enabled.
@@ -996,10 +991,10 @@ void ScHTMLExport::WriteCell( SCCOL nCol, SCROW nRow, SCTAB nTab )
             break;
         case SVX_HOR_JUSTIFY_CENTER:	pChar = OOO_STRING_SVTOOLS_HTML_AL_center;	break;
         case SVX_HOR_JUSTIFY_BLOCK:		pChar = OOO_STRING_SVTOOLS_HTML_AL_justify;	break;
-        case SVX_HOR_JUSTIFY_RIGHT:		pChar = OOO_STRING_SVTOOLS_HTML_AL_right;		break;
+        case SVX_HOR_JUSTIFY_RIGHT:		pChar = OOO_STRING_SVTOOLS_HTML_AL_right;   break;
         case SVX_HOR_JUSTIFY_LEFT:
         case SVX_HOR_JUSTIFY_REPEAT:
-        default:						pChar = OOO_STRING_SVTOOLS_HTML_AL_left;		break;
+        default:						pChar = OOO_STRING_SVTOOLS_HTML_AL_left;    break;
     }
 
     (((aStrTD += ' ') += OOO_STRING_SVTOOLS_HTML_O_align) += '=') += pChar;
@@ -1104,7 +1099,7 @@ void ScHTMLExport::WriteCell( SCCOL nCol, SCROW nRow, SCTAB nTab )
     }
 
     String aStrOut;
-    BOOL bFieldText = FALSE;
+    sal_Bool bFieldText = false;
     if ( pCell )
     {	// cell content
         Color* pColor;
@@ -1126,7 +1121,7 @@ void ScHTMLExport::WriteCell( SCCOL nCol, SCROW nRow, SCTAB nTab )
     {
         if ( !aStrOut.Len() )
         {
-            TAG_ON( OOO_STRING_SVTOOLS_HTML_linebreak );		// #42573# keine komplett leere Zelle
+            TAG_ON( OOO_STRING_SVTOOLS_HTML_linebreak );		// keine komplett leere Zelle
         }
         else
         {
@@ -1144,7 +1139,7 @@ void ScHTMLExport::WriteCell( SCCOL nCol, SCROW nRow, SCTAB nTab )
                     OUT_STR( aSingleLine );
                     TAG_ON( OOO_STRING_SVTOOLS_HTML_linebreak );
                     nStartPos = nPos + 1;
-                } 
+                }
                 while( ( nPos = aStrOut.Search( _LF, nStartPos ) ) != STRING_NOTFOUND );
                 String aSingleLine( aStrOut, nStartPos, aStrOut.Len() - nStartPos );
                 OUT_STR( aSingleLine );
@@ -1163,51 +1158,51 @@ void ScHTMLExport::WriteCell( SCCOL nCol, SCROW nRow, SCTAB nTab )
 }
 
 
-BOOL ScHTMLExport::WriteFieldText( const ScEditCell* pCell )
+sal_Bool ScHTMLExport::WriteFieldText( const ScEditCell* pCell )
 {
-    BOOL bFields = FALSE;
+    sal_Bool bFields = false;
     const EditTextObject* pData;
     pCell->GetData( pData );
     // text and anchor of URL fields, Doc-Engine is a ScFieldEditEngine
     EditEngine& rEngine = pDoc->GetEditEngine();
     rEngine.SetText( *pData );
-    USHORT nParas = rEngine.GetParagraphCount();
+    sal_uInt16 nParas = rEngine.GetParagraphCount();
     if ( nParas )
     {
         ESelection aSel( 0, 0, nParas-1, rEngine.GetTextLen( nParas-1 ) );
         SfxItemSet aSet( rEngine.GetAttribs( aSel ) );
-        SfxItemState eFieldState = aSet.GetItemState( EE_FEATURE_FIELD, FALSE );
+        SfxItemState eFieldState = aSet.GetItemState( EE_FEATURE_FIELD, false );
         if ( eFieldState == SFX_ITEM_DONTCARE || eFieldState == SFX_ITEM_SET )
-            bFields = TRUE;
+            bFields = sal_True;
     }
     if ( bFields )
     {
-        BOOL bOldUpdateMode = rEngine.GetUpdateMode();
-        rEngine.SetUpdateMode( TRUE );		// no portions if not formatted
-        for ( USHORT nPar=0; nPar < nParas; nPar++ )
+        sal_Bool bOldUpdateMode = rEngine.GetUpdateMode();
+        rEngine.SetUpdateMode( sal_True );		// no portions if not formatted
+        for ( sal_uInt16 nPar=0; nPar < nParas; nPar++ )
         {
             if ( nPar > 0 )
                 TAG_ON( OOO_STRING_SVTOOLS_HTML_linebreak );
             SvUShorts aPortions;
             rEngine.GetPortions( nPar, aPortions );
-            USHORT nCnt = aPortions.Count();
-            USHORT nStart = 0;
-            for ( USHORT nPos = 0; nPos < nCnt; nPos++ )
+            sal_uInt16 nCnt = aPortions.Count();
+            sal_uInt16 nStart = 0;
+            for ( sal_uInt16 nPos = 0; nPos < nCnt; nPos++ )
             {
-                USHORT nEnd = aPortions.GetObject( nPos );
+                sal_uInt16 nEnd = aPortions.GetObject( nPos );
                 ESelection aSel( nPar, nStart, nPar, nEnd );
-                BOOL bUrl = FALSE;
+                sal_Bool bUrl = false;
                 // fields are single characters
                 if ( nEnd == nStart+1 )
                 {
                     const SfxPoolItem* pItem;
                     SfxItemSet aSet = rEngine.GetAttribs( aSel );
-                    if ( aSet.GetItemState( EE_FEATURE_FIELD, FALSE, &pItem ) == SFX_ITEM_ON )
+                    if ( aSet.GetItemState( EE_FEATURE_FIELD, false, &pItem ) == SFX_ITEM_ON )
                     {
                         const SvxFieldData* pField = ((const SvxFieldItem*)pItem)->GetField();
                         if ( pField && pField->ISA(SvxURLField) )
                         {
-                            bUrl = TRUE;
+                            bUrl = sal_True;
                             const SvxURLField*	pURLField = (const SvxURLField*)pField;
 //							String				aFieldText = rEngine.GetText( aSel );
                             rStrm << '<' << OOO_STRING_SVTOOLS_HTML_anchor << ' ' << OOO_STRING_SVTOOLS_HTML_O_href << "=\"";
@@ -1229,10 +1224,10 @@ BOOL ScHTMLExport::WriteFieldText( const ScEditCell* pCell )
 }
 
 
-BOOL ScHTMLExport::CopyLocalFileToINet( String& rFileNm,
-        const String& rTargetNm, BOOL bFileToFile )
+sal_Bool ScHTMLExport::CopyLocalFileToINet( String& rFileNm,
+        const String& rTargetNm, sal_Bool bFileToFile )
 {
-    BOOL bRet = FALSE;
+    sal_Bool bRet = false;
     INetURLObject aFileUrl, aTargetUrl;
     aFileUrl.SetSmartURL( rFileNm );
     aTargetUrl.SetSmartURL( rTargetNm );
@@ -1245,11 +1240,11 @@ BOOL ScHTMLExport::CopyLocalFileToINet( String& rFileNm,
         if( pSrcArr )
         {
             // wurde die Datei schon verschoben
-            USHORT nPos;
+            sal_uInt16 nPos;
             if( pSrcArr->Seek_Entry( &rFileNm, &nPos ))
             {
                 rFileNm = *(*pDestArr)[ nPos ];
-                return TRUE;
+                return sal_True;
             }
         }
         else
@@ -1276,10 +1271,7 @@ BOOL ScHTMLExport::CopyLocalFileToINet( String& rFileNm,
         else
         {
             SfxMedium aMedium( *pDest, STREAM_WRITE | STREAM_SHARE_DENYNONE,
-                                FALSE );
-
-            // temp. File anlegen
-    //		aMedium.DownLoad();
+                                false );
 
             {
                 SvFileStream aCpy( aMedium.GetPhysicalName(), STREAM_WRITE );
