@@ -49,7 +49,7 @@ using namespace xmloff::token;
 //------------------------------------------------------------------
 
 ScXMLFilterContext::ScXMLFilterContext( ScXMLImport& rImport,
-                                      USHORT nPrfx,
+                                      sal_uInt16 nPrfx,
                                       const ::rtl::OUString& rLName,
                                       const ::com::sun::star::uno::Reference<
                                       ::com::sun::star::xml::sax::XAttributeList>& xAttrList,
@@ -57,12 +57,12 @@ ScXMLFilterContext::ScXMLFilterContext( ScXMLImport& rImport,
     SvXMLImportContext( rImport, nPrfx, rLName ),
     pDatabaseRangeContext(pTempDatabaseRangeContext),
     aFilterFields(),
-    bSkipDuplicates(sal_False),
-    bCopyOutputData(sal_False),
-    bUseRegularExpressions(sal_False),
+    bSkipDuplicates(false),
+    bCopyOutputData(false),
+    bUseRegularExpressions(false),
     bConnectionOr(sal_True),
     bNextConnectionOr(sal_True),
-    bConditionSourceRange(sal_False)
+    bConditionSourceRange(false)
 {
     ScDocument* pDoc(GetScImport().GetDocument());
 
@@ -72,7 +72,7 @@ ScXMLFilterContext::ScXMLFilterContext( ScXMLImport& rImport,
     {
         const rtl::OUString& sAttrName(xAttrList->getNameByIndex( i ));
         rtl::OUString aLocalName;
-        USHORT nPrefix = GetScImport().GetNamespaceMap().GetKeyByAttrName(
+        sal_uInt16 nPrefix = GetScImport().GetNamespaceMap().GetKeyByAttrName(
                                             sAttrName, &aLocalName );
         const rtl::OUString& sValue(xAttrList->getValueByIndex( i ));
 
@@ -114,7 +114,7 @@ ScXMLFilterContext::~ScXMLFilterContext()
 {
 }
 
-SvXMLImportContext *ScXMLFilterContext::CreateChildContext( USHORT nPrefix,
+SvXMLImportContext *ScXMLFilterContext::CreateChildContext( sal_uInt16 nPrefix,
                                             const ::rtl::OUString& rLName,
                                             const ::com::sun::star::uno::Reference<
                                           ::com::sun::star::xml::sax::XAttributeList>& xAttrList )
@@ -159,7 +159,7 @@ void ScXMLFilterContext::EndElement()
         pDatabaseRangeContext->SetFilterCopyOutputData(bCopyOutputData);
     }
     else
-        pDatabaseRangeContext->SetFilterCopyOutputData(sal_False);
+        pDatabaseRangeContext->SetFilterCopyOutputData(false);
     pDatabaseRangeContext->SetFilterIsCaseSensitive(bIsCaseSensitive);
     pDatabaseRangeContext->SetFilterSkipDuplicates(bSkipDuplicates);
     pDatabaseRangeContext->SetFilterFields(aFilterFields);
@@ -168,7 +168,7 @@ void ScXMLFilterContext::EndElement()
 }
 
 ScXMLAndContext::ScXMLAndContext( ScXMLImport& rImport,
-                                      USHORT nPrfx,
+                                      sal_uInt16 nPrfx,
                                       const ::rtl::OUString& rLName,
                                       const ::com::sun::star::uno::Reference<
                                       ::com::sun::star::xml::sax::XAttributeList>& /* xAttrList */,
@@ -176,14 +176,14 @@ ScXMLAndContext::ScXMLAndContext( ScXMLImport& rImport,
     SvXMLImportContext( rImport, nPrfx, rLName ),
     pFilterContext(pTempFilterContext)
 {
-    pFilterContext->OpenConnection(sal_False);
+    pFilterContext->OpenConnection(false);
 }
 
 ScXMLAndContext::~ScXMLAndContext()
 {
 }
 
-SvXMLImportContext *ScXMLAndContext::CreateChildContext( USHORT nPrefix,
+SvXMLImportContext *ScXMLAndContext::CreateChildContext( sal_uInt16 nPrefix,
                                             const ::rtl::OUString& rLName,
                                             const ::com::sun::star::uno::Reference<
                                           ::com::sun::star::xml::sax::XAttributeList>& xAttrList )
@@ -218,7 +218,7 @@ void ScXMLAndContext::EndElement()
 }
 
 ScXMLOrContext::ScXMLOrContext( ScXMLImport& rImport,
-                                      USHORT nPrfx,
+                                      sal_uInt16 nPrfx,
                                       const ::rtl::OUString& rLName,
                                       const ::com::sun::star::uno::Reference<
                                       ::com::sun::star::xml::sax::XAttributeList>& /* xAttrList */,
@@ -233,7 +233,7 @@ ScXMLOrContext::~ScXMLOrContext()
 {
 }
 
-SvXMLImportContext *ScXMLOrContext::CreateChildContext( USHORT nPrefix,
+SvXMLImportContext *ScXMLOrContext::CreateChildContext( sal_uInt16 nPrefix,
                                             const ::rtl::OUString& rLName,
                                             const ::com::sun::star::uno::Reference<
                                           ::com::sun::star::xml::sax::XAttributeList>& xAttrList )
@@ -269,14 +269,14 @@ void ScXMLOrContext::EndElement()
 }
 
 ScXMLConditionContext::ScXMLConditionContext( ScXMLImport& rImport,
-                                      USHORT nPrfx,
+                                      sal_uInt16 nPrfx,
                                       const ::rtl::OUString& rLName,
                                       const ::com::sun::star::uno::Reference<
                                       ::com::sun::star::xml::sax::XAttributeList>& xAttrList,
                                         ScXMLFilterContext* pTempFilterContext) :
     SvXMLImportContext( rImport, nPrfx, rLName ),
     pFilterContext(pTempFilterContext),
-    bIsCaseSensitive(sal_False)
+    bIsCaseSensitive(false)
 {
     sDataType = GetXMLToken(XML_TEXT);
 
@@ -286,7 +286,7 @@ ScXMLConditionContext::ScXMLConditionContext( ScXMLImport& rImport,
     {
         const rtl::OUString& sAttrName(xAttrList->getNameByIndex( i ));
         rtl::OUString aLocalName;
-        USHORT nPrefix = GetScImport().GetNamespaceMap().GetKeyByAttrName(
+        sal_uInt16 nPrefix = GetScImport().GetNamespaceMap().GetKeyByAttrName(
                                             sAttrName, &aLocalName );
         const rtl::OUString& sValue(xAttrList->getValueByIndex( i ));
 
@@ -325,7 +325,7 @@ ScXMLConditionContext::~ScXMLConditionContext()
 {
 }
 
-SvXMLImportContext *ScXMLConditionContext::CreateChildContext( USHORT nPrefix,
+SvXMLImportContext *ScXMLConditionContext::CreateChildContext( sal_uInt16 nPrefix,
                                             const ::rtl::OUString& rLName,
                                             const ::com::sun::star::uno::Reference<
                                         ::com::sun::star::xml::sax::XAttributeList>& /* xAttrList */ )
@@ -335,7 +335,7 @@ SvXMLImportContext *ScXMLConditionContext::CreateChildContext( USHORT nPrefix,
 
 void ScXMLConditionContext::getOperatorXML(const rtl::OUString sTempOperator, sal_Int32& aFilterOperator, sal_Bool& bUseRegularExpressions) const
 {
-    bUseRegularExpressions = sal_False;
+    bUseRegularExpressions = false;
     if (IsXMLToken(sTempOperator, XML_MATCH))
     {
         bUseRegularExpressions = sal_True;
@@ -404,7 +404,7 @@ void ScXMLConditionContext::EndElement()
     else
     {
         aFilterField.StringValue = sConditionValue;
-        aFilterField.IsNumeric = sal_False;
+        aFilterField.IsNumeric = false;
     }
     pFilterContext->AddFilterField(aFilterField);
 }
@@ -412,7 +412,7 @@ void ScXMLConditionContext::EndElement()
 //==========================================================================
 
 ScXMLDPFilterContext::ScXMLDPFilterContext( ScXMLImport& rImport,
-                                      USHORT nPrfx,
+                                      sal_uInt16 nPrfx,
                                       const ::rtl::OUString& rLName,
                                       const ::com::sun::star::uno::Reference<
                                       ::com::sun::star::xml::sax::XAttributeList>& xAttrList,
@@ -421,12 +421,12 @@ ScXMLDPFilterContext::ScXMLDPFilterContext( ScXMLImport& rImport,
     pDataPilotTable(pTempDataPilotTableContext),
     aFilterFields(),
     nFilterFieldCount(0),
-    bSkipDuplicates(sal_False),
-    bCopyOutputData(sal_False),
-    bUseRegularExpressions(sal_False),
+    bSkipDuplicates(false),
+    bCopyOutputData(false),
+    bUseRegularExpressions(false),
     bConnectionOr(sal_True),
     bNextConnectionOr(sal_True),
-    bConditionSourceRange(sal_False)
+    bConditionSourceRange(false)
 {
     ScDocument* pDoc(GetScImport().GetDocument());
 
@@ -436,7 +436,7 @@ ScXMLDPFilterContext::ScXMLDPFilterContext( ScXMLImport& rImport,
     {
         const rtl::OUString& sAttrName(xAttrList->getNameByIndex( i ));
         rtl::OUString aLocalName;
-        USHORT nPrefix(GetScImport().GetNamespaceMap().GetKeyByAttrName(
+        sal_uInt16 nPrefix(GetScImport().GetNamespaceMap().GetKeyByAttrName(
                                             sAttrName, &aLocalName ));
         const rtl::OUString& sValue(xAttrList->getValueByIndex( i ));
 
@@ -478,7 +478,7 @@ ScXMLDPFilterContext::~ScXMLDPFilterContext()
 {
 }
 
-SvXMLImportContext *ScXMLDPFilterContext::CreateChildContext( USHORT nPrefix,
+SvXMLImportContext *ScXMLDPFilterContext::CreateChildContext( sal_uInt16 nPrefix,
                                             const ::rtl::OUString& rLName,
                                             const ::com::sun::star::uno::Reference<
                                           ::com::sun::star::xml::sax::XAttributeList>& xAttrList )
@@ -526,7 +526,7 @@ void ScXMLDPFilterContext::EndElement()
         pDataPilotTable->SetFilterCopyOutputData(bCopyOutputData);
     }
     else
-        pDataPilotTable->SetFilterCopyOutputData(sal_False);
+        pDataPilotTable->SetFilterCopyOutputData(false);
 //	pDataPilotTable->SetFilterIsCaseSensitive(bIsCaseSensitive);
 //	pDataPilotTable->SetFilterSkipDuplicates(bSkipDuplicates);
     pDataPilotTable->SetSourceQueryParam(aFilterFields);
@@ -544,7 +544,7 @@ void ScXMLDPFilterContext::AddFilterField (const ScQueryEntry& aFilterField)
 }
 
 ScXMLDPAndContext::ScXMLDPAndContext( ScXMLImport& rImport,
-                                      USHORT nPrfx,
+                                      sal_uInt16 nPrfx,
                                       const ::rtl::OUString& rLName,
                                       const ::com::sun::star::uno::Reference<
                                       ::com::sun::star::xml::sax::XAttributeList>& /* xAttrList */,
@@ -552,14 +552,14 @@ ScXMLDPAndContext::ScXMLDPAndContext( ScXMLImport& rImport,
     SvXMLImportContext( rImport, nPrfx, rLName )
 {
     pFilterContext = pTempFilterContext;
-    pFilterContext->OpenConnection(sal_False);
+    pFilterContext->OpenConnection(false);
 }
 
 ScXMLDPAndContext::~ScXMLDPAndContext()
 {
 }
 
-SvXMLImportContext *ScXMLDPAndContext::CreateChildContext( USHORT nPrefix,
+SvXMLImportContext *ScXMLDPAndContext::CreateChildContext( sal_uInt16 nPrefix,
                                             const ::rtl::OUString& rLName,
                                             const ::com::sun::star::uno::Reference<
                                           ::com::sun::star::xml::sax::XAttributeList>& xAttrList )
@@ -594,7 +594,7 @@ void ScXMLDPAndContext::EndElement()
 }
 
 ScXMLDPOrContext::ScXMLDPOrContext( ScXMLImport& rImport,
-                                      USHORT nPrfx,
+                                      sal_uInt16 nPrfx,
                                       const ::rtl::OUString& rLName,
                                       const ::com::sun::star::uno::Reference<
                                       ::com::sun::star::xml::sax::XAttributeList>& /* xAttrList */,
@@ -609,7 +609,7 @@ ScXMLDPOrContext::~ScXMLDPOrContext()
 {
 }
 
-SvXMLImportContext *ScXMLDPOrContext::CreateChildContext( USHORT nPrefix,
+SvXMLImportContext *ScXMLDPOrContext::CreateChildContext( sal_uInt16 nPrefix,
                                             const ::rtl::OUString& rLName,
                                             const ::com::sun::star::uno::Reference<
                                           ::com::sun::star::xml::sax::XAttributeList>& xAttrList )
@@ -645,7 +645,7 @@ void ScXMLDPOrContext::EndElement()
 }
 
 ScXMLDPConditionContext::ScXMLDPConditionContext( ScXMLImport& rImport,
-                                      USHORT nPrfx,
+                                      sal_uInt16 nPrfx,
                                       const ::rtl::OUString& rLName,
                                       const ::com::sun::star::uno::Reference<
                                       ::com::sun::star::xml::sax::XAttributeList>& xAttrList,
@@ -653,7 +653,7 @@ ScXMLDPConditionContext::ScXMLDPConditionContext( ScXMLImport& rImport,
     SvXMLImportContext( rImport, nPrfx, rLName ),
     pFilterContext(pTempFilterContext),
     sDataType(GetXMLToken(XML_TEXT)),
-    bIsCaseSensitive(sal_False)
+    bIsCaseSensitive(false)
 {
 
     sal_Int16 nAttrCount(xAttrList.is() ? xAttrList->getLength() : 0);
@@ -662,7 +662,7 @@ ScXMLDPConditionContext::ScXMLDPConditionContext( ScXMLImport& rImport,
     {
         const rtl::OUString& sAttrName(xAttrList->getNameByIndex( i ));
         rtl::OUString aLocalName;
-        USHORT nPrefix(GetScImport().GetNamespaceMap().GetKeyByAttrName(
+        sal_uInt16 nPrefix(GetScImport().GetNamespaceMap().GetKeyByAttrName(
                                             sAttrName, &aLocalName ));
         const rtl::OUString& sValue(xAttrList->getValueByIndex( i ));
 
@@ -701,7 +701,7 @@ ScXMLDPConditionContext::~ScXMLDPConditionContext()
 {
 }
 
-SvXMLImportContext *ScXMLDPConditionContext::CreateChildContext( USHORT nPrefix,
+SvXMLImportContext *ScXMLDPConditionContext::CreateChildContext( sal_uInt16 nPrefix,
                                             const ::rtl::OUString& rLName,
                                             const ::com::sun::star::uno::Reference<
                                         ::com::sun::star::xml::sax::XAttributeList>& /* xAttrList */ )
@@ -712,7 +712,7 @@ SvXMLImportContext *ScXMLDPConditionContext::CreateChildContext( USHORT nPrefix,
 void ScXMLDPConditionContext::getOperatorXML(const rtl::OUString sTempOperator, ScQueryOp& aFilterOperator, sal_Bool& bUseRegularExpressions,
                                             double& dVal) const
 {
-    bUseRegularExpressions = sal_False;
+    bUseRegularExpressions = false;
     if (IsXMLToken(sTempOperator, XML_MATCH))
     {
         bUseRegularExpressions = sal_True;
@@ -766,7 +766,7 @@ void ScXMLDPConditionContext::EndElement()
     {
         aFilterField.nVal = sConditionValue.toDouble();
         *aFilterField.pStr = sConditionValue;
-        aFilterField.bQueryByString = sal_False;
+        aFilterField.bQueryByString = false;
         if (dVal != 0.0)
         {
             aFilterField.nVal = dVal;
