@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -29,7 +29,6 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_sc.hxx"
 
-
 #include <sfx2/dispatch.hxx>
 #include <svl/stritem.hxx>
 
@@ -48,6 +47,7 @@
 #include "condfrmt.hxx"
 #undef _CONDFRMT_CXX
 
+#include "rangelst.hxx"
 
 //============================================================================
 //	class ScConditionalFormat
@@ -72,7 +72,6 @@ ScConditionalFormatDlg::ScConditionalFormatDlg(
         aFtCond1Template	( this, ScResId( FT_COND1_TEMPLATE ) ),
         aLbCond1Template	( this, ScResId( LB_COND1_TEMPLATE ) ),
         aBtnNew1            ( this, ScResId( BTN_COND1_NEW ) ),
-        aFlSep1             ( this, ScResId( FL_SEP1 ) ),
 
         aCbxCond2			( this, ScResId( CBX_COND2 ) ),
         aLbCond21			( this, ScResId( LB_COND2_1 ) ),
@@ -85,7 +84,6 @@ ScConditionalFormatDlg::ScConditionalFormatDlg(
         aFtCond2Template	( this, ScResId( FT_COND2_TEMPLATE ) ),
         aLbCond2Template	( this, ScResId( LB_COND2_TEMPLATE ) ),
         aBtnNew2            ( this, ScResId( BTN_COND2_NEW ) ),
-        aFlSep2             ( this, ScResId( FL_SEP2 ) ),
 
         aCbxCond3			( this, ScResId( CBX_COND3 ) ),
         aLbCond31			( this, ScResId( LB_COND3_1 ) ),
@@ -102,8 +100,10 @@ ScConditionalFormatDlg::ScConditionalFormatDlg(
         aBtnOk				( this, ScResId( BTN_OK ) ),
         aBtnCancel			( this, ScResId( BTN_CANCEL ) ),
         aBtnHelp			( this, ScResId( BTN_HELP ) ),
+        aFlSep2             ( this, ScResId( FL_SEP2 ) ),
+        aFlSep1             ( this, ScResId( FL_SEP1 ) ),
         pEdActive			( NULL ),
-        bDlgLostFocus       ( FALSE ),
+        bDlgLostFocus       ( false ),
 
         pDoc				( pCurDoc )
 {
@@ -188,7 +188,7 @@ ScConditionalFormatDlg::ScConditionalFormatDlg(
     aCond2Size2 = Size( aPos.X() - aCond2Pos2.X(), aCond2Size3.Height() );
     aCond2Size1 = Size( aPos.X() - aCond2Pos1.X(), aCond2Size3.Height() );
 
-    aCbxCond2.Check( FALSE );
+    aCbxCond2.Check( false );
     aLbCond21.SelectEntryPos( 0 );
     aLbCond22.SelectEntryPos( 0 );
 
@@ -203,7 +203,7 @@ ScConditionalFormatDlg::ScConditionalFormatDlg(
     aCond3Size2 = Size( aPos.X() - aCond3Pos2.X(), aCond3Size3.Height() );
     aCond3Size1 = Size( aPos.X() - aCond3Pos1.X(), aCond3Size3.Height() );
 
-    aCbxCond3.Check( FALSE );
+    aCbxCond3.Check( false );
     aLbCond31.SelectEntryPos( 0 );
     aLbCond32.SelectEntryPos( 0 );
 
@@ -256,16 +256,15 @@ ScConditionalFormatDlg::ScConditionalFormatDlg(
                 ;
             else									// via Werte
             {
-                aLbCond12.SelectEntryPos( sal::static_int_cast<USHORT>( eMode ) );
+                aLbCond12.SelectEntryPos( sal::static_int_cast<sal_uInt16>( eMode ) );
                 if ( ( eMode == SC_COND_BETWEEN ) || ( eMode == SC_COND_NOTBETWEEN ) )
                     aEdtCond12.SetText( pEntry->GetExpression( aCurPos, 1 ) );
             }
         }
 
-
         if ( pCurrentFormat->Count() > 1 )
         {
-            aCbxCond2.Check( TRUE );
+            aCbxCond2.Check( sal_True );
             pEntry= pCurrentFormat->GetEntry( 1 );
             aEdtCond21.SetText( pEntry->GetExpression( aCurPos, 0 ) );
             aLbCond2Template.SelectEntry( pEntry->GetStyle() );
@@ -280,7 +279,7 @@ ScConditionalFormatDlg::ScConditionalFormatDlg(
                 ;
             else									// via Werte
             {
-                aLbCond22.SelectEntryPos( sal::static_int_cast<USHORT>( eMode ) );
+                aLbCond22.SelectEntryPos( sal::static_int_cast<sal_uInt16>( eMode ) );
                 if ( ( eMode == SC_COND_BETWEEN ) || ( eMode == SC_COND_NOTBETWEEN ) )
                     aEdtCond22.SetText( pEntry->GetExpression( aCurPos, 1 ) );
             }
@@ -288,7 +287,7 @@ ScConditionalFormatDlg::ScConditionalFormatDlg(
 
         if ( pCurrentFormat->Count() > 2 )
         {
-            aCbxCond3.Check( TRUE );
+            aCbxCond3.Check( sal_True );
             pEntry= pCurrentFormat->GetEntry( 2 );
             aEdtCond31.SetText( pEntry->GetExpression( aCurPos, 0 ) );
             aLbCond3Template.SelectEntry( pEntry->GetStyle() );
@@ -303,7 +302,7 @@ ScConditionalFormatDlg::ScConditionalFormatDlg(
                 ;
             else									// via Werte
             {
-                aLbCond32.SelectEntryPos( sal::static_int_cast<USHORT>( eMode ) );
+                aLbCond32.SelectEntryPos( sal::static_int_cast<sal_uInt16>( eMode ) );
                 if ( ( eMode == SC_COND_BETWEEN ) || ( eMode == SC_COND_NOTBETWEEN ) )
                     aEdtCond32.SetText( pEntry->GetExpression( aCurPos, 1 ) );
             }
@@ -323,17 +322,41 @@ ScConditionalFormatDlg::ScConditionalFormatDlg(
     //@BugID 54702 Enablen/Disablen nur noch in Basisklasse
     //SFX_APPWINDOW->Enable();		// Ref-Feld hat Focus
 //	SFX_APPWINDOW->Disable();
-}
 
+    aLbCond11.SetAccessibleRelationLabeledBy( &aCbxCond1 );
+    aLbCond12.SetAccessibleRelationLabeledBy( &aCbxCond1 );
+    aEdtCond11.SetAccessibleRelationLabeledBy( &aCbxCond1 );
+    aRbCond11.SetAccessibleRelationLabeledBy( &aCbxCond1 );
+
+    aLbCond21.SetAccessibleRelationLabeledBy( &aCbxCond2 );
+    aLbCond22.SetAccessibleRelationLabeledBy( &aCbxCond2 );
+    aEdtCond21.SetAccessibleRelationLabeledBy( &aCbxCond2 );
+    aRbCond21.SetAccessibleRelationLabeledBy( &aCbxCond2 );
+
+    aLbCond31.SetAccessibleRelationLabeledBy( &aCbxCond3 );
+    aLbCond32.SetAccessibleRelationLabeledBy( &aCbxCond3 );
+    aEdtCond31.SetAccessibleRelationLabeledBy( &aCbxCond3 );
+    aRbCond31.SetAccessibleRelationLabeledBy( &aCbxCond3 );
+    aLbCond11.SetAccessibleName( ScResId(LABEL_FORMARTTING_CONDITIONS) );
+    aLbCond12.SetAccessibleName( ScResId(LABEL_CONDITIONS) );
+    aEdtCond11.SetAccessibleName( ScResId(LABEL_CONDITION_VALUE) );
+
+    aLbCond21.SetAccessibleName( ScResId(LABEL_FORMARTTING_CONDITIONS) );
+    aLbCond22.SetAccessibleName( ScResId(LABEL_CONDITIONS) );
+    aEdtCond21.SetAccessibleName( ScResId(LABEL_CONDITION_VALUE) );
+
+    aLbCond31.SetAccessibleName( ScResId(LABEL_FORMARTTING_CONDITIONS) );
+    aLbCond32.SetAccessibleName( ScResId(LABEL_CONDITIONS) );
+    aEdtCond31.SetAccessibleName( ScResId(LABEL_CONDITION_VALUE) );
+}
 
 //----------------------------------------------------------------------------
 // Destruktor
 
-__EXPORT ScConditionalFormatDlg::~ScConditionalFormatDlg()
+ScConditionalFormatDlg::~ScConditionalFormatDlg()
 {
 }
 
-
 //----------------------------------------------------------------------------
 
 void ScConditionalFormatDlg::SetReference( const ScRange& rRef, ScDocument* pDocP )
@@ -375,19 +398,18 @@ void ScConditionalFormatDlg::AddRefEntry()
 
 //----------------------------------------------------------------------------
 
-BOOL ScConditionalFormatDlg::IsRefInputMode() const
+sal_Bool ScConditionalFormatDlg::IsRefInputMode() const
 {
     return (pEdActive != NULL);
 }
 
-
 //----------------------------------------------------------------------------
 
 void ScConditionalFormatDlg::SetActive()
 {
     if ( bDlgLostFocus )
     {
-        bDlgLostFocus = FALSE;
+        bDlgLostFocus = false;
         if( pEdActive )
             pEdActive->GrabFocus();
     }
@@ -397,7 +419,6 @@ void ScConditionalFormatDlg::SetActive()
     RefInputDone();
 }
 
-
 //----------------------------------------------------------------------------
 // Holt die ausgewaehlte bedingte Formatierung ab
 
@@ -413,6 +434,9 @@ void ScConditionalFormatDlg::GetConditionalFormat( ScConditionalFormat& rCndFmt
     if (pViewShell)
     {
         ScViewData* pData = pViewShell->GetViewData();
+        ScRangeListRef rRanges;
+        pData->GetMultiArea( rRanges );
+        rCndFmt.AddRangeInfo( rRanges );
         aCurPos = ScAddress( pData->GetCurX(), pData->GetCurY(), pData->GetTabNo() );
     }
 
@@ -456,16 +480,14 @@ void ScConditionalFormatDlg::GetConditionalFormat( ScConditionalFormat& rCndFmt
     }
 }
 
-
 //----------------------------------------------------------------------------
 // Zerstoert den Dialog
 
-BOOL ScConditionalFormatDlg::Close()
+sal_Bool ScConditionalFormatDlg::Close()
 {
     return DoClose( ScCondFormatDlgWrapper::GetChildWindowId() );
 }
 
-
 //----------------------------------------------------------------------------
 // Handler:
 
@@ -474,7 +496,7 @@ BOOL ScConditionalFormatDlg::Close()
 
 IMPL_LINK( ScConditionalFormatDlg, ClickCond1Hdl, void *, EMPTYARG )
 {
-    BOOL bChecked = aCbxCond1.IsChecked();
+    sal_Bool bChecked = aCbxCond1.IsChecked();
 
     aLbCond11.Enable( bChecked );
     aLbCond12.Enable( bChecked );
@@ -490,13 +512,12 @@ IMPL_LINK( ScConditionalFormatDlg, ClickCond1Hdl, void *, EMPTYARG )
     return( 0L );
 }
 
-
 //----------------------------------------------------------------------------
 // Zellwert/Formel
 
 IMPL_LINK( ScConditionalFormatDlg, ChangeCond11Hdl, void *, EMPTYARG )
 {
-    USHORT nPos = aLbCond11.GetSelectEntryPos();
+    sal_uInt16 nPos = aLbCond11.GetSelectEntryPos();
 
     if( nPos == 0 ) // Zellwert
     {
@@ -518,7 +539,6 @@ IMPL_LINK( ScConditionalFormatDlg, ChangeCond11Hdl, void *, EMPTYARG )
     return( 0L );
 }
 
-
 //----------------------------------------------------------------------------
 // zwischen, gleich, groesser, ...
 
@@ -526,9 +546,19 @@ IMPL_LINK( ScConditionalFormatDlg, ChangeCond12Hdl, void *, EMPTYARG )
 {
     if( aLbCond12.IsVisible() )
     {
-        USHORT nPos = aLbCond12.GetSelectEntryPos();
+        sal_uInt16 nPos = aLbCond12.GetSelectEntryPos();
 
-        if( nPos == 6  || nPos == 7 ) // zwischen, n. zwischen
+        aEdtCond11.Show();
+        aRbCond11.Show();
+        if( nPos > 7 )
+        {
+            aEdtCond11.Hide();
+            aRbCond11.Hide();
+            aFtCond1And.Hide();
+            aEdtCond12.Hide();
+            aRbCond12.Hide();
+        }
+        else if( nPos == 6  || nPos == 7 ) // zwischen, n. zwischen
         {
             aEdtCond11.SetSizePixel( aCond1Size3 );
             aRbCond11.SetPosPixel( aRBtn1Pos1 );
@@ -549,13 +579,12 @@ IMPL_LINK( ScConditionalFormatDlg, ChangeCond12Hdl, void *, EMPTYARG )
     return( 0L );
 }
 
-
 //----------------------------------------------------------------------------
 // Enabled/Disabled Condition2-Controls
 
 IMPL_LINK( ScConditionalFormatDlg, ClickCond2Hdl, void *, EMPTYARG )
 {
-    BOOL bChecked = aCbxCond2.IsChecked();
+    sal_Bool bChecked = aCbxCond2.IsChecked();
 
     aLbCond21.Enable( bChecked );
     aLbCond22.Enable( bChecked );
@@ -571,13 +600,12 @@ IMPL_LINK( ScConditionalFormatDlg, ClickCond2Hdl, void *, EMPTYARG )
     return( 0L );
 }
 
-
 //----------------------------------------------------------------------------
 // Zellwert/Formel
 
 IMPL_LINK( ScConditionalFormatDlg, ChangeCond21Hdl, void *, EMPTYARG )
 {
-    USHORT nPos = aLbCond21.GetSelectEntryPos();
+    sal_uInt16 nPos = aLbCond21.GetSelectEntryPos();
 
     if( nPos == 0 ) // Zellwert
     {
@@ -599,7 +627,6 @@ IMPL_LINK( ScConditionalFormatDlg, ChangeCond21Hdl, void *, EMPTYARG )
     return( 0L );
 }
 
-
 //----------------------------------------------------------------------------
 // zwischen, gleich, groesser, ...
 
@@ -607,9 +634,19 @@ IMPL_LINK( ScConditionalFormatDlg, ChangeCond22Hdl, void *, EMPTYARG )
 {
     if( aLbCond22.IsVisible() )
     {
-        USHORT nPos = aLbCond22.GetSelectEntryPos();
+        sal_uInt16 nPos = aLbCond22.GetSelectEntryPos();
 
-        if( nPos == 6  || nPos == 7 ) // zwischen, n. zwischen
+        aEdtCond21.Show();
+        aRbCond21.Show();
+        if( nPos > 7 )
+        {
+            aEdtCond21.Hide();
+            aRbCond21.Hide();
+            aFtCond2And.Hide();
+            aEdtCond22.Hide();
+            aRbCond22.Hide();
+        }
+        else if( nPos == 6  || nPos == 7 ) // zwischen, n. zwischen
         {
             aEdtCond21.SetSizePixel( aCond2Size3 );
             aRbCond21.SetPosPixel( aRBtn2Pos1 );
@@ -630,13 +667,12 @@ IMPL_LINK( ScConditionalFormatDlg, ChangeCond22Hdl, void *, EMPTYARG )
     return( 0L );
 }
 
-
 //----------------------------------------------------------------------------
 // Enabled/Disabled Condition3-Controls
 
 IMPL_LINK( ScConditionalFormatDlg, ClickCond3Hdl, void *, EMPTYARG )
 {
-    BOOL bChecked = aCbxCond3.IsChecked();
+    sal_Bool bChecked = aCbxCond3.IsChecked();
 
     aLbCond31.Enable( bChecked );
     aLbCond32.Enable( bChecked );
@@ -652,13 +688,12 @@ IMPL_LINK( ScConditionalFormatDlg, ClickCond3Hdl, void *, EMPTYARG )
     return( 0L );
 }
 
-
 //----------------------------------------------------------------------------
 // Zellwert/Formel
 
 IMPL_LINK( ScConditionalFormatDlg, ChangeCond31Hdl, void *, EMPTYARG )
 {
-    USHORT nPos = aLbCond31.GetSelectEntryPos();
+    sal_uInt16 nPos = aLbCond31.GetSelectEntryPos();
 
     if( nPos == 0 ) // Zellwert
     {
@@ -680,7 +715,6 @@ IMPL_LINK( ScConditionalFormatDlg, ChangeCond31Hdl, void *, EMPTYARG )
     return( 0L );
 }
 
-
 //----------------------------------------------------------------------------
 // zwischen, gleich, groesser, ...
 
@@ -688,9 +722,19 @@ IMPL_LINK( ScConditionalFormatDlg, ChangeCond32Hdl, void *, EMPTYARG )
 {
     if( aLbCond32.IsVisible() )
     {
-        USHORT nPos = aLbCond32.GetSelectEntryPos();
+        sal_uInt16 nPos = aLbCond32.GetSelectEntryPos();
 
-        if( nPos == 6  || nPos == 7 ) // zwischen, n. zwischen
+        aEdtCond31.Show();
+        aRbCond31.Show();
+        if( nPos > 7 )
+        {
+            aEdtCond31.Hide();
+            aRbCond31.Hide();
+            aFtCond3And.Hide();
+            aEdtCond32.Hide();
+            aRbCond32.Hide();
+        }
+        else if( nPos == 6  || nPos == 7 ) // zwischen, n. zwischen
         {
             aEdtCond31.SetSizePixel( aCond3Size3 );
             aRbCond31.SetPosPixel( aRBtn3Pos1 );
@@ -711,7 +755,6 @@ IMPL_LINK( ScConditionalFormatDlg, ChangeCond32Hdl, void *, EMPTYARG )
     return( 0L );
 }
 
-
 //----------------------------------------------------------------------------
 
 IMPL_LINK( ScConditionalFormatDlg, GetFocusHdl, Control*, pCtrl )
@@ -737,7 +780,6 @@ IMPL_LINK( ScConditionalFormatDlg, GetFocusHdl, Control*, pCtrl )
     return 0;
 }
 
-
 //----------------------------------------------------------------------------
 
 IMPL_LINK( ScConditionalFormatDlg, LoseFocusHdl, Control*, EMPTYARG )
@@ -746,7 +788,6 @@ IMPL_LINK( ScConditionalFormatDlg, LoseFocusHdl, Control*, EMPTYARG )
     return 0;
 }
 
-
 //----------------------------------------------------------------------------
 //	[OK], [Cancel]
 
@@ -758,7 +799,7 @@ IMPL_LINK( ScConditionalFormatDlg, BtnHdl, PushButton*, pBtn )
         GetConditionalFormat( aCondFrmt );
         ScCondFrmtItem aOutItem( FID_CONDITIONAL_FORMAT, aCondFrmt );
 
-        SetDispatcherLock( FALSE );
+        SetDispatcherLock( false );
         SwitchToDocument();
         GetBindings().GetDispatcher()->Execute( FID_CONDITIONAL_FORMAT,
                                   SFX_CALLMODE_SLOT | SFX_CALLMODE_RECORD,
@@ -771,7 +812,6 @@ IMPL_LINK( ScConditionalFormatDlg, BtnHdl, PushButton*, pBtn )
     return( 0L );
 }
 
-
 //----------------------------------------------------------------------------
 
 IMPL_LINK( ScConditionalFormatDlg, NewBtnHdl, PushButton*, pBtn )
@@ -782,9 +822,9 @@ IMPL_LINK( ScConditionalFormatDlg, NewBtnHdl, PushButton*, pBtn )
     // unlock the dispatcher so SID_STYLE_NEW can be executed
     // (SetDispatcherLock would affect all Calc documents)
     SfxDispatcher* pDisp = GetBindings().GetDispatcher();
-    BOOL bLocked = pDisp->IsLocked();
+    sal_Bool bLocked = pDisp->IsLocked();
     if (bLocked)
-        pDisp->Lock(sal_False);
+        pDisp->Lock(false);
 
     // Execute the "new style" slot, complete with undo and all necessary updates.
     // The return value (SfxUInt16Item) is ignored, look for new styles instead.
