@@ -184,21 +184,6 @@ SC_SIMPLE_SERVICE_INFO( ScSpreadsheetSettings, "ScSpreadsheetSettings", SCSPREAD
 
 //------------------------------------------------------------------------
 
-static void lcl_WriteInfo( registry::XRegistryKey* pRegistryKey,
-                        const rtl::OUString& rImplementationName,
-                        const uno::Sequence< rtl::OUString >& rServices )
-                    throw( registry::InvalidRegistryException )
-{
-    rtl::OUString aImpl(rtl::OUString::createFromAscii( "/" ));
-    aImpl += rImplementationName;
-    aImpl += rtl::OUString::createFromAscii( "/UNO/SERVICES" );
-    uno::Reference<registry::XRegistryKey> xNewKey(pRegistryKey->createKey(aImpl));
-
-    const rtl::OUString* pArray = rServices.getConstArray();
-    for( sal_Int32 i = 0; i < rServices.getLength(); i++ )
-        xNewKey->createKey( pArray[i]);
-}
-
 extern "C" {
 
 SAL_DLLPUBLIC_EXPORT void SAL_CALL component_getImplementationEnvironment(
@@ -207,111 +192,6 @@ SAL_DLLPUBLIC_EXPORT void SAL_CALL component_getImplementationEnvironment(
     *ppEnvTypeName = CPPU_CURRENT_LANGUAGE_BINDING_NAME;
 }
 
-SAL_DLLPUBLIC_EXPORT sal_Bool SAL_CALL component_writeInfo(
-    void * /* pServiceManager */, registry::XRegistryKey * pRegistryKey )
-{
-    if (pRegistryKey)
-    {
-        try
-        {
-            lcl_WriteInfo( pRegistryKey,
-                            ScSpreadsheetSettings::getImplementationName_Static(),
-                            ScSpreadsheetSettings::getSupportedServiceNames_Static() );
-
-            lcl_WriteInfo( pRegistryKey,
-                            ScRecentFunctionsObj::getImplementationName_Static(),
-                            ScRecentFunctionsObj::getSupportedServiceNames_Static() );
-
-            lcl_WriteInfo( pRegistryKey,
-                            ScFunctionListObj::getImplementationName_Static(),
-                            ScFunctionListObj::getSupportedServiceNames_Static() );
-
-            lcl_WriteInfo( pRegistryKey,
-                            ScAutoFormatsObj::getImplementationName_Static(),
-                            ScAutoFormatsObj::getSupportedServiceNames_Static() );
-
-            lcl_WriteInfo( pRegistryKey,
-                            ScFunctionAccess::getImplementationName_Static(),
-                            ScFunctionAccess::getSupportedServiceNames_Static() );
-
-            lcl_WriteInfo( pRegistryKey,
-                            ScFilterOptionsObj::getImplementationName_Static(),
-                            ScFilterOptionsObj::getSupportedServiceNames_Static() );
-
-            lcl_WriteInfo( pRegistryKey,
-                            ScXMLImport_getImplementationName(),
-                            ScXMLImport_getSupportedServiceNames() );
-
-            lcl_WriteInfo( pRegistryKey,
-                            ScXMLImport_Meta_getImplementationName(),
-                            ScXMLImport_Meta_getSupportedServiceNames() );
-
-            lcl_WriteInfo( pRegistryKey,
-                            ScXMLImport_Styles_getImplementationName(),
-                            ScXMLImport_Styles_getSupportedServiceNames() );
-
-            lcl_WriteInfo( pRegistryKey,
-                            ScXMLImport_Content_getImplementationName(),
-                            ScXMLImport_Content_getSupportedServiceNames() );
-
-            lcl_WriteInfo( pRegistryKey,
-                            ScXMLImport_Settings_getImplementationName(),
-                            ScXMLImport_Settings_getSupportedServiceNames() );
-
-            lcl_WriteInfo( pRegistryKey,
-                            ScXMLOOoExport_getImplementationName(),
-                            ScXMLOOoExport_getSupportedServiceNames() );
-
-            lcl_WriteInfo( pRegistryKey,
-                            ScXMLOOoExport_Meta_getImplementationName(),
-                            ScXMLOOoExport_Meta_getSupportedServiceNames() );
-
-            lcl_WriteInfo( pRegistryKey,
-                            ScXMLOOoExport_Styles_getImplementationName(),
-                            ScXMLOOoExport_Styles_getSupportedServiceNames() );
-
-            lcl_WriteInfo( pRegistryKey,
-                            ScXMLOOoExport_Content_getImplementationName(),
-                            ScXMLOOoExport_Content_getSupportedServiceNames() );
-
-            lcl_WriteInfo( pRegistryKey,
-                            ScXMLOOoExport_Settings_getImplementationName(),
-                            ScXMLOOoExport_Settings_getSupportedServiceNames() );
-
-            lcl_WriteInfo( pRegistryKey,
-                            ScXMLOasisExport_getImplementationName(),
-                            ScXMLOasisExport_getSupportedServiceNames() );
-
-            lcl_WriteInfo( pRegistryKey,
-                            ScXMLOasisExport_Meta_getImplementationName(),
-                            ScXMLOasisExport_Meta_getSupportedServiceNames() );
-
-            lcl_WriteInfo( pRegistryKey,
-                            ScXMLOasisExport_Styles_getImplementationName(),
-                            ScXMLOasisExport_Styles_getSupportedServiceNames() );
-
-            lcl_WriteInfo( pRegistryKey,
-                            ScXMLOasisExport_Content_getImplementationName(),
-                            ScXMLOasisExport_Content_getSupportedServiceNames() );
-
-            lcl_WriteInfo( pRegistryKey,
-                            ScXMLOasisExport_Settings_getImplementationName(),
-                            ScXMLOasisExport_Settings_getSupportedServiceNames() );
-
-            lcl_WriteInfo( pRegistryKey,
-                            ScDocument_getImplementationName(),
-                            ScDocument_getSupportedServiceNames() );
-
-            return sal_True;
-        }
-        catch (registry::InvalidRegistryException&)
-        {
-            OSL_ENSURE( sal_False, "### InvalidRegistryException!" );
-        }
-    }
-    return sal_False;
-}
-
 SAL_DLLPUBLIC_EXPORT void * SAL_CALL component_getFactory(
     const sal_Char * pImplName, void * pServiceManager, void * /* pRegistryKey */ )
 {
@@ -504,14 +384,14 @@ uno::Reference<uno::XInterface>	SAL_CALL ScSpreadsheetSettings_CreateInstance(
 
 rtl::OUString ScSpreadsheetSettings::getImplementationName_Static()
 {
-    return rtl::OUString::createFromAscii( "stardiv.StarCalc.ScSpreadsheetSettings" );
+    return rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "stardiv.StarCalc.ScSpreadsheetSettings" ));
 }
 
 uno::Sequence<rtl::OUString> ScSpreadsheetSettings::getSupportedServiceNames_Static()
 {
     uno::Sequence<rtl::OUString> aRet(1);
     rtl::OUString* pArray = aRet.getArray();
-    pArray[0] = rtl::OUString::createFromAscii( SCSPREADSHEETSETTINGS_SERVICE );
+    pArray[0] = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( SCSPREADSHEETSETTINGS_SERVICE ));
     return aRet;
 }
 
@@ -538,74 +418,74 @@ void SAL_CALL ScSpreadsheetSettings::setPropertyValue(
     ScModule* pScMod = SC_MOD();
     ScAppOptions   aAppOpt(pScMod->GetAppOptions());
     ScInputOptions aInpOpt(pScMod->GetInputOptions());
-    BOOL bSaveApp = FALSE;
-    BOOL bSaveInp = FALSE;
+    sal_Bool bSaveApp = false;
+    sal_Bool bSaveInp = false;
     // print options aren't loaded until needed
 
     if (aString.EqualsAscii( SC_UNONAME_DOAUTOCP ))
     {
         aAppOpt.SetAutoComplete( ScUnoHelpFunctions::GetBoolFromAny( aValue ) );
-        bSaveApp = TRUE;
+        bSaveApp = sal_True;
     }
     else if (aString.EqualsAscii( SC_UNONAME_ENTERED ))
     {
         aInpOpt.SetEnterEdit( ScUnoHelpFunctions::GetBoolFromAny( aValue ) );
-        bSaveInp = TRUE;
+        bSaveInp = sal_True;
     }
     else if (aString.EqualsAscii( SC_UNONAME_EXPREF ))
     {
         aInpOpt.SetExpandRefs( ScUnoHelpFunctions::GetBoolFromAny( aValue ) );
-        bSaveInp = TRUE;
+        bSaveInp = sal_True;
     }
     else if (aString.EqualsAscii( SC_UNONAME_EXTFMT ))
     {
         aInpOpt.SetExtendFormat( ScUnoHelpFunctions::GetBoolFromAny( aValue ) );
-        bSaveInp = TRUE;
+        bSaveInp = sal_True;
     }
     else if (aString.EqualsAscii( SC_UNONAME_LINKUPD ))
     {
         aAppOpt.SetLinkMode( (ScLkUpdMode) ScUnoHelpFunctions::GetInt16FromAny( aValue ) );
-        bSaveApp = TRUE;
+        bSaveApp = sal_True;
     }
     else if (aString.EqualsAscii( SC_UNONAME_MARKHDR ))
     {
         aInpOpt.SetMarkHeader( ScUnoHelpFunctions::GetBoolFromAny( aValue ) );
-        bSaveInp = TRUE;
+        bSaveInp = sal_True;
     }
     else if (aString.EqualsAscii( SC_UNONAME_MOVESEL ))
     {
         aInpOpt.SetMoveSelection( ScUnoHelpFunctions::GetBoolFromAny( aValue ) );
-        bSaveInp = TRUE;
+        bSaveInp = sal_True;
     }
     else if (aString.EqualsAscii( SC_UNONAME_RANGEFIN ))
     {
         aInpOpt.SetRangeFinder( ScUnoHelpFunctions::GetBoolFromAny( aValue ) );
-        bSaveInp = TRUE;
+        bSaveInp = sal_True;
     }
     else if (aString.EqualsAscii( SC_UNONAME_USETABCOL ))
     {
         aInpOpt.SetUseTabCol( ScUnoHelpFunctions::GetBoolFromAny( aValue ) );
-        bSaveInp = TRUE;
+        bSaveInp = sal_True;
     }
     else if (aString.EqualsAscii( SC_UNONAME_PRMETRICS ))
     {
         aInpOpt.SetTextWysiwyg( ScUnoHelpFunctions::GetBoolFromAny( aValue ) );
-        bSaveInp = TRUE;
+        bSaveInp = sal_True;
     }
     else if (aString.EqualsAscii( SC_UNONAME_REPLWARN ))
     {
         aInpOpt.SetReplaceCellsWarn( ScUnoHelpFunctions::GetBoolFromAny( aValue ) );
-        bSaveInp = TRUE;
+        bSaveInp = sal_True;
     }
     else if (aString.EqualsAscii( SC_UNONAME_METRIC ))
     {
         aAppOpt.SetAppMetric( (FieldUnit) ScUnoHelpFunctions::GetInt16FromAny( aValue ) );
-        bSaveApp = TRUE;
+        bSaveApp = sal_True;
     }
     else if (aString.EqualsAscii( SC_UNONAME_MOVEDIR ))
     {
         aInpOpt.SetMoveDir( ScUnoHelpFunctions::GetInt16FromAny( aValue ) );
-        bSaveInp = TRUE;
+        bSaveInp = sal_True;
     }
     else if (aString.EqualsAscii( SC_UNONAME_SCALE ))
     {
@@ -626,12 +506,12 @@ void SAL_CALL ScSpreadsheetSettings::setPropertyValue(
             aAppOpt.SetZoom( nVal );
             aAppOpt.SetZoomType( SVX_ZOOM_PERCENT );
         }
-        bSaveApp = TRUE;
+        bSaveApp = sal_True;
     }
     else if (aString.EqualsAscii( SC_UNONAME_STBFUNC ))
     {
         aAppOpt.SetStatusFunc( ScUnoHelpFunctions::GetInt16FromAny( aValue ) );
-        bSaveApp = TRUE;
+        bSaveApp = sal_True;
     }
     else if (aString.EqualsAscii( SC_UNONAME_ULISTS ))
     {
@@ -643,16 +523,16 @@ void SAL_CALL ScSpreadsheetSettings::setPropertyValue(
             //	mehr tut ScGlobal::SetUserList auch nicht
 
             pUserList->FreeAll();					// alle Eintraege raus
-            USHORT nCount = (USHORT)aSeq.getLength();
+            sal_uInt16 nCount = (sal_uInt16)aSeq.getLength();
             const rtl::OUString* pAry = aSeq.getConstArray();
-            for (USHORT i=0; i<nCount; i++)
+            for (sal_uInt16 i=0; i<nCount; i++)
             {
                 String aEntry = pAry[i];
                 ScUserListData* pData = new ScUserListData(aEntry);
                 if (!pUserList->Insert(pData))		// hinten anhaengen
                     delete pData;					// sollte nicht vorkommen
             }
-            bSaveApp = TRUE;	// Liste wird mit den App-Optionen gespeichert
+            bSaveApp = sal_True;	// Liste wird mit den App-Optionen gespeichert
         }
     }
     else if (aString.EqualsAscii( SC_UNONAME_PRALLSH ))
@@ -704,7 +584,7 @@ uno::Any SAL_CALL ScSpreadsheetSettings::getPropertyValue( const rtl::OUString&
     else if (aString.EqualsAscii( SC_UNONAME_STBFUNC ))	aRet <<= (sal_Int16) aAppOpt.GetStatusFunc();
     else if (aString.EqualsAscii( SC_UNONAME_SCALE ))
     {
-        INT16 nZoomVal = 0;
+        sal_Int16 nZoomVal = 0;
         switch ( aAppOpt.GetZoomType() )
         {
             case SVX_ZOOM_PERCENT:	 nZoomVal = aAppOpt.GetZoom();	  break;
@@ -723,10 +603,10 @@ uno::Any SAL_CALL ScSpreadsheetSettings::getPropertyValue( const rtl::OUString&
         ScUserList* pUserList = ScGlobal::GetUserList();
         if (pUserList)
         {
-            USHORT nCount = pUserList->GetCount();
+            sal_uInt16 nCount = pUserList->GetCount();
             uno::Sequence<rtl::OUString> aSeq(nCount);
             rtl::OUString* pAry = aSeq.getArray();
-            for (USHORT i=0; i<nCount; i++)
+            for (sal_uInt16 i=0; i<nCount; i++)
             {
                 String aEntry((*pUserList)[i]->GetString());
                 pAry[i] = aEntry;
@@ -767,14 +647,14 @@ uno::Reference<uno::XInterface>	SAL_CALL ScRecentFunctionsObj_CreateInstance(
 
 rtl::OUString ScRecentFunctionsObj::getImplementationName_Static()
 {
-    return rtl::OUString::createFromAscii( "stardiv.StarCalc.ScRecentFunctionsObj" );
+    return rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "stardiv.StarCalc.ScRecentFunctionsObj" ));
 }
 
 uno::Sequence<rtl::OUString> ScRecentFunctionsObj::getSupportedServiceNames_Static()
 {
     uno::Sequence<rtl::OUString> aRet(1);
     rtl::OUString* pArray = aRet.getArray();
-    pArray[0] = rtl::OUString::createFromAscii( SCRECENTFUNCTIONSOBJ_SERVICE );
+    pArray[0] = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( SCRECENTFUNCTIONSOBJ_SERVICE ));
     return aRet;
 }
 
@@ -785,13 +665,13 @@ uno::Sequence<sal_Int32> SAL_CALL ScRecentFunctionsObj::getRecentFunctionIds()
 {
     SolarMutexGuard aGuard;
     const ScAppOptions& rOpt = SC_MOD()->GetAppOptions();
-    USHORT nCount = rOpt.GetLRUFuncListCount();
-    const USHORT* pFuncs = rOpt.GetLRUFuncList();
+    sal_uInt16 nCount = rOpt.GetLRUFuncListCount();
+    const sal_uInt16* pFuncs = rOpt.GetLRUFuncList();
     if (pFuncs)
     {
         uno::Sequence<sal_Int32> aSeq(nCount);
         sal_Int32* pAry = aSeq.getArray();
-        for (USHORT i=0; i<nCount; i++)
+        for (sal_uInt16 i=0; i<nCount; i++)
             pAry[i] = pFuncs[i];
         return aSeq;
     }
@@ -803,12 +683,12 @@ void SAL_CALL ScRecentFunctionsObj::setRecentFunctionIds(
                                     throw(uno::RuntimeException)
 {
     SolarMutexGuard aGuard;
-    USHORT nCount = (USHORT) Min( aRecentFunctionIds.getLength(), (INT32) LRU_MAX );
-    const INT32* pAry = aRecentFunctionIds.getConstArray();
+    sal_uInt16 nCount = (sal_uInt16) Min( aRecentFunctionIds.getLength(), (sal_Int32) LRU_MAX );
+    const sal_Int32* pAry = aRecentFunctionIds.getConstArray();
 
-    USHORT* pFuncs = nCount ? new USHORT[nCount] : NULL;
-    for (USHORT i=0; i<nCount; i++)
-        pFuncs[i] = (USHORT)pAry[i];		//! auf gueltige Werte testen?
+    sal_uInt16* pFuncs = nCount ? new sal_uInt16[nCount] : NULL;
+    for (sal_uInt16 i=0; i<nCount; i++)
+        pFuncs[i] = (sal_uInt16)pAry[i];		//! auf gueltige Werte testen?
 
     ScModule* pScMod = SC_MOD();
     ScAppOptions aNewOpts(pScMod->GetAppOptions());
@@ -848,14 +728,14 @@ uno::Reference<uno::XInterface>	SAL_CALL ScFunctionListObj_CreateInstance(
 
 rtl::OUString ScFunctionListObj::getImplementationName_Static()
 {
-    return rtl::OUString::createFromAscii( "stardiv.StarCalc.ScFunctionListObj" );
+    return rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "stardiv.StarCalc.ScFunctionListObj" ));
 }
 
 uno::Sequence<rtl::OUString> ScFunctionListObj::getSupportedServiceNames_Static()
 {
     uno::Sequence<rtl::OUString> aRet(1);
     rtl::OUString* pArray = aRet.getArray();
-    pArray[0] = rtl::OUString::createFromAscii( SCFUNCTIONLISTOBJ_SERVICE );
+    pArray[0] = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( SCFUNCTIONLISTOBJ_SERVICE ));
     return aRet;
 }
 
@@ -868,27 +748,27 @@ static void lcl_FillSequence( uno::Sequence<beans::PropertyValue>& rSequence, co
 
     beans::PropertyValue* pArray = rSequence.getArray();
 
-    pArray[0].Name = rtl::OUString::createFromAscii( SC_UNONAME_ID );
+    pArray[0].Name = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( SC_UNONAME_ID ));
     pArray[0].Value <<= (sal_Int32) rDesc.nFIndex;
 
-    pArray[1].Name = rtl::OUString::createFromAscii( SC_UNONAME_CATEGORY );
+    pArray[1].Name = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( SC_UNONAME_CATEGORY ));
     pArray[1].Value <<= (sal_Int32) rDesc.nCategory;
 
-    pArray[2].Name = rtl::OUString::createFromAscii( SC_UNONAME_NAME );
+    pArray[2].Name = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( SC_UNONAME_NAME ));
     if (rDesc.pFuncName)
         pArray[2].Value <<= rtl::OUString( *rDesc.pFuncName );
 
-    pArray[3].Name = rtl::OUString::createFromAscii( SC_UNONAME_DESCRIPTION );
+    pArray[3].Name = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( SC_UNONAME_DESCRIPTION ));
     if (rDesc.pFuncDesc)
         pArray[3].Value <<= rtl::OUString( *rDesc.pFuncDesc );
 
-    pArray[4].Name = rtl::OUString::createFromAscii( SC_UNONAME_ARGUMENTS );
+    pArray[4].Name = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( SC_UNONAME_ARGUMENTS ));
     if (rDesc.ppDefArgNames && rDesc.ppDefArgDescs && rDesc.pDefArgFlags )
     {
-        USHORT nCount = rDesc.nArgCount;
+        sal_uInt16 nCount = rDesc.nArgCount;
         if (nCount >= VAR_ARGS)
             nCount -= VAR_ARGS - 1;
-        USHORT nSeqCount = rDesc.GetSuppressedArgCount();
+        sal_uInt16 nSeqCount = rDesc.GetSuppressedArgCount();
         if (nSeqCount >= VAR_ARGS)
             nSeqCount -= VAR_ARGS - 1;
 
@@ -896,7 +776,7 @@ static void lcl_FillSequence( uno::Sequence<beans::PropertyValue>& rSequence, co
         {
             uno::Sequence<sheet::FunctionArgument> aArgSeq(nSeqCount);
             sheet::FunctionArgument* pArgAry = aArgSeq.getArray();
-            for (USHORT i=0, j=0; i<nCount; i++)
+            for (sal_uInt16 i=0, j=0; i<nCount; i++)
             {
                 if (!rDesc.pDefArgFlags[i].bSuppress)
                 {
@@ -925,8 +805,8 @@ uno::Sequence<beans::PropertyValue> SAL_CALL ScFunctionListObj::getById( sal_Int
     const ScFunctionList* pFuncList = ScGlobal::GetStarCalcFunctionList();
     if ( pFuncList )
     {
-        USHORT nCount = (USHORT)pFuncList->GetCount();
-        for (USHORT nIndex=0; nIndex<nCount; nIndex++)
+        sal_uInt16 nCount = (sal_uInt16)pFuncList->GetCount();
+        for (sal_uInt16 nIndex=0; nIndex<nCount; nIndex++)
         {
             const ScFuncDesc* pDesc = pFuncList->GetFunction(nIndex);
             if ( pDesc && pDesc->nFIndex == nId )
@@ -941,8 +821,6 @@ uno::Sequence<beans::PropertyValue> SAL_CALL ScFunctionListObj::getById( sal_Int
     }
     else
         throw uno::RuntimeException();					// should not happen
-
-//    return uno::Sequence<beans::PropertyValue>(0);
 }
 
 // XNameAccess
@@ -952,12 +830,12 @@ uno::Any SAL_CALL ScFunctionListObj::getByName( const rtl::OUString& aName )
                     lang::WrappedTargetException, uno::RuntimeException)
 {
     SolarMutexGuard aGuard;
-    String aNameStr(aName);
+    ::rtl::OUString aNameStr(aName);
     const ScFunctionList* pFuncList = ScGlobal::GetStarCalcFunctionList();
     if ( pFuncList )
     {
-        USHORT nCount = (USHORT)pFuncList->GetCount();
-        for (USHORT nIndex=0; nIndex<nCount; nIndex++)
+        sal_uInt16 nCount = (sal_uInt16)pFuncList->GetCount();
+        for (sal_uInt16 nIndex=0; nIndex<nCount; nIndex++)
         {
             const ScFuncDesc* pDesc = pFuncList->GetFunction(nIndex);
             //!	Case-insensitiv ???
@@ -973,8 +851,6 @@ uno::Any SAL_CALL ScFunctionListObj::getByName( const rtl::OUString& aName )
     }
     else
         throw uno::RuntimeException();					// should not happen
-
-//    return uno::Any();
 }
 
 // XIndexAccess
@@ -982,10 +858,10 @@ uno::Any SAL_CALL ScFunctionListObj::getByName( const rtl::OUString& aName )
 sal_Int32 SAL_CALL ScFunctionListObj::getCount() throw(uno::RuntimeException)
 {
     SolarMutexGuard aGuard;
-    USHORT nCount = 0;
+    sal_Int32 nCount = 0;
     const ScFunctionList* pFuncList = ScGlobal::GetStarCalcFunctionList();
     if ( pFuncList )
-        nCount = (USHORT)pFuncList->GetCount();
+        nCount = static_cast<sal_Int32>(pFuncList->GetCount());
     return nCount;
 }
 
@@ -1012,8 +888,6 @@ uno::Any SAL_CALL ScFunctionListObj::getByIndex( sal_Int32 nIndex )
     }
     else
         throw uno::RuntimeException();					// should not happen
-
-//    return uno::Any();
 }
 
 // XEnumerationAccess
@@ -1045,10 +919,10 @@ uno::Sequence<rtl::OUString> SAL_CALL ScFunctionListObj::getElementNames() throw
     const ScFunctionList* pFuncList = ScGlobal::GetStarCalcFunctionList();
     if ( pFuncList )
     {
-        USHORT nCount = (USHORT)pFuncList->GetCount();
+        sal_uInt32 nCount = pFuncList->GetCount();
         uno::Sequence<rtl::OUString> aSeq(nCount);
         rtl::OUString* pAry = aSeq.getArray();
-        for (USHORT nIndex=0; nIndex<nCount; nIndex++)
+        for (sal_uInt32 nIndex=0; nIndex<nCount; ++nIndex)
         {
             const ScFuncDesc* pDesc = pFuncList->GetFunction(nIndex);
             if ( pDesc && pDesc->pFuncName )
@@ -1063,20 +937,19 @@ sal_Bool SAL_CALL ScFunctionListObj::hasByName( const rtl::OUString& aName )
                                         throw(uno::RuntimeException)
 {
     SolarMutexGuard aGuard;
-    String aNameStr(aName);
     const ScFunctionList* pFuncList = ScGlobal::GetStarCalcFunctionList();
     if ( pFuncList )
     {
-        USHORT nCount = (USHORT)pFuncList->GetCount();
-        for (USHORT nIndex=0; nIndex<nCount; nIndex++)
+        sal_uInt32 nCount = pFuncList->GetCount();
+        for (sal_uInt32 nIndex=0; nIndex<nCount; ++nIndex)
         {
             const ScFuncDesc* pDesc = pFuncList->GetFunction(nIndex);
             //!	Case-insensitiv ???
-            if ( pDesc && pDesc->pFuncName && aNameStr == *pDesc->pFuncName )
-                return TRUE;
+            if ( pDesc && pDesc->pFuncName && aName == *pDesc->pFuncName )
+                return sal_True;
         }
     }
-    return FALSE;
+    return false;
 }
 
 //------------------------------------------------------------------------
