@@ -25,8 +25,12 @@
  * for a copy of the LGPLv3 License.
  *
  ************************************************************************/
-#include <docuno.hxx>
+
 #include "excelvbahelper.hxx"
+
+#include <comphelper/processfactory.hxx>
+#include <com/sun/star/sheet/XSheetCellRange.hpp>
+#include "docuno.hxx"
 #include "tabvwsh.hxx"
 #include "transobj.hxx"
 #include "scmod.hxx"
@@ -34,18 +38,22 @@
 #include "compiler.hxx"
 #include "token.hxx"
 #include "tokenarray.hxx"
-#include <comphelper/processfactory.hxx>
-#include <com/sun/star/sheet/XSheetCellRange.hpp>
+
+#include <com/sun/star/script/vba/VBAEventId.hpp>
+#include <com/sun/star/script/vba/XVBACompatibility.hpp>
+#include <com/sun/star/script/vba/XVBAEventProcessor.hpp>
+#include <com/sun/star/script/vba/XVBAModuleInfo.hpp>
+#include <com/sun/star/script/ModuleInfo.hpp>
+#include <com/sun/star/script/ModuleType.hpp>
 
 using namespace ::com::sun::star;
 using namespace ::ooo::vba;
 
-namespace ooo
-{
-namespace vba
-{
-namespace excel
-{
+namespace ooo {
+namespace vba {
+namespace excel {
+
+// ============================================================================
 
 uno::Reference< sheet::XDatabaseRanges >
 GetDataBaseRanges( ScDocShell* pShell ) throw ( uno::RuntimeException )
@@ -79,7 +87,7 @@ GetAutoFiltRange( ScDocShell* pShell, sal_Int16 nSheet, rtl::OUString& sName ) t
         dbAddress = xDBRange->getDataArea();
         if ( dbAddress.Sheet == nSheet )
         {
-            sal_Bool bHasAuto = sal_False;
+            sal_Bool bHasAuto = false;
             uno::Reference< beans::XPropertySet > xProps( xDBRange, uno::UNO_QUERY_THROW );
             xProps->getPropertyValue( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("AutoFilter") ) ) >>= bHasAuto;
             if ( bHasAuto )
@@ -103,6 +111,14 @@ ScDocShell* GetDocShellFromRange( const uno::Reference< uno::XInterface >& xRang
     return pScCellRangesBase->GetDocShell();
 }
 
+uno::Reference< XHelperInterface >
+getUnoSheetModuleObj( const uno::Reference< table::XCellRange >& xRange ) throw ( uno::RuntimeException )
+{
+    uno::Reference< sheet::XSheetCellRange > xSheetRange( xRange, uno::UNO_QUERY_THROW );
+    uno::Reference< sheet::XSpreadsheet > xSheet( xSheetRange->getSpreadsheet(), uno::UNO_SET_THROW );
+    return getUnoSheetModuleObj( xSheet );
+}
+
 ScDocShell* GetDocShellFromRanges( const uno::Reference< sheet::XSheetCellRangeContainer >& xRanges ) throw ( uno::RuntimeException )
 {
     // need the ScCellRangesBase to get docshell
@@ -169,7 +185,7 @@ private:
 
     bool getReplaceCellsWarning() throw ( uno::RuntimeException )
     {
-        sal_Bool res = sal_False;
+        sal_Bool res = false;
         getGlobalSheetSettings()->getPropertyValue( REPLACE_CELLS_WARNING ) >>= res;
         return ( res == sal_True );
     }
@@ -217,7 +233,14 @@ implnCopy( const uno::Reference< frame::XModel>& xModel )
 {
     ScTabViewShell* pViewShell = getBestViewShell( xModel );
     if ( pViewShell )
+    {
         pViewShell->CopyToClip(NULL,false,false,true);
+
+        // mark the copied transfer object so it is used in ScVbaRange::Insert
+        ScTransferObj* pClipObj = ScTransferObj::GetOwnClipboard( NULL );
+        if (pClipObj)
+            pClipObj->SetUseInApi( true );
+    }
 }
 
 void
@@ -225,13 +248,20 @@ implnCut( const uno::Reference< frame::XModel>& xModel )
 {
     ScTabViewShell* pViewShell =  getBestViewShell( xModel );
     if ( pViewShell )
-        pViewShell->CutToClip( NULL, TRUE );
+    {
+        pViewShell->CutToClip( NULL, sal_True );
+
+        // mark the copied transfer object so it is used in ScVbaRange::Insert
+        ScTransferObj* pClipObj = ScTransferObj::GetOwnClipboard( NULL );
+        if (pClipObj)
+            pClipObj->SetUseInApi( true );
+    }
 }
 
-void implnPasteSpecial( const uno::Reference< frame::XModel>& xModel, USHORT nFlags,USHORT nFunction,sal_Bool bSkipEmpty, sal_Bool bTranspose)
+void implnPasteSpecial( const uno::Reference< frame::XModel>& xModel, sal_uInt16 nFlags,sal_uInt16 nFunction,sal_Bool bSkipEmpty, sal_Bool bTranspose)
 {
     PasteCellsWarningReseter resetWarningBox;
-    sal_Bool bAsLink(sal_False), bOtherDoc(sal_False);
+    sal_Bool bAsLink(false), bOtherDoc(false);
     InsCellCmd eMoveMode = INS_NONE;
 
     ScTabViewShell* pTabViewShell = getBestViewShell( xModel );
@@ -251,7 +281,7 @@ void implnPasteSpecial( const uno::Reference< frame::XModel>& xModel, USHORT nFl
                     pDoc = pOwnClip->GetDocument();
                 pTabViewShell->PasteFromClip( nFlags, pDoc,
                     nFunction, bSkipEmpty, bTranspose, bAsLink,
-                    eMoveMode, IDF_NONE, TRUE );
+                    eMoveMode, IDF_NONE, sal_True );
                 pTabViewShell->CellContentChanged();
             }
         }
@@ -264,7 +294,7 @@ void implnCopyRange( const uno::Reference< frame::XModel>& xModel, const ScRange
     ScTabViewShell* pViewShell = getBestViewShell( xModel );
     if ( pViewShell )
     {
-        pViewShell->CopyToClip( NULL, rRange, FALSE, TRUE, TRUE );
+        pViewShell->CopyToClip( NULL, rRange, false, true, true );
     }
 }
 
@@ -309,20 +339,19 @@ sal_Bool IsR1C1ReferFormat( ScDocument* pDoc, const rtl::OUString& sRangeStr )
 {
     ScRangeList aCellRanges;
     String sAddress( sRangeStr );
-    USHORT nMask = SCA_VALID;
-    USHORT rResFlags = aCellRanges.Parse( sAddress, pDoc, nMask, formula::FormulaGrammar::CONV_XL_R1C1 );
+    sal_uInt16 nMask = SCA_VALID;
+    sal_uInt16 rResFlags = aCellRanges.Parse( sAddress, pDoc, nMask, formula::FormulaGrammar::CONV_XL_R1C1 );
     if ( rResFlags & SCA_VALID )
     {
         return sal_True;
     }
-    return sal_False;
+    return false;
 }
 
-uno::Reference< XHelperInterface >
-getUnoSheetModuleObj( const uno::Reference< table::XCellRange >& xRange ) throw ( uno::RuntimeException )
+uno::Reference< vba::XHelperInterface >
+getUnoSheetModuleObj( const uno::Reference< sheet::XSpreadsheet >& xSheet ) throw ( uno::RuntimeException )
 {
-    uno::Reference< sheet::XSheetCellRange > xSheetRange( xRange, uno::UNO_QUERY_THROW );
-    uno::Reference< beans::XPropertySet > xProps( xSheetRange->getSpreadsheet(), uno::UNO_QUERY_THROW );
+    uno::Reference< beans::XPropertySet > xProps( xSheet, uno::UNO_QUERY_THROW );
     rtl::OUString sCodeName;
     xProps->getPropertyValue( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("CodeName") ) ) >>= sCodeName;
     // #TODO #FIXME ideally we should 'throw' here if we don't get a valid parent, but... it is possible
@@ -330,8 +359,7 @@ getUnoSheetModuleObj( const uno::Reference< table::XCellRange >& xRange ) throw
     // are *NO* special document module objects ( of course being able to switch between vba/non vba mode at
     // the document in the future could fix this, especially IF the switching of the vba mode takes care to
     // create the special document module objects if they don't exist.
-    uno::Reference< XHelperInterface > xParent( ov::getUnoDocModule( sCodeName, GetDocShellFromRange( xRange ) ), uno::UNO_QUERY );
-
+    uno::Reference< XHelperInterface > xParent( ov::getUnoDocModule( sCodeName, GetDocShellFromRange( xSheet ) ), uno::UNO_QUERY );
     return xParent;
 }
 
@@ -348,9 +376,9 @@ formula::FormulaGrammar::Grammar GetFormulaGrammar( ScDocument* pDoc, const ScAd
         ScTokenArray* pCode = aCompiler.CompileString( sFormula );
         if ( pCode )
         {
-            USHORT nLen = pCode->GetLen();
+            sal_uInt16 nLen = pCode->GetLen();
             formula::FormulaToken** pTokens = pCode->GetArray();
-            for ( USHORT nPos = 0; nPos < nLen; nPos++ )
+            for ( sal_uInt16 nPos = 0; nPos < nLen; nPos++ )
             {
                 const formula::FormulaToken& rToken = *pTokens[nPos];
                 switch ( rToken.GetType() )
@@ -377,7 +405,7 @@ void CompileExcelFormulaToODF( ScDocument* pDoc, const String& rOldFormula, Stri
     }
     ScCompiler aCompiler( pDoc, ScAddress() );
     aCompiler.SetGrammar( excel::GetFormulaGrammar( pDoc, ScAddress(), uno::Any( rtl::OUString( rOldFormula ) ) ) );
-    ScTokenArray* pCode = aCompiler.CompileString( rOldFormula );
+    aCompiler.CompileString( rOldFormula );
     aCompiler.SetGrammar( formula::FormulaGrammar::GRAM_PODF_A1 );
     aCompiler.CreateStringFromTokenArray( rNewFormula );
 }
@@ -397,13 +425,13 @@ void CompileODFFormulaToExcel( ScDocument* pDoc, const String& rOldFormula, Stri
     {
         return;
     }
-    USHORT nLen = pCode->GetLen();
+    sal_uInt16 nLen = pCode->GetLen();
     formula::FormulaToken** pTokens = pCode->GetArray();
-    for ( USHORT nPos = 0; nPos < nLen && pTokens[nPos]; nPos++ )
+    for ( sal_uInt16 nPos = 0; nPos < nLen && pTokens[nPos]; nPos++ )
     {
         String rFormula;
         formula::FormulaToken* pToken = pTokens[nPos];
-        aCompiler.CreateStringFromToken( rFormula, pToken, TRUE );
+        aCompiler.CreateStringFromToken( rFormula, pToken, true );
         if ( pToken->GetOpCode() == ocSep )
         {
             // Excel formula separator is ",".
@@ -419,19 +447,114 @@ getUnoSheetModuleObj( const uno::Reference< sheet::XSheetCellRangeContainer >& x
     uno::Reference< container::XEnumerationAccess > xEnumAccess( xRanges, uno::UNO_QUERY_THROW );
     uno::Reference< container::XEnumeration > xEnum = xEnumAccess->createEnumeration();
     uno::Reference< table::XCellRange > xRange( xEnum->nextElement(), uno::UNO_QUERY_THROW );
-
     return getUnoSheetModuleObj( xRange );
 }
 
+uno::Reference< XHelperInterface >
+getUnoSheetModuleObj( const uno::Reference< table::XCell >& xCell ) throw ( uno::RuntimeException )
+{
+    uno::Reference< sheet::XSheetCellRange > xSheetRange( xCell, uno::UNO_QUERY_THROW );
+    uno::Reference< sheet::XSpreadsheet > xSheet( xSheetRange->getSpreadsheet(), uno::UNO_SET_THROW );
+    return getUnoSheetModuleObj( xSheet );
+}
+
+uno::Reference< XHelperInterface >
+getUnoSheetModuleObj( const uno::Reference< frame::XModel >& xModel, SCTAB nTab ) throw ( uno::RuntimeException )
+{
+    uno::Reference< sheet::XSpreadsheetDocument > xDoc( xModel, uno::UNO_QUERY_THROW );
+    uno::Reference< container::XIndexAccess > xSheets( xDoc->getSheets(), uno::UNO_QUERY_THROW );
+    uno::Reference< sheet::XSpreadsheet > xSheet( xSheets->getByIndex( nTab ), uno::UNO_QUERY_THROW );
+    return getUnoSheetModuleObj( xSheet );
+}
+
+void setUpDocumentModules( const uno::Reference< sheet::XSpreadsheetDocument >& xDoc )
+{
+    uno::Reference< frame::XModel > xModel( xDoc, uno::UNO_QUERY );
+    ScDocShell* pShell = excel::getDocShell( xModel );
+    if ( pShell )
+    {
+        String aPrjName( RTL_CONSTASCII_USTRINGPARAM( "Standard" ) );
+        pShell->GetBasicManager()->SetName( aPrjName );
+
+        /*  Set library container to VBA compatibility mode. This will create
+            the VBA Globals object and store it in the Basic manager of the
+            document. */
+        uno::Reference<script::XLibraryContainer> xLibContainer = pShell->GetBasicContainer();
+        uno::Reference<script::vba::XVBACompatibility> xVBACompat( xLibContainer, uno::UNO_QUERY_THROW );
+        xVBACompat->setVBACompatibilityMode( sal_True );
+
+        if( xLibContainer.is() )
+        {
+            if( !xLibContainer->hasByName( aPrjName ) )
+                xLibContainer->createLibrary( aPrjName );
+            uno::Any aLibAny = xLibContainer->getByName( aPrjName );
+            uno::Reference< container::XNameContainer > xLib;
+            aLibAny >>= xLib;
+            if( xLib.is()  )
+            {
+                uno::Reference< script::vba::XVBAModuleInfo > xVBAModuleInfo( xLib, uno::UNO_QUERY_THROW );
+                uno::Reference< lang::XMultiServiceFactory> xSF( pShell->GetModel(), uno::UNO_QUERY_THROW);
+                uno::Reference< container::XNameAccess > xVBACodeNamedObjectAccess( xSF->createInstance( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "ooo.vba.VBAObjectModuleObjectProvider"))), uno::UNO_QUERY_THROW );
+                // set up the module info for the workbook and sheets in the nealy created
+                // spreadsheet
+                ScDocument* pDoc = pShell->GetDocument();
+                String sCodeName = pDoc->GetCodeName();
+                if ( sCodeName.Len() == 0 )
+                {
+                    sCodeName = String( RTL_CONSTASCII_USTRINGPARAM("ThisWorkbook") );
+                    pDoc->SetCodeName( sCodeName );
+                }
+
+                std::vector< rtl::OUString > sDocModuleNames;
+                sDocModuleNames.push_back( sCodeName );
+
+                for ( SCTAB index = 0; index < pDoc->GetTableCount(); index++)
+                {
+                    String aName;
+                    pDoc->GetCodeName( index, aName );
+                    sDocModuleNames.push_back( aName );
+                }
+
+                std::vector<rtl::OUString>::iterator it_end = sDocModuleNames.end();
+
+                for ( std::vector<rtl::OUString>::iterator it = sDocModuleNames.begin(); it != it_end; ++it )
+                {
+                    script::ModuleInfo sModuleInfo;
+
+                    uno::Any aName= xVBACodeNamedObjectAccess->getByName( *it );
+                    sModuleInfo.ModuleObject.set( aName, uno::UNO_QUERY );
+                    sModuleInfo.ModuleType = script::ModuleType::DOCUMENT;
+                    xVBAModuleInfo->insertModuleInfo( *it, sModuleInfo );
+                    if( xLib->hasByName( *it ) )
+                        xLib->replaceByName( *it, uno::makeAny( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "Option VBASupport 1\n") ) ) );
+                    else
+                        xLib->insertByName( *it, uno::makeAny( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "Option VBASupport 1\n" ) ) ) );
+                }
+            }
+        }
+
+        /*  Trigger the Workbook_Open event, event processor will register
+            itself as listener for specific events. */
+        try
+        {
+            uno::Reference< script::vba::XVBAEventProcessor > xVbaEvents( pShell->GetDocument()->GetVbaEventProcessor(), uno::UNO_SET_THROW );
+            uno::Sequence< uno::Any > aArgs;
+            xVbaEvents->processVbaEvent( script::vba::VBAEventId::WORKBOOK_OPEN, aArgs );
+        }
+        catch( uno::Exception& )
+        {
+        }
+    }
+}
+
 SfxItemSet*
 ScVbaCellRangeAccess::GetDataSet( ScCellRangesBase* pRangeObj )
 {
     return pRangeObj ? pRangeObj->GetCurrentDataSet( true ) : 0;
 }
 
+// ============================================================================
 
-} //excel
-} //vba
-} //ooo
-
-/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
+} // namespace excel
+} // namespace vba
+} // namespace ooo
