@@ -100,35 +100,35 @@ ScPreview::ScPreview( Window* pParent, ScDocShell* pDocSh, ScPreviewShell* pView
     Window( pParent ),
     nPageNo( 0 ),
     nZoom( 100 ),
-    bValid( FALSE ),
+    bValid( false ),
     nTabsTested( 0 ),
     nTab( 0 ),
     nTabStart( 0 ),
     nDisplayStart( 0 ),
     nTotalPages( 0 ),
-    bStateValid( FALSE ),
-    bLocationValid( FALSE ),
+    bStateValid( false ),
+    bLocationValid( false ),
     pLocationData( NULL ),
     pDrawView( NULL ),
     nCurTab ( ScDocShell::GetCurTab() ),
-    bInPaint( FALSE ),
-    bInGetState( FALSE ),
+    bInPaint( false ),
+    bInGetState( false ),
     pDocShell( pDocSh ),
     pViewShell( pViewSh ),
-    bLeftRulerMove( FALSE ),
-    bRightRulerMove( FALSE ),
-    bTopRulerMove( FALSE ),
-    bBottomRulerMove( FALSE ),
-    bHeaderRulerMove( FALSE ),
-    bFooterRulerMove( FALSE ),
-    bLeftRulerChange( FALSE ),
-    bRightRulerChange( FALSE ),
-    bTopRulerChange( FALSE ),
-    bBottomRulerChange( FALSE ),
-    bHeaderRulerChange( FALSE ),
-    bFooterRulerChange( FALSE ),
-    bPageMargin ( FALSE ),
-    bColRulerMove( FALSE ),
+    bLeftRulerMove( false ),
+    bRightRulerMove( false ),
+    bTopRulerMove( false ),
+    bBottomRulerMove( false ),
+    bHeaderRulerMove( false ),
+    bFooterRulerMove( false ),
+    bLeftRulerChange( false ),
+    bRightRulerChange( false ),
+    bTopRulerChange( false ),
+    bBottomRulerChange( false ),
+    bHeaderRulerChange( false ),
+    bFooterRulerChange( false ),
+    bPageMargin ( false ),
+    bColRulerMove( false ),
     mnScale( 0 ),
     nColNumberButttonDown( 0 ),
     nHeaderHeight ( 0 ),
@@ -144,7 +144,7 @@ ScPreview::ScPreview( Window* pParent, ScDocShell* pDocSh, ScPreviewShell* pView
 }
 
 
-__EXPORT ScPreview::~ScPreview()
+ScPreview::~ScPreview()
 {
     delete pDrawView;
     delete pLocationData;
@@ -169,10 +169,10 @@ void ScPreview::UpdateDrawView()		// nTab muss richtig sein
         if ( !pDrawView )									// neu anlegen?
         {
             pDrawView = new FmFormView( pModel, this );
-            // #55259# die DrawView uebernimmt den Design-Modus vom Model
+            // die DrawView uebernimmt den Design-Modus vom Model
             // (Einstellung "Im Entwurfsmodus oeffnen"), darum hier zuruecksetzen
-            pDrawView->SetDesignMode( TRUE );
-            pDrawView->SetPrintPreview( TRUE );
+            pDrawView->SetDesignMode( sal_True );
+            pDrawView->SetPrintPreview( sal_True );
             pDrawView->ShowSdrPage(pPage);
         }
     }
@@ -197,7 +197,7 @@ void ScPreview::TestLastPage()
             DBG_ASSERT(nPages[nTab],"alle Tabellen leer?");
             nTabPage = nPages[nTab] - 1;
             nTabStart = 0;
-            for (USHORT i=0; i<nTab; i++)
+            for (sal_uInt16 i=0; i<nTab; i++)
                 nTabStart += nPages[i];
 
             ScDocument* pDoc = pDocShell->GetDocument();
@@ -226,7 +226,6 @@ void ScPreview::CalcPages( SCTAB /*nToWhichTab*/ )
     ScDocument* pDoc = pDocShell->GetDocument();
     nTabCount = pDoc->GetTableCount();
 
-    //SCTAB nAnz = Min( nTabCount, SCTAB(nToWhichTab+1) );
     SCTAB nAnz = nTabCount;
     SCTAB nStart = nTabsTested;
     if (!bValid)
@@ -245,7 +244,7 @@ void ScPreview::CalcPages( SCTAB /*nToWhichTab*/ )
     ScPrintOptions aOptions = SC_MOD()->GetPrintOptions();
 
     ScMarkData aMarkData;
-    aMarkData.SelectTable( nCurTab, TRUE );
+    aMarkData.SelectTable( nCurTab, true );
 
     for (SCTAB i=nStart; i<nAnz; i++)
     {
@@ -287,8 +286,8 @@ void ScPreview::CalcPages( SCTAB /*nToWhichTab*/ )
 
     aState.nDocPages = nTotalPages;
 
-    bValid = TRUE;
-    bStateValid = TRUE;
+    bValid = sal_True;
+    bStateValid = sal_True;
     DoInvalidate();
 }
 
@@ -300,11 +299,11 @@ void ScPreview::RecalcPages()					// nur nPageNo geaendert
 
     SCTAB nOldTab = nTab;
 
-    BOOL bDone = FALSE;
+    sal_Bool bDone = false;
     while (nPageNo >= nTotalPages && nTabsTested < nTabCount)
     {
         CalcPages( nTabsTested );
-        bDone = TRUE;
+        bDone = sal_True;
     }
 
     if (!bDone)
@@ -320,8 +319,6 @@ void ScPreview::RecalcPages()					// nur nPageNo geaendert
                 nTab = i;
                 nTabPage = nPageNo - nThisStart;
                 nTabStart = nThisStart;
-
-//				aPageSize = aPrintFunc.GetPageSize();
             }
         }
 
@@ -332,7 +329,7 @@ void ScPreview::RecalcPages()					// nur nPageNo geaendert
     TestLastPage();			// testen, ob hinter letzter Seite
 
     if ( nTab != nOldTab )
-        bStateValid = FALSE;
+        bStateValid = false;
 
     DoInvalidate();
 }
@@ -351,8 +348,8 @@ void ScPreview::DoPrint( ScPreviewLocationData* pFillLocation )
     Fraction aHorPrevZoom( (long)( 100 * nZoom / pDocShell->GetOutputFactor() ), 10000 );
     MapMode aMMMode( MAP_100TH_MM, Point(), aHorPrevZoom, aPreviewZoom );
 
-    BOOL bDoPrint = ( pFillLocation == NULL );
-    BOOL bValidPage = ( nPageNo < nTotalPages );
+    sal_Bool bDoPrint = ( pFillLocation == NULL );
+    sal_Bool bValidPage = ( nPageNo < nTotalPages );
 
     ScModule* pScMod = SC_MOD();
     const svtools::ColorConfig& rColorCfg = pScMod->GetColorConfig();
@@ -385,7 +382,7 @@ void ScPreview::DoPrint( ScPreviewLocationData* pFillLocation )
         pPrintFunc->SetOffset(aOffset);
         pPrintFunc->SetManualZoom(nZoom);
         pPrintFunc->SetDateTime(aDate,aTime);
-        pPrintFunc->SetClearFlag(TRUE);
+        pPrintFunc->SetClearFlag(sal_True);
         pPrintFunc->SetUseStyleColor( pScMod->GetAccessOptions().GetIsForPagePreviews() );
 
         pPrintFunc->SetDrawView( pDrawView );
@@ -400,7 +397,6 @@ void ScPreview::DoPrint( ScPreviewLocationData* pFillLocation )
         DBG_ASSERT(nPrinted<=1, "was'n nu los?");
 
         SetMapMode(aMMMode);
-//		USHORT nPrintZoom = pPrintFunc->GetZoom();
 
         if (nPrinted)	// wenn nichts, alles grau zeichnen
         {
@@ -413,7 +409,7 @@ void ScPreview::DoPrint( ScPreviewLocationData* pFillLocation )
         {
             pPrintFunc->GetPrintState( aState );
             aState.nDocPages = nTotalPages;
-            bStateValid = TRUE;
+            bStateValid = sal_True;
         }
         delete pPrintFunc;
     }
@@ -427,8 +423,8 @@ void ScPreview::DoPrint( ScPreviewLocationData* pFillLocation )
 
         Size aWinSize = GetOutputSize();
         Point aWinEnd( aWinSize.Width(), aWinSize.Height() );
-        BOOL bRight  = nPageEndX <= aWinEnd.X();
-        BOOL bBottom = nPageEndY <= aWinEnd.Y();
+        sal_Bool bRight  = nPageEndX <= aWinEnd.X();
+        sal_Bool bBottom = nPageEndY <= aWinEnd.Y();
         if (bRight || bBottom)
         {
             SetLineColor();
@@ -484,7 +480,7 @@ void ScPreview::DoPrint( ScPreviewLocationData* pFillLocation )
 }
 
 //Issue51656 Add resizeable margin on page preview from maoyg
-void __EXPORT ScPreview::Paint( const Rectangle& /* rRect */ )
+void ScPreview::Paint( const Rectangle& /* rRect */ )
 {
     if (!bValid)
     {
@@ -518,11 +514,11 @@ void __EXPORT ScPreview::Paint( const Rectangle& /* rRect */ )
     long   nRightMargin = 0;
     long   nTopMargin = 0;
     long   nBottomMargin = 0;
-    BOOL   bHeaderOn = FALSE;
-    BOOL   bFooterOn = FALSE;
+    sal_Bool   bHeaderOn = false;
+    sal_Bool   bFooterOn = false;
 
     ScDocument* pDoc = pDocShell->GetDocument();
-    BOOL   bLayoutRTL = pDoc->IsLayoutRTL( nTab );
+    sal_Bool   bLayoutRTL = pDoc->IsLayoutRTL( nTab );
 
     Size aPaintPageSize;
     if ( nPageNo < nTotalPages )
@@ -538,7 +534,7 @@ void __EXPORT ScPreview::Paint( const Rectangle& /* rRect */ )
         pPrintFunc->SetOffset(aOffset);
         pPrintFunc->SetManualZoom(nZoom);
         pPrintFunc->SetDateTime(aDate,aTime);
-        pPrintFunc->SetClearFlag(TRUE);
+        pPrintFunc->SetClearFlag(sal_True);
         pPrintFunc->SetUseStyleColor( pScMod->GetAccessOptions().GetIsForPagePreviews() );
         pPrintFunc->SetDrawView( pDrawView );
 
@@ -610,7 +606,7 @@ void __EXPORT ScPreview::Paint( const Rectangle& /* rRect */ )
         {
             pPrintFunc->GetPrintState( aState );
             aState.nDocPages = nTotalPages;
-            bStateValid = TRUE;
+            bStateValid = sal_True;
         }
 
         delete pPrintFunc;
@@ -621,8 +617,8 @@ void __EXPORT ScPreview::Paint( const Rectangle& /* rRect */ )
     long nPageEndY = aPaintPageSize.Height() - aOffset.Y();
     Size aWinSize = GetOutputSize();
     Point aWinEnd( aWinSize.Width(), aWinSize.Height() );
-    BOOL bRight  = nPageEndX <= aWinEnd.X();
-    BOOL bBottom = nPageEndY <= aWinEnd.Y();
+    sal_Bool bRight  = nPageEndX <= aWinEnd.X();
+    sal_Bool bBottom = nPageEndY <= aWinEnd.Y();
 
     if( bPageMargin )
     {
@@ -672,12 +668,12 @@ void __EXPORT ScPreview::Paint( const Rectangle& /* rRect */ )
 }
 //Issue51656 Add resizeable margin on page preview from maoyg
 
-void __EXPORT ScPreview::Command( const CommandEvent& rCEvt )
+void ScPreview::Command( const CommandEvent& rCEvt )
 {
-    USHORT nCmd = rCEvt.GetCommand();
+    sal_uInt16 nCmd = rCEvt.GetCommand();
     if ( nCmd == COMMAND_WHEEL || nCmd == COMMAND_STARTAUTOSCROLL || nCmd == COMMAND_AUTOSCROLL )
     {
-        BOOL bDone = pViewShell->ScrollCommand( rCEvt );
+        sal_Bool bDone = pViewShell->ScrollCommand( rCEvt );
         if (!bDone)
             Window::Command(rCEvt);
     }
@@ -688,17 +684,17 @@ void __EXPORT ScPreview::Command( const CommandEvent& rCEvt )
 }
 
 
-void __EXPORT ScPreview::KeyInput( const KeyEvent& rKEvt )
+void ScPreview::KeyInput( const KeyEvent& rKEvt )
 {
     //  The + and - keys can't be configured as accelerator entries, so they must be handled directly
     //  (in ScPreview, not ScPreviewShell -> only if the preview window has the focus)
 
     const KeyCode& rKeyCode = rKEvt.GetKeyCode();
-    USHORT nKey = rKeyCode.GetCode();
-    BOOL bHandled = FALSE;
+    sal_uInt16 nKey = rKeyCode.GetCode();
+    sal_Bool bHandled = false;
     if(!rKeyCode.GetModifier())
     {
-        USHORT nSlot = 0;
+        sal_uInt16 nSlot = 0;
         switch(nKey)
         {
             case KEY_ADD:      nSlot = SID_PREVIEW_ZOOMIN;  break;
@@ -707,7 +703,7 @@ void __EXPORT ScPreview::KeyInput( const KeyEvent& rKEvt )
         }
         if(nSlot)
         {
-            bHandled = TRUE;
+            bHandled = sal_True;
             pViewShell->GetViewFrame()->GetDispatcher()->Execute( nSlot, SFX_CALLMODE_ASYNCHRON );
         }
     }
@@ -722,19 +718,19 @@ const ScPreviewLocationData& ScPreview::GetLocationData()
     if ( !pLocationData )
     {
         pLocationData = new ScPreviewLocationData( pDocShell->GetDocument(), this );
-        bLocationValid = FALSE;
+        bLocationValid = false;
     }
     if ( !bLocationValid )
     {
         pLocationData->Clear();
         DoPrint( pLocationData );
-        bLocationValid = TRUE;
+        bLocationValid = sal_True;
     }
     return *pLocationData;
 }
 
 
-void ScPreview::DataChanged(BOOL bNewTime)
+void ScPreview::DataChanged(sal_Bool bNewTime)
 {
     if (bNewTime)
     {
@@ -742,7 +738,7 @@ void ScPreview::DataChanged(BOOL bNewTime)
         aTime = Time();
     }
 
-    bValid = FALSE;
+    bValid = false;
     InvalidateLocationData( SC_HINT_DATACHANGED );
     Invalidate();
 }
@@ -770,7 +766,7 @@ String ScPreview::GetPosString()
 }
 
 
-void ScPreview::SetZoom(USHORT nNewZoom)
+void ScPreview::SetZoom(sal_uInt16 nNewZoom)
 {
     if (nNewZoom < 20)
         nNewZoom = 20;
@@ -787,11 +783,11 @@ void ScPreview::SetZoom(USHORT nNewZoom)
         MapMode aMMMode( MAP_100TH_MM, Point(), aHorPrevZoom, aPreviewZoom );
         SetMapMode( aMMMode );
 
-        bInPaint = TRUE;				// don't scroll during SetYOffset in UpdateScrollBars
+        bInPaint = sal_True;				// don't scroll during SetYOffset in UpdateScrollBars
         pViewShell->UpdateScrollBars();
-        bInPaint = FALSE;
+        bInPaint = false;
 
-        bStateValid = FALSE;
+        bStateValid = false;
         InvalidateLocationData( SC_HINT_ACC_VISAREACHANGED );
         DoInvalidate();
         Invalidate();
@@ -846,13 +842,13 @@ Size lcl_GetDocPageSize( ScDocument* pDoc, SCTAB nTab )
     }
     else
     {
-        DBG_ERROR( "PageStyle not found" );
+        OSL_FAIL( "PageStyle not found" );
         return Size();
     }
 }
 
 
-USHORT ScPreview::GetOptimalZoom(BOOL bWidthOnly)
+sal_uInt16 ScPreview::GetOptimalZoom(sal_Bool bWidthOnly)
 {
     double nWinScaleX = ScGlobal::nScreenPPTX / pDocShell->GetOutputFactor();
     double nWinScaleY = ScGlobal::nScreenPPTY;
@@ -880,7 +876,7 @@ USHORT ScPreview::GetOptimalZoom(BOOL bWidthOnly)
         if (nOptimal>400)
             nOptimal = 400;
 
-        return (USHORT) nOptimal;
+        return (sal_uInt16) nOptimal;
     }
     else
         return nZoom;
@@ -1010,7 +1006,7 @@ void ScPreview::DataChanged( const DataChangedEvent& rDCEvt )
 }
 
 //Issue51656 Add resizeable margin on page preview from maoyg
-void __EXPORT ScPreview::MouseButtonDown( const MouseEvent& rMEvt )
+void ScPreview::MouseButtonDown( const MouseEvent& rMEvt )
 {
     Fraction  aPreviewZoom( nZoom, 100 );
     Fraction  aHorPrevZoom( (long)( 100 * nZoom / pDocShell->GetOutputFactor() ), 10000 );
@@ -1027,14 +1023,14 @@ void __EXPORT ScPreview::MouseButtonDown( const MouseEvent& rMEvt )
         if( bLeftRulerChange )
         {
            DrawInvert( aButtonDownChangePoint.X(), POINTER_HSIZEBAR );
-           bLeftRulerMove = TRUE;
-           bRightRulerMove = FALSE;
+           bLeftRulerMove = sal_True;
+           bRightRulerMove = false;
         }
         else if( bRightRulerChange )
         {
            DrawInvert( aButtonDownChangePoint.X(), POINTER_HSIZEBAR );
-           bLeftRulerMove = FALSE;
-           bRightRulerMove = TRUE;
+           bLeftRulerMove = false;
+           bRightRulerMove = sal_True;
         }
     }
 
@@ -1044,26 +1040,26 @@ void __EXPORT ScPreview::MouseButtonDown( const MouseEvent& rMEvt )
         if( bTopRulerChange )
         {
             DrawInvert( aButtonDownChangePoint.Y(), POINTER_VSIZEBAR );
-            bTopRulerMove = TRUE;
-            bBottomRulerMove = FALSE;
+            bTopRulerMove = sal_True;
+            bBottomRulerMove = false;
         }
         else if( bBottomRulerChange )
         {
             DrawInvert( aButtonDownChangePoint.Y(), POINTER_VSIZEBAR );
-            bTopRulerMove = FALSE;
-            bBottomRulerMove = TRUE;
+            bTopRulerMove = false;
+            bBottomRulerMove = sal_True;
         }
         else if( bHeaderRulerChange )
         {
             DrawInvert( aButtonDownChangePoint.Y(), POINTER_VSIZEBAR );
-            bHeaderRulerMove = TRUE;
-            bFooterRulerMove = FALSE;
+            bHeaderRulerMove = sal_True;
+            bFooterRulerMove = false;
         }
         else if( bFooterRulerChange )
         {
             DrawInvert( aButtonDownChangePoint.Y(), POINTER_VSIZEBAR );
-            bHeaderRulerMove = FALSE;
-            bFooterRulerMove = TRUE;
+            bHeaderRulerMove = false;
+            bFooterRulerMove = sal_True;
         }
     }
 
@@ -1089,11 +1085,11 @@ void __EXPORT ScPreview::MouseButtonDown( const MouseEvent& rMEvt )
             DrawInvert( PixelToLogic( Point( nRight[ nColNumberButttonDown-1 ], 0 ),aMMMode ).X() ,POINTER_HSPLIT );
 
         DrawInvert( aButtonDownChangePoint.X(), POINTER_HSPLIT );
-        bColRulerMove = TRUE;
+        bColRulerMove = sal_True;
     }
 }
 
-void __EXPORT ScPreview::MouseButtonUp( const MouseEvent& rMEvt )
+void ScPreview::MouseButtonUp( const MouseEvent& rMEvt )
 {
         Fraction  aPreviewZoom( nZoom, 100 );
         Fraction  aHorPrevZoom( (long)( 100 * nZoom / pDocShell->GetOutputFactor() ), 10000 );
@@ -1108,11 +1104,11 @@ void __EXPORT ScPreview::MouseButtonUp( const MouseEvent& rMEvt )
         {
             SetPointer( Pointer( POINTER_ARROW ) );
 
-            BOOL bMoveRulerAction= TRUE;
+            sal_Bool bMoveRulerAction= sal_True;
 
             ScDocument * pDoc = pDocShell->GetDocument();
             String   aOldName = pDoc->GetPageStyle( nTab );
-            BOOL  bUndo( pDoc->IsUndoEnabled() );
+            sal_Bool  bUndo( pDoc->IsUndoEnabled() );
             ScStyleSheetPool* pStylePool = pDoc->GetStyleSheetPool();
             SfxStyleSheetBase* pStyleSheet = pStylePool->Find( aOldName, SFX_STYLE_FAMILY_PAGE );
 
@@ -1128,22 +1124,22 @@ void __EXPORT ScPreview::MouseButtonUp( const MouseEvent& rMEvt )
 
                 if(( bLeftRulerChange || bRightRulerChange ) && ( aButtonUpPt.X() <= ( 0 - aOffset.X() ) || aButtonUpPt.X() > nWidth * HMM_PER_TWIPS - aOffset.X() ) )
                 {
-                    bMoveRulerAction = FALSE;
+                    bMoveRulerAction = false;
                     Paint(Rectangle(0,0,10000,10000));
                 }
                 else if( bLeftRulerChange && ( aButtonUpPt.X() / HMM_PER_TWIPS > nWidth - aLRItem.GetRight() - aOffset.X() / HMM_PER_TWIPS ) )
                 {
-                    bMoveRulerAction = FALSE;
+                    bMoveRulerAction = false;
                     Paint(Rectangle(0,0,10000,10000));
                 }
                 else if( bRightRulerChange && ( aButtonUpPt.X() / HMM_PER_TWIPS < aLRItem.GetLeft() - aOffset.X() / HMM_PER_TWIPS ) )
                 {
-                    bMoveRulerAction = FALSE;
+                    bMoveRulerAction = false;
                     Paint(Rectangle(0,0,10000,10000));
                 }
                 else if( aButtonDownPt.X() == aButtonUpPt.X() )
                 {
-                    bMoveRulerAction = FALSE;
+                    bMoveRulerAction = false;
                     DrawInvert( aButtonUpPt.X(), POINTER_HSIZEBAR );
                 }
                 if( bMoveRulerAction )
@@ -1178,33 +1174,33 @@ void __EXPORT ScPreview::MouseButtonUp( const MouseEvent& rMEvt )
 
                     Rectangle aRect(0,0,10000,10000);
                     Paint( aRect );
-                    bLeftRulerChange = FALSE;
-                    bRightRulerChange = FALSE;
+                    bLeftRulerChange = false;
+                    bRightRulerChange = false;
                 }
             }
-            bLeftRulerMove = FALSE;
-            bRightRulerMove = FALSE;
+            bLeftRulerMove = false;
+            bRightRulerMove = false;
         }
 
         if( rMEvt.IsLeft() && GetPointer() == POINTER_VSIZEBAR )
         {
             SetPointer( POINTER_ARROW );
 
-            BOOL  bMoveRulerAction = TRUE;
+            sal_Bool  bMoveRulerAction = sal_True;
             if( ( bTopRulerChange || bBottomRulerChange || bHeaderRulerChange || bFooterRulerChange ) && ( aButtonUpPt.Y() <= ( 0 - aOffset.Y() ) || aButtonUpPt.Y() > nHeight * HMM_PER_TWIPS -aOffset.Y() ) )
             {
-                bMoveRulerAction = FALSE;
+                bMoveRulerAction = false;
                 Paint( Rectangle(0,0,10000,10000) );
             }
             else if( aButtonDownPt.Y() == aButtonUpPt.Y() )
             {
-                bMoveRulerAction = FALSE;
+                bMoveRulerAction = false;
                 DrawInvert( aButtonUpPt.Y(), POINTER_VSIZEBAR );
             }
             if( bMoveRulerAction )
             {
                 ScDocument * pDoc = pDocShell->GetDocument();
-                BOOL  bUndo( pDoc->IsUndoEnabled() );
+                sal_Bool  bUndo( pDoc->IsUndoEnabled() );
                 ScStyleSheetPool* pStylePool = pDoc->GetStyleSheetPool();
                 SfxStyleSheetBase* pStyleSheet = pStylePool->Find( pDoc->GetPageStyle( nTab ), SFX_STYLE_FAMILY_PAGE );
                 DBG_ASSERT( pStyleSheet, "PageStyle not found" );
@@ -1220,20 +1216,20 @@ void __EXPORT ScPreview::MouseButtonUp( const MouseEvent& rMEvt )
 
                     if( bTopRulerMove && bTopRulerChange )
                     {
-                        aULItem.SetUpperValue( (USHORT)( aButtonUpPt.Y() / HMM_PER_TWIPS + aOffset.Y() / HMM_PER_TWIPS ) );
+                        aULItem.SetUpperValue( (sal_uInt16)( aButtonUpPt.Y() / HMM_PER_TWIPS + aOffset.Y() / HMM_PER_TWIPS ) );
                         rStyleSet.Put( aULItem );
                         pDocShell->SetModified(true);
                     }
                     else if( bBottomRulerMove && bBottomRulerChange )
                     {
-                        aULItem.SetLowerValue( (USHORT)( nHeight - aButtonUpPt.Y() / HMM_PER_TWIPS - aOffset.Y() / HMM_PER_TWIPS ) );
+                        aULItem.SetLowerValue( (sal_uInt16)( nHeight - aButtonUpPt.Y() / HMM_PER_TWIPS - aOffset.Y() / HMM_PER_TWIPS ) );
                         rStyleSet.Put( aULItem );
                         pDocShell->SetModified(true);
                     }
                     else if( bHeaderRulerMove && bHeaderRulerChange )
                     {
                         const SfxPoolItem* pItem = NULL;
-                        if ( rStyleSet.GetItemState( ATTR_PAGE_HEADERSET, FALSE, &pItem ) == SFX_ITEM_SET )
+                        if ( rStyleSet.GetItemState( ATTR_PAGE_HEADERSET, false, &pItem ) == SFX_ITEM_SET )
                         {
                             SfxItemSet& pHeaderSet = ((SvxSetItem*)pItem)->GetItemSet();
                             Size  aHeaderSize = ((const SvxSizeItem&)pHeaderSet.Get(ATTR_PAGE_SIZE)).GetSize();
@@ -1248,7 +1244,7 @@ void __EXPORT ScPreview::MouseButtonUp( const MouseEvent& rMEvt )
                     else if( bFooterRulerMove && bFooterRulerChange )
                     {
                         const SfxPoolItem* pItem = NULL;
-                        if( rStyleSet.GetItemState( ATTR_PAGE_FOOTERSET, FALSE, &pItem ) == SFX_ITEM_SET )
+                        if( rStyleSet.GetItemState( ATTR_PAGE_FOOTERSET, false, &pItem ) == SFX_ITEM_SET )
                         {
                             SfxItemSet& pFooterSet = ((SvxSetItem*)pItem)->GetItemSet();
                             Size aFooterSize = ((const SvxSizeItem&)pFooterSet.Get(ATTR_PAGE_SIZE)).GetSize();
@@ -1278,26 +1274,26 @@ void __EXPORT ScPreview::MouseButtonUp( const MouseEvent& rMEvt )
 
                     Rectangle  aRect(0,0,10000,10000);
                     Paint( aRect );
-                    bTopRulerChange = FALSE;
-                    bBottomRulerChange = FALSE;
-                    bHeaderRulerChange = FALSE;
-                    bFooterRulerChange = FALSE;
+                    bTopRulerChange = false;
+                    bBottomRulerChange = false;
+                    bHeaderRulerChange = false;
+                    bFooterRulerChange = false;
                  }
               }
-              bTopRulerMove = FALSE;
-              bBottomRulerMove = FALSE;
-              bHeaderRulerMove = FALSE;
-              bFooterRulerMove = FALSE;
+              bTopRulerMove = false;
+              bBottomRulerMove = false;
+              bHeaderRulerMove = false;
+              bFooterRulerMove = false;
         }
         if( rMEvt.IsLeft() && GetPointer() == POINTER_HSPLIT )
         {
             SetPointer(POINTER_ARROW);
             ScDocument* pDoc = pDocShell->GetDocument();
-            BOOL  bLayoutRTL = pDoc->IsLayoutRTL( nTab );
-            BOOL  bMoveRulerAction = TRUE;
+            sal_Bool  bLayoutRTL = pDoc->IsLayoutRTL( nTab );
+            sal_Bool  bMoveRulerAction = sal_True;
             if( aButtonDownPt.X() == aButtonUpPt.X() )
             {
-                bMoveRulerAction = FALSE;
+                bMoveRulerAction = false;
                 if( nColNumberButttonDown == aPageArea.aStart.Col() )
                     DrawInvert( PixelToLogic( Point( nLeftPosition, 0 ),aMMMode ).X() ,POINTER_HSPLIT );
                 else
@@ -1324,7 +1320,7 @@ void __EXPORT ScPreview::MouseButtonUp( const MouseEvent& rMEvt )
 
                 if( nNewColWidth >= 0 )
                 {
-                    aFunc.SetWidthOrHeight( TRUE, 1,nCols, nTab, SC_SIZE_DIRECT, (USHORT)nNewColWidth, TRUE, TRUE);
+                    aFunc.SetWidthOrHeight( true, 1,nCols, nTab, SC_SIZE_DIRECT, (sal_uInt16)nNewColWidth, true, true);
                     pDocShell->SetModified(true);
                 }
                 if ( ValidTab( nTab ) )
@@ -1335,12 +1331,12 @@ void __EXPORT ScPreview::MouseButtonUp( const MouseEvent& rMEvt )
                 Rectangle  nRect(0,0,10000,10000);
                 Paint( nRect );
             }
-            bColRulerMove = FALSE;
+            bColRulerMove = false;
         }
         ReleaseMouse();
 }
 
-void __EXPORT ScPreview::MouseMove( const MouseEvent& rMEvt )
+void ScPreview::MouseMove( const MouseEvent& rMEvt )
 {
     Fraction aPreviewZoom( nZoom, 100 );
     Fraction aHorPrevZoom( (long)( 100 * nZoom / pDocShell->GetOutputFactor() ), 10000 );
@@ -1396,7 +1392,7 @@ void __EXPORT ScPreview::MouseMove( const MouseEvent& rMEvt )
     Point   aHeaderLeft = LogicToPixel( Point(  -aOffset.X(), nHeaderHeight ), aMMMode );
     Point   aFooderLeft = LogicToPixel( Point( -aOffset.X(), nFooterHeight ), aMMMode );
 
-    BOOL   bOnColRulerChange = FALSE;
+    sal_Bool   bOnColRulerChange = false;
 
     for( SCCOL i=aPageArea.aStart.Col(); i<= aPageArea.aEnd.Col(); i++ )
     {
@@ -1406,7 +1402,7 @@ void __EXPORT ScPreview::MouseMove( const MouseEvent& rMEvt )
             && ( aPixPt.Y() > aColumnTop.Y() ) && ( aPixPt.Y() < aColumnBottom.Y() ) && !bLeftRulerMove && !bRightRulerMove
             && !bTopRulerMove && !bBottomRulerMove && !bHeaderRulerMove && !bFooterRulerMove )
         {
-            bOnColRulerChange = TRUE;
+            bOnColRulerChange = sal_True;
             if( !rMEvt.GetButtons() && GetPointer() == POINTER_HSPLIT )
                 nColNumberButttonDown = i;
             break;
@@ -1415,41 +1411,41 @@ void __EXPORT ScPreview::MouseMove( const MouseEvent& rMEvt )
 
     if( aPixPt.X() < ( aLeftTop.X() + 2 ) && aPixPt.X() > ( aLeftTop.X() - 2 ) && !bRightRulerMove )
     {
-        bLeftRulerChange = TRUE;
-        bRightRulerChange = FALSE;
+        bLeftRulerChange = sal_True;
+        bRightRulerChange = false;
     }
     else if( aPixPt.X() < ( aRightTop.X() + 2 ) && aPixPt.X() > ( aRightTop.X() - 2 ) && !bLeftRulerMove )
     {
-        bLeftRulerChange = FALSE;
-        bRightRulerChange = TRUE;
+        bLeftRulerChange = false;
+        bRightRulerChange = sal_True;
     }
     else if( aPixPt.Y() < ( aTopLeft.Y() + 2 ) && aPixPt.Y() > ( aTopLeft.Y() - 2 ) && !bBottomRulerMove && !bHeaderRulerMove && !bFooterRulerMove )
     {
-        bTopRulerChange = TRUE;
-        bBottomRulerChange = FALSE;
-        bHeaderRulerChange = FALSE;
-        bFooterRulerChange = FALSE;
+        bTopRulerChange = sal_True;
+        bBottomRulerChange = false;
+        bHeaderRulerChange = false;
+        bFooterRulerChange = false;
     }
     else if( aPixPt.Y() < ( aBottomLeft.Y() + 2 ) && aPixPt.Y() > ( aBottomLeft.Y() - 2 ) && !bTopRulerMove && !bHeaderRulerMove && !bFooterRulerMove )
     {
-        bTopRulerChange = FALSE;
-        bBottomRulerChange = TRUE;
-        bHeaderRulerChange = FALSE;
-        bFooterRulerChange = FALSE;
+        bTopRulerChange = false;
+        bBottomRulerChange = sal_True;
+        bHeaderRulerChange = false;
+        bFooterRulerChange = false;
     }
     else if( aPixPt.Y() < ( aHeaderLeft.Y() + 2 ) && aPixPt.Y() > ( aHeaderLeft.Y() - 2 ) && !bTopRulerMove && !bBottomRulerMove && !bFooterRulerMove )
     {
-        bTopRulerChange = FALSE;
-        bBottomRulerChange = FALSE;
-        bHeaderRulerChange = TRUE;
-        bFooterRulerChange = FALSE;
+        bTopRulerChange = false;
+        bBottomRulerChange = false;
+        bHeaderRulerChange = sal_True;
+        bFooterRulerChange = false;
     }
     else if( aPixPt.Y() < ( aFooderLeft.Y() + 2 ) && aPixPt.Y() > ( aFooderLeft.Y() - 2 ) && !bTopRulerMove && !bBottomRulerMove && !bHeaderRulerMove )
     {
-        bTopRulerChange = FALSE;
-        bBottomRulerChange = FALSE;
-        bHeaderRulerChange = FALSE;
-        bFooterRulerChange = TRUE;
+        bTopRulerChange = false;
+        bBottomRulerChange = false;
+        bHeaderRulerChange = false;
+        bFooterRulerChange = sal_True;
     }
 
     if( bPageMargin )
@@ -1540,9 +1536,9 @@ void __EXPORT ScPreview::MouseMove( const MouseEvent& rMEvt )
     }
 }
 //Issue51656 Add resizeable margin on page preview from maoyg
-void ScPreview::InvalidateLocationData(ULONG nId)
+void ScPreview::InvalidateLocationData(sal_uLong nId)
 {
-    bLocationValid = FALSE;
+    bLocationValid = false;
     if (pViewShell->HasAccessibilityObjects())
         pViewShell->BroadcastAccessibility( SfxSimpleHint( nId ) );
 }
@@ -1569,7 +1565,7 @@ com::sun::star::uno::Reference<com::sun::star::accessibility::XAccessible> ScPre
 }
 
 //Issue51656 Add resizeable margin on page preview from maoyg
-void ScPreview::DragMove( long nDragMovePos, USHORT nFlags )
+void ScPreview::DragMove( long nDragMovePos, sal_uInt16 nFlags )
 {
     Fraction aPreviewZoom( nZoom, 100 );
     Fraction aHorPrevZoom( (long)( 100 * nZoom / pDocShell->GetOutputFactor() ), 10000 );
@@ -1596,7 +1592,7 @@ void ScPreview::DragMove( long nDragMovePos, USHORT nFlags )
     }
 }
 
-void ScPreview::DrawInvert( long nDragPos, USHORT nFlags )
+void ScPreview::DrawInvert( long nDragPos, sal_uInt16 nFlags )
 {
     long  nHeight = (long) lcl_GetDocPageSize( pDocShell->GetDocument(), nTab ).Height();
     long  nWidth = (long) lcl_GetDocPageSize( pDocShell->GetDocument(), nTab ).Width();
